@@ -173,7 +173,7 @@ import colors
  CAL_DAYOOR,        # Day out of range (1...31)
  CAL_BADOPTION,     # Unknown option (must be Last, first, -1, ...)
  CAL_EMPTYFIELD     # A part is empty (1-6//Last)
-) = (-1, 0, -2, -3, -4, -5, -6, -7, -8)
+ ) = (-1, 0, -2, -3, -4, -5, -6, -7, -8)
 
 
 def is_leap_year(year):
@@ -192,13 +192,13 @@ def get_last_day(year, month):
     if month < 1 or month > 12 or year < 0:
         return -1
 
-    if  month == 1 or \
-        month == 3 or \
-        month == 5 or \
-        month == 7 or \
-        month == 8 or \
-        month == 10 or \
-        month == 12:
+    if month == 1 or \
+       month == 3 or \
+       month == 5 or \
+       month == 7 or \
+       month == 8 or \
+       month == 10 or \
+       month == 12:
         return 31
     if month == 2:
         if is_leap_year(year):
@@ -220,7 +220,7 @@ def day_of_week(day, month, year):
     else:
         y = year
         m = 2
-    return ((23 * month / 9) + day + 4 + year + (y / 4) \
+    return ((23 * month / 9) + day + 4 + year + (y / 4)
             - (y / 100) + (y / 400) - m) % 7
 
 
@@ -824,9 +824,9 @@ class cal_t:
             CAL_NOMATCH --> The date does not match the calendar
 
         """
-        if  self.cal_year != year or \
-            not is_bit_set(self.month, month) or \
-            not is_bit_set(self.year[month - 1], day):
+        if self.cal_year != year or \
+           not is_bit_set(self.month, month) or \
+           not is_bit_set(self.year[month - 1], day):
             return CAL_NOMATCH
         return CAL_NOERROR
 
@@ -957,7 +957,7 @@ class cal_t:
         day_labels = list()
         for i in range(loc.first_week_day, 7 + loc.first_week_day):
             day_labels.append(
-                        loc.days['format']['abbreviated'][i % 7][:DAY_LEN])
+                loc.days['format']['abbreviated'][i % 7][:DAY_LEN])
         str_day = ' '.join(day_labels).encode('utf-8')
         if month is not None:
             t = "%s %d" % (loc.months['format']['wide'][month].encode('utf-8'),
@@ -998,7 +998,7 @@ class cal_t:
                                 sys.stdout.write(" " * (DAY_LEN + 1))
                                 continue
                             if (self.calmatch(d, ml, self.cal_year) !=
-                                CAL_NOMATCH):
+                                    CAL_NOMATCH):
                                 sys.stdout.write(" " *
                                                  (1 - self.highlight_len))
                                 sys.stdout.write(self.highlight_on)
