@@ -29,7 +29,7 @@ from help import print_trim
 
 def usage():
     """Print a usage message on STDOUT."""
-    print_trim(_("""Usage: cat [-h] [CAL|DIR]...
+    print_trim(_("""Usage: cat [CAL|DIR]...
         Print calendar or calendar directory parameters.
         If CAL|DIR is not specified, print the parameters of the current
         calendar directory.
@@ -86,8 +86,10 @@ def cat(sql_session, current_cwd, arguments, workload=None):
     paths = list()
     if args:
         for arg in args:
-            paths.extend(path_cal.get_paths(sql_session, arg, current_cwd,
-                                             workload=workload))
+            paths.extend(path_cal.get_paths(sql_session,
+                                            arg,
+                                            current_cwd,
+                                            workload=workload))
     else:
         paths.append(current_cwd)
     if not paths:
@@ -96,7 +98,7 @@ def cat(sql_session, current_cwd, arguments, workload=None):
     first = True
     error = False
     for p in paths:
-        if first == False:
+        if first is False:
             sys.stdout.write("\n")
         else:
             first = False
