@@ -30,7 +30,7 @@ from help import print_trim
 
 def usage():
     """Print a usage message on STDOUT."""
-    print_trim(_("""Usage: cd [-h] [DIR]
+    print_trim(_("""Usage: cd [DIR]
         Change the current calendar directory to DIR.
         If DIR is not specified, change to the root directory (`/').
         If DIR is `-', change to the previous working calendar directory.
