@@ -82,7 +82,7 @@ def _rename(sql_session, cwd, src_path, dst, recursive):
         return 1
     if lp > 1:
         sys.stderr.write(_("cp: `%s/%s': no such calendar or directory\n") %
-                            (dest_path[0], base))
+                         (dest_path[0], base))
         return 1
     session = sql_session.open_session()
     try:
@@ -166,9 +166,11 @@ def _cp_multi(sql_session, cwd, paths, recursive, force):
                     return 1
                 else:
                     if recursive or dest_child.entry_type == 0:
-                        rm.rm_recursive(session,
-                                path_cal.PathCal(session, id=dest_child.id),
-                                True, recursive=True)
+                        rm.rm_recursive(
+                            session,
+                            path_cal.PathCal(session, id=dest_child.id),
+                            True,
+                            recursive=True)
                         sql_session.close_session(session)
                         session = sql_session.open_session()
         if cal.entry_type != 0:
@@ -182,7 +184,8 @@ def _cp_multi(sql_session, cwd, paths, recursive, force):
                 cp_recursive(session, cal, dest_cal)
             else:
                 sys.stderr.write(
-                  _("cp: cannot copy `%s' to a sub-directory of itself\n") % p)
+                    _("cp: cannot copy `%s' to a sub-directory of itself\n") %
+                    p)
                 sql_session.cancel_session(session)
                 return 1
         else:
@@ -226,7 +229,8 @@ def cp(sql_session, current_cwd, arguments):
             if not p:
                 if i + 1 != num_args:
                     sys.stderr.write(
-                      _("cp: `%s': no such calendar or directory\n") % args[i])
+                        _("cp: `%s': no such calendar or directory\n") %
+                        args[i])
                     return 1
                 else:
                     dest_rename = args[i]
@@ -243,7 +247,7 @@ def cp(sql_session, current_cwd, arguments):
     if lp == 1:
         if num_args < 2:
             sys.stderr.write(
-                    _("cp: no enough operand or unknown calendar/directory\n"))
+                _("cp: no enough operand or unknown calendar/directory\n"))
             return 1
         return _rename(sql_session, current_cwd, paths[0], args[1], recursive)
     # Copy
