@@ -66,13 +66,13 @@ def _print1cal(session, cal, long_listing):
         print cal.name
         return
     print "%(dir)s %(name)s" % \
-            {"dir":   'd' if cal.entry_type == 1 else '-',
-             "name":     cal.name}
+          {"dir":   'd' if cal.entry_type == 1 else '-',
+           "name":     cal.name}
 
 
 def _print_cals(session, cals, long_listing):
     """Print the given calendars."""
-    if config.ISATTY and not long_listing:
+    if config.ISATTY_STDOUT and not long_listing:
         m = reduce(_max, cals, 0) + _INTERSPACE
         w = console_size.width
         n = w / m
@@ -120,7 +120,7 @@ def ls(sql_session, current_cwd, arguments, workload=None):
                                    workload=workload)
             if not p:
                 sys.stderr.write(
-                        _("ls: `%s': no such calendar or directory\n") % arg)
+                    _("ls: `%s': no such calendar or directory\n") % arg)
             else:
                 paths.extend(p)
     else:
