@@ -111,12 +111,12 @@ def rm_recursive(session, p, force, recursive, workload=None):
 
     """
     global ROOT_DIR_ID
-    if force == True and recursive == True:
+    if force is True and recursive is True:
         ret = rm_recursive_force(session, p, workload)
         if ret:
-            sys.stderr.write(
-            _("rm: `%s' is used (run `whatuses \"%s\"' for more details)\n")
-            % (ret, ret))
+            sys.stderr.write(_(
+                "rm: `%s' is used (run `whatuses \"%s\"' for more details)\n")
+                % (ret, ret))
             return 3
         else:
             return 0
@@ -132,7 +132,7 @@ def rm_recursive(session, p, force, recursive, workload=None):
         return 3
     # Calendar
     if cal.entry_type == 0:
-        if force == False:
+        if force is False:
             answer = raw_input(_("rm: remove calendar `%s'? ") %
                                unicode(p).encode('utf-8'))
             if answer[0] not in (_('y'), _('Y')):
@@ -140,7 +140,7 @@ def rm_recursive(session, p, force, recursive, workload=None):
         session.delete(cal)
         return 0
     # Directory
-    if recursive == False:
+    if recursive is False:
         sys.stderr.write(_("rm: cannot remove `%s': Is a directory\n") % p)
         return 1
     answer = raw_input(_("rm: descend into directory `%s'? ") %
@@ -193,15 +193,17 @@ def rm(sql_session, current_cwd, arguments, workload=None):
     paths = list()
     if args:
         for arg in args:
-            paths.extend(path_cal.get_paths(sql_session, arg, current_cwd,
-                                             workload=workload))
+            paths.extend(path_cal.get_paths(sql_session,
+                                            arg,
+                                            current_cwd,
+                                            workload=workload))
     else:
-        if force == False:
+        if force is False:
             sys.stderr.write(_("rm: missing calendar or directory name\n"))
             return 1
         return 0
     if not paths:
-        if force == False:
+        if force is False:
             sys.stderr.write(_("rm: no such calendar or directory\n"))
             return 1
         return 0
