@@ -56,11 +56,11 @@ def show(sql_session, current_cwd, arguments, workload=None):
     # Parse the parameters
     try:
         optlist, args = getopt.getopt(arguments, "m:y:h",
-                [
-                    "month=",
-                    "year=",
-                    "help"
-                ])
+                                      [
+                                          "month=",
+                                          "year=",
+                                          "help"
+                                      ])
     except getopt.GetoptError, err:
         sys.stderr.write(_("show: ") + str(err) + "\n")
         return 1
@@ -95,7 +95,7 @@ def show(sql_session, current_cwd, arguments, workload=None):
     if args:
         for arg in args:
             paths.extend(path_cal.get_paths(sql_session, arg, current_cwd,
-                                             workload=workload))
+                                            workload=workload))
     else:
         sys.stderr.write(_("show: missing calendar name\n"))
         return 1
@@ -106,7 +106,7 @@ def show(sql_session, current_cwd, arguments, workload=None):
     error = False
     session = sql_session.open_session()
     for p in paths:
-        if first == False:
+        if first is False:
             sys.stdout.write("\n")
         else:
             first = False
