@@ -95,9 +95,10 @@ def print_whatuses(session, cal, p, workload,
         q = q.filter(job_main_s.workload_date == workload)
         q = q.order_by(job_main_s.parent)
     for job in q:
-        print_function(user_data, cal_name,
-                   _("Job") if job.type else _("Jobset"),
-                   path.id2path(session, job.id, workload))
+        print_function(user_data,
+                       cal_name,
+                       _("Job") if job.type else _("Jobset"),
+                       path.id2path(session, job.id, workload))
 
 
 def print_whatuses_dir(session, cal, p, workload,
@@ -115,15 +116,21 @@ def print_whatuses_dir(session, cal, p, workload,
     for c in simple_queries_cal.sql_get_cal_children(session, cal.id, False,
                                                      workload, False):
         if c.entry_type == 0:
-            print_whatuses(session, c,
-                            path_cal.PathCal(session, id=c.id,
-                                             workload=workload),
-                            workload, print_function, user_data)
+            print_whatuses(session,
+                           c,
+                           path_cal.PathCal(session, id=c.id,
+                                            workload=workload),
+                           workload,
+                           print_function,
+                           user_data)
         else:
-            print_whatuses_dir(session, c,
-                                path_cal.PathCal(session, id=c.id,
-                                                 workload=workload),
-                                workload, print_function, user_data)
+            print_whatuses_dir(session,
+                               c,
+                               path_cal.PathCal(session, id=c.id,
+                                                workload=workload),
+                               workload,
+                               print_function,
+                               user_data)
 
 
 def whatuses(sql_session, current_cwd, arguments, workload=None):
@@ -155,8 +162,7 @@ def whatuses(sql_session, current_cwd, arguments, workload=None):
                                    workload=workload)
             if not p:
                 sys.stderr.write(
-                      _("whatuses: `%s': no such calendar or directory\n")
-                      % arg)
+                    _("whatuses: `%s': no such calendar or directory\n") % arg)
             else:
                 paths.extend(p)
     else:
