@@ -68,8 +68,9 @@ def rm(sql_session, arguments, workload=None):
         else:
             for e in env_list:
                 if whatuses.is_used(session, e, workload):
-                    sys.stderr.write(
-         _("rm: `%s' is used (run `whatuses %s' for more details)\n") % (e, e))
+                    sys.stderr.write(_(
+                      "rm: `%s' is used (run `whatuses %s' for more details)\n"
+                        ) % (e, e))
                     error = True
                 else:
                     session.delete(e)
