@@ -38,9 +38,9 @@ def usage_options(with_name=True):
     if with_name:
         print _("  --name=NAME             environment group name.")
     print _(
-"""  --append=NAME=VALUE     add an environment variable at the end of the list.
-                          This option can be specified more than one time to
-                          add several environment variables in one go.
+        """  --append=NAME=VALUE     add an environment variable at the end of
+                          the list. This option can be specified more than one
+                          time to add several environment variables in one go.
   --insert=NAME=VALUE     insert an environment variable at the position
                           specified by the --position parameter or in first
                           position if --position is not specified.  Cannot be
@@ -72,15 +72,15 @@ def parse_args(argv):
 
     """
     optlist, args = getopt.getopt(argv, "n:d:a:i:p:h",
-            [
-                "name=",
-                "delete=",
-                "append=",
-                "insert=",
-                "position=",
-                "description=",
-                "help"
-            ])
+                                  [
+                                      "name=",
+                                      "delete=",
+                                      "append=",
+                                      "insert=",
+                                      "position=",
+                                      "description=",
+                                      "help"
+                                  ])
     return (optlist, args)
 
 
