@@ -117,8 +117,7 @@ def print_whatuses(session, env, workload,
         q = q.filter(host_environment_s.host_id == hosts.id)
         q = q.order_by(hosts.hostname)
     for h in q:
-        print_function(user_data, _("Host"),
-                       "%s (%s)" % (h.hostname, h.portnum))
+        print_function(user_data, _("Host"), str(h))
 
 
 def whatuses(sql_session, arguments, workload=None):
