@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011, 2012 Herve Quatremain
+# Copyright (C) 2011, 2013 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -24,6 +24,8 @@ import getopt
 
 from tables.host_environment import host_environment
 from tables.environments import environments
+from tables.clusters import clusters
+from tables.host_clusters import host_clusters
 import host_utils
 from help import print_trim
 import cert
@@ -68,7 +70,7 @@ def _print_host(session, host):
 
     Arguments:
     session -- SQLAlchemy session
-    env -- host object to print
+    host -- host object to print
 
     """
     _print_val(_("Hostname"), "%s", host.hostname)
@@ -88,6 +90,10 @@ def _print_host(session, host):
     q = q.filter(host_environment.env_id == environments.id)
     for e in q.order_by(host_environment.position):
         _print_val(_("Environment group"), "%s", e.name)
+    q = session.query(clusters).filter(host_clusters.host_id == host.id)
+    q = q.filter(host_clusters.cluster_id == clusters.id)
+    for c in q.order_by(clusters.name):
+        _print_val(_("Cluster"), "%s", c.name)
     _print_val(_("Description"), "%s", host.description)
 
 
