@@ -67,13 +67,17 @@ if WITH_GNUTLS:
 
         def get_not_before(self):
             dt = datetime.datetime.fromtimestamp(self.cert.activation_time)
-            return babel.dates.format_datetime(dt, format="medium",
-                            locale=locale_utils.get_locale()).encode('utf-8')
+            return babel.dates.format_datetime(
+                dt,
+                format="medium",
+                locale=locale_utils.get_locale()).encode('utf-8')
 
         def get_not_after(self):
             dt = datetime.datetime.fromtimestamp(self.cert.expiration_time)
-            return babel.dates.format_datetime(dt, format="medium",
-                            locale=locale_utils.get_locale()).encode('utf-8')
+            return babel.dates.format_datetime(
+                dt,
+                format="medium",
+                locale=locale_utils.get_locale()).encode('utf-8')
 
         def get_CN(self):
             return self.cert.subject.CN
@@ -128,14 +132,18 @@ else:
         def get_not_before(self):
             dt = datetime.datetime.strptime(str(self.cert.get_not_before()),
                                             "%b %d %H:%M:%S %Y %Z")
-            return babel.dates.format_datetime(dt, format="medium",
-                            locale=locale_utils.get_locale()).encode('utf-8')
+            return babel.dates.format_datetime(
+                dt,
+                format="medium",
+                locale=locale_utils.get_locale()).encode('utf-8')
 
         def get_not_after(self):
             dt = datetime.datetime.strptime(str(self.cert.get_not_after()),
                                             "%b %d %H:%M:%S %Y %Z")
-            return babel.dates.format_datetime(dt, format="medium",
-                            locale=locale_utils.get_locale()).encode('utf-8')
+            return babel.dates.format_datetime(
+                dt,
+                format="medium",
+                locale=locale_utils.get_locale()).encode('utf-8')
 
         def get_CN(self):
             return self.cert.get_subject().CN
