@@ -57,13 +57,13 @@ def usage():
 def _print_host(host, long_listing):
     """Print a host name."""
     if not long_listing:
-        print "%s (%s)" % (host.hostname, host.portnum)
+        print str(host)
         return
     print "%(ssl)s%(env)s %(port)-16s %(name)s" % \
-               {"ssl": 's' if host.sslenable else '-',
-                "env": 'e' if host.host_environment else '-',
-                "port": host.portnum,
-                "name": host.hostname}
+          {"ssl": 's' if host.sslenable else '-',
+           "env": 'e' if host.host_environment else '-',
+           "port": host.portnum,
+           "name": host.hostname}
 
 
 def ls(sql_session, arguments):
