@@ -69,17 +69,17 @@ def parse_args(argv):
 
     """
     optlist, args = getopt.getopt(argv, "hf",
-            [
-                "force",
-                "host=",
-                "port=",
-                "ssl=",
-                "sslcert=",
-                "addenv=",
-                "delenv=",
-                "description=",
-                "help"
-            ])
+                                  [
+                                      "force",
+                                      "host=",
+                                      "port=",
+                                      "ssl=",
+                                      "sslcert=",
+                                      "addenv=",
+                                      "delenv=",
+                                      "description=",
+                                      "help"
+                                  ])
     return (optlist, args)
 
 
@@ -138,12 +138,13 @@ def set(session, host, opts):
             envs = filter(lambda id: id != env.id, envs)
     error = False
     if port is not None:
-        if host_utils.is_known_port(port) or force == True:
+        if host_utils.is_known_port(port) or force is True:
             host.portnum = port.decode('utf-8')
         else:
-            sys.stderr.write(
-            _("Unknown port (--port=%s). Use --force to bypass this check.\n")
-                            % port)
+            sys.stderr.write(_(
+                "Unknown port (--port=%s). Use --force to bypass this check.\n"
+                )
+                % port)
             error = True
     if envs:
         new_envs = list()
@@ -183,17 +184,18 @@ def set(session, host, opts):
                     if altname.lower() == h:
                         break
                 else:
-                    if force == False:
+                    if force is False:
                         sys.stderr.write(_("The hostname (`%s') does not \
 match the certificate CN (`%s') nor the certificate alternative DNS names \
 (%s)\n")
-                         % (host.hostname, certX509.get_CN(),
-                            certX509.get_dns()))
+                                         % (host.hostname,
+                                            certX509.get_CN(),
+                                            certX509.get_dns()))
                         error = True
             if certX509.not_yet_active() and not force:
                 sys.stderr.write(_("The certificate is not yet activated (it \
 will be valid on %s)\n")
-                         % certX509.get_not_before())
+                                 % certX509.get_not_before())
                 error = True
             if certX509.has_expired() and not force:
                 sys.stderr.write(_("The certificate has expired on %s\n") %
