@@ -48,11 +48,14 @@ from tables.job_success_return_code import job_success_return_code
 from tables.job_username import job_username
 from tables.job_host import job_host
 from tables.hosts import hosts
+from tables.job_cluster import job_cluster
+from tables.clusters import clusters
 from tables.constraint_file import constraint_file
 from tables.job_environment import job_environment
 from tables.link import link
 from tables.job_main_s import job_main_s
 from tables.job_host_s import job_host_s
+from tables.job_cluster_s import job_cluster_s
 from tables.job_command_s import job_command_s
 from tables.job_arguments_s import job_arguments_s
 from tables.job_success_return_code_s import job_success_return_code_s
@@ -76,7 +79,7 @@ from help import print_trim
 
 def usage():
     """Print a usage message on STDOUT."""
-    print_trim(_("""Usage: cat [-h] [JOB|JOBSET]...
+    print_trim(_("""Usage: cat [JOB|JOBSET]...
     Print job or jobset parameters.
     If JOB|JOBSET is not specified, print the parameters of the current jobset.
     In the output, if a parameter name is followed by the `*' character, it
@@ -144,10 +147,10 @@ def _print_val(title, hist, fmt=None, val=None, writable=True):
     if fmt is not None:
         if val is not None:
             print "%s %c %s" % (title.rjust(_FIELD_WIDTH),
-                               ' ' if hist else '*', sep), fmt % val
+                                ' ' if hist else '*', sep), fmt % val
         else:
             print "%s %c %s" % (title.rjust(_FIELD_WIDTH),
-                               ' ' if hist else '*', sep), fmt
+                                ' ' if hist else '*', sep), fmt
     else:
         print "%s %c %s" % (title.rjust(_FIELD_WIDTH), ' ' if hist else '*',
                             sep)
@@ -186,7 +189,7 @@ def cat(sql_session, current_cwd, arguments, workload=None):
     first = True
     error = False
     for p in paths:
-        if first == False:
+        if first is False:
             sys.stdout.write("\n")
         else:
             first = False
@@ -208,22 +211,34 @@ def cat(sql_session, current_cwd, arguments, workload=None):
             _print_val(_("Current status"), True, "%s",
                        status_utils.get_status_string(session, job.id,
                                                       workload))
+            d = status_utils.get_status_duration(session, job.id, workload)
+            _print_val(_("Duration"), True, "%d (%dh%02dm%02ds)",
+                       (d, d / 3600, d / 60, d % 60), False)
         _print_val(_("Type"), True,
                    "%s", _("Jobset") if not job.type else _("Job"),
                    True if workload is None else job_main_s.rw_type)
         _print_val(_("Enabled"), True, "%s", bool(job.enabled),
                    True if workload is None else job_main_s.rw_enabled)
-        sql_session.close_session(session)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                                job_host if workload is None else job_host_s,
-                                workload)
-        session = sql_session.open_session()
-        host = session.query(hosts).filter_by(id=obj.host_id).one()
-        _print_val(_("Host"), in_object,
-                   "%s (%s/SSL)" if host.sslenable else "%s (%s)",
-                   (host.hostname, host.portnum),
-                   True if workload is None else job_main_s.rw_job_host)
+        in_object, obj = sql_hierarchy.get_cluster_or_host(session, p,
+                                                           workload)
+        if obj is not None:
+            if isinstance(obj, job_cluster) or isinstance(obj, job_cluster_s):
+                c = session.query(clusters).filter_by(id=obj.cluster_id).one()
+                _print_val(_("Cluster"),
+                           in_object,
+                           "%s",
+                           c.name,
+                           True if workload is None
+                           else job_main_s.rw_job_cluster)
+            elif isinstance(obj, job_host) or isinstance(obj, job_host_s):
+                host = session.query(hosts).filter_by(id=obj.host_id).one()
+                _print_val(
+                    _("Host"),
+                    in_object,
+                    "%s (SSL)" if host.sslenable else "%s",
+                    str(host),
+                    True if workload is None else job_main_s.rw_job_host)
 
         if job.cal_id == 0:
             for i in range(len(p.id) - 2, -1, -1):
@@ -234,7 +249,10 @@ def cat(sql_session, current_cwd, arguments, workload=None):
                     query = query.filter(job_main_s.workload_date == workload)
                 cal_id, = query.filter_by(id=p.id[i]).one()
                 if cal_id != 0:
-                    _print_val(_("Calendar"), False, "%s",
+                    _print_val(
+                        _("Calendar"),
+                        False,
+                        "%s",
                         path_cal.PathCal(sql_session, id=cal_id,
                                          workload=workload),
                         True if workload is None else job_main_s.rw_cal_id)
@@ -244,8 +262,8 @@ def cat(sql_session, current_cwd, arguments, workload=None):
                            True if workload is None else job_main_s.rw_cal_id)
         else:
             _print_val(_("Calendar"), True, "%s",
-                        path_cal.PathCal(sql_session, id=job.cal_id,
-                                         workload=workload),
+                       path_cal.PathCal(sql_session, id=job.cal_id,
+                                        workload=workload),
                        True if workload is None else job_main_s.rw_cal_id)
 
         if job.start_time < 0:
@@ -253,21 +271,25 @@ def cat(sql_session, current_cwd, arguments, workload=None):
                                                      workload)
             if j is not None:
                 start_time = j.start_time
-                _print_val(_("Start time"), False, "%02dh%02d",
-                            (start_time / 100, start_time % 100),
+                _print_val(
+                    _("Start time"), False, "%02dh%02d",
+                    (start_time / 100, start_time % 100),
                     True if workload is None else job_main_s.rw_start_time)
             else:
-                _print_val(_("Start time"), False, "%02dh%02d", (0, 0),
+                _print_val(
+                    _("Start time"), False, "%02dh%02d", (0, 0),
                     True if workload is None else job_main_s.rw_start_time)
         else:
             _print_val(_("Start time"), True, "%02dh%02d",
-                     (job.start_time / 100, job.start_time % 100),
-                     True if workload is None else job_main_s.rw_start_time)
+                       (job.start_time / 100, job.start_time % 100),
+                       True if workload is None else job_main_s.rw_start_time)
         sql_session.close_session(session)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                            job_command if workload is None else job_command_s,
-                            workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_command if workload is None else job_command_s,
+            workload)
         if obj is not None:
             _print_val(_("Command"), in_object, "%s", obj.command,
                        True if workload is None else job_main_s.rw_job_command)
@@ -275,143 +297,198 @@ def cat(sql_session, current_cwd, arguments, workload=None):
             _print_val(_("Command"), True, "%s", _("None"),
                        True if workload is None else job_main_s.rw_job_command)
 
-        in_object, lst = sql_hierarchy.get_list(sql_session, p,
-                        job_arguments if workload is None else job_arguments_s,
-                        job_arguments.position if workload is None \
-                                               else job_arguments_s.position,
-                         workload)
+        in_object, lst = sql_hierarchy.get_list(
+            sql_session,
+            p,
+            job_arguments if workload is None else job_arguments_s,
+            job_arguments.position if workload is None
+            else job_arguments_s.position,
+            workload)
 
         if lst is not None:
             params = list()
             for param in lst:
                 if param.position == -1:
-                    _print_val(_("Parameters"), in_object,
-                     True if workload is None else job_main_s.rw_job_arguments)
+                    _print_val(
+                        _("Parameters"),
+                        in_object,
+                        True if workload is None
+                        else job_main_s.rw_job_arguments)
                     break
                 params.append('"' + param.argument + '"')
             else:
-                _print_val(_("Parameters"), in_object, "%s", ' '.join(params),
+                _print_val(
+                    _("Parameters"),
+                    in_object,
+                    "%s",
+                    ' '.join(params),
                     True if workload is None else job_main_s.rw_job_arguments)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                        job_success_return_code if workload is None \
-                                                else job_success_return_code_s,
-                        workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_success_return_code if workload is None
+            else job_success_return_code_s,
+            workload)
         if obj is not None:
             _print_val(_("Success return code"), in_object, "%s",
                        obj.success_ret,
-                       True if workload is None \
-                            else job_main_s.rw_job_success_return_code)
+                       True if workload is None
+                       else job_main_s.rw_job_success_return_code)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_username if workload is None else job_username_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_username if workload is None else job_username_s, workload)
         if obj is not None:
-            _print_val(_("Username"), in_object, "%s", obj.username,
-                    True if workload is None else job_main_s.rw_job_username)
+            _print_val(
+                _("Username"),
+                in_object,
+                "%s",
+                obj.username,
+                True if workload is None else job_main_s.rw_job_username)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_file_out if workload is None else job_file_out_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_file_out if workload is None else job_file_out_s,
+            workload)
         if obj is not None:
-            _print_val(_("Output file"), in_object, "%s", obj.file_out,
-                    True if workload is None else job_main_s.rw_job_file_out)
+            _print_val(
+                _("Output file"),
+                in_object,
+                "%s",
+                obj.file_out,
+                True if workload is None else job_main_s.rw_job_file_out)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_file_err if workload is None else job_file_err_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_file_err if workload is None else job_file_err_s,
+            workload)
         if obj is not None:
-            _print_val(_("Error file"), in_object, "%s", obj.file_err,
-                    True if workload is None else job_main_s.rw_job_file_err)
+            _print_val(
+                _("Error file"),
+                in_object,
+                "%s",
+                obj.file_err,
+                True if workload is None else job_main_s.rw_job_file_err)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_detach if workload is None else job_detach_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_detach if workload is None else job_detach_s,
+            workload)
         if obj is not None:
             _print_val(_("Detach"), in_object, "%s", bool(obj.detach),
                        True if workload is None else job_main_s.rw_job_detach)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_manual if workload is None else job_manual_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_manual if workload is None else job_manual_s,
+            workload)
         if obj is not None:
             _print_val(_("Manual"), in_object, "%s", bool(obj.manual),
                        True if workload is None else job_main_s.rw_job_manual)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_manual_command if workload is None
-                                             else job_manual_command_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_manual_command if workload is None else job_manual_command_s,
+            workload)
         if obj is not None:
-            _print_val(_("Alert cmd for manual"), in_object, "%s",
-                       obj.manual_command,
-                       True if workload is None
-                            else job_main_s.rw_job_manual_command)
+            _print_val(
+                _("Alert cmd for manual"),
+                in_object,
+                "%s",
+                obj.manual_command,
+                True if workload is None else job_main_s.rw_job_manual_command)
         else:
             _print_val(_("Alert cmd for manual"), True, "%s", _("None"),
                        True if workload is None
-                            else job_main_s.rw_job_manual_command)
+                       else job_main_s.rw_job_manual_command)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_control_group if workload is None \
-                                            else job_control_group_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_control_group if workload is None else job_control_group_s,
+            workload)
         if obj is not None:
-            _print_val(_("Linux Control Group"), in_object, "%s",
-                       obj.control_group,
+            _print_val(
+                _("Linux Control Group"),
+                in_object,
+                "%s",
+                obj.control_group,
                 True if workload is None else job_main_s.rw_job_control_group)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_max_duration if workload is None \
-                                           else job_max_duration_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_max_duration if workload is None else job_max_duration_s,
+            workload)
         if obj is not None:
             if obj.max_duration == 0:
-                _print_val(_("Max duration"), in_object, "%s", _("No limit"),
-                           True if workload is None \
-                                else job_main_s.rw_job_max_duration)
+                _print_val(
+                    _("Max duration"),
+                    in_object,
+                    "%s",
+                    _("No limit"),
+                    True if workload is None
+                    else job_main_s.rw_job_max_duration)
             else:
                 _print_val(_("Max duration"), in_object, "%dh%02d",
                            (obj.max_duration / 60, obj.max_duration % 60),
-                           True if workload is None \
-                                else job_main_s.rw_job_max_duration)
+                           True if workload is None
+                           else job_main_s.rw_job_max_duration)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_retries if workload is None else job_retries_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_retries if workload is None else job_retries_s,
+            workload)
         if obj is not None:
-            _print_val(_("Number of retries"), in_object, "%s", obj.retries,
+            _print_val(
+                _("Number of retries"),
+                in_object,
+                "%s",
+                obj.retries,
                 True if workload is None else job_main_s.rw_job_retries)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_retries_interval if workload is None \
-                                               else job_retries_interval_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_retries_interval if workload is None
+            else job_retries_interval_s,
+            workload)
         if obj is not None:
             _print_val(_("Interval retries"), in_object, "%dh%02d",
                        (obj.retries_interval / 60, obj.retries_interval % 60),
-                       True if workload is None \
-                            else job_main_s.rw_job_retries_interval)
+                       True if workload is None
+                       else job_main_s.rw_job_retries_interval)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_start_limit if workload is None \
-                                                      else job_start_limit_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_start_limit if workload is None else job_start_limit_s,
+            workload)
         if obj is not None:
             if obj.start_limit <= 0:
                 _print_val(_("Limit past start time"), in_object, "%s",
                            _("No limit"),
-                           True if workload is None \
-                                else job_main_s.rw_job_start_limit)
+                           True if workload is None
+                           else job_main_s.rw_job_start_limit)
             else:
                 _print_val(_("Limit past start time"), in_object, "%dh%02d",
                            (obj.start_limit / 60, obj.start_limit % 60),
-                           True if workload is None \
-                                else job_main_s.rw_job_start_limit)
+                           True if workload is None
+                           else job_main_s.rw_job_start_limit)
 
-        in_object, obj = sql_hierarchy.get(sql_session, p,
-                          job_loadenv if workload is None else job_loadenv_s,
-                          workload)
+        in_object, obj = sql_hierarchy.get(
+            sql_session,
+            p,
+            job_loadenv if workload is None else job_loadenv_s,
+            workload)
         if obj is not None:
             _print_val(_("Load user env"), in_object, "%s", bool(obj.loadenv),
                        True if workload is None else job_main_s.rw_job_loadenv)
@@ -433,8 +510,8 @@ def cat(sql_session, current_cwd, arguments, workload=None):
             else:
                 query = session.query(job_environment_s)
                 query = query.filter_by(job_id=p.id[i])
-                query = query.filter(
-                               job_environment_s.workload_date == workload)
+                query = query.filter(job_environment_s.workload_date ==
+                                     workload)
                 query = query.order_by(desc(job_environment_s.position))
             for je in query.all():
                 env_list.insert(0, je.env_id)
@@ -466,11 +543,12 @@ def cat(sql_session, current_cwd, arguments, workload=None):
             query = query.order_by(desc(constraint_file_s.exist))
 
         for f, h in query.all():
-            _print_val(_("Constraint file"), True,
-                       _("%s must %sexist on %s(%s)"),
-                        (f.filename, '' if f.exist else _('NOT '),
-                         h.hostname, h.portnum),
-                   True if workload is None else job_main_s.rw_constraint_file)
+            _print_val(
+                _("Constraint file"),
+                True,
+                _("%s must %sexist on %s"),
+                (f.filename, '' if f.exist else _('NOT '), str(h)),
+                True if workload is None else job_main_s.rw_constraint_file)
 
         if workload is None:
             query = session.query(link)
@@ -481,8 +559,8 @@ def cat(sql_session, current_cwd, arguments, workload=None):
             destination = path.id2path(sql_session, lnk.job_id_destination,
                                        workload)
             _print_val(_("Link"), True, _("%s must be %s"),
-                       (destination, status_utils.status2string(
-                                             lnk.required_status)),
+                       (destination,
+                        status_utils.status2string(lnk.required_status)),
                        True if workload is None else job_main_s.rw_links)
 
         sql_session.close_session(session)
