@@ -33,6 +33,9 @@ from tables.job_main_s import job_main_s
 from tables.hosts import hosts
 from tables.job_host import job_host
 from tables.job_host_s import job_host_s
+from tables.clusters import clusters
+from tables.job_cluster import job_cluster
+from tables.job_cluster_s import job_cluster_s
 from tables.environments import environments
 from tables.environments_s import environments_s
 from tables.job_environment import job_environment
@@ -74,8 +77,6 @@ from tables.constraint_file import constraint_file
 from tables.constraint_file_s import constraint_file_s
 from tables.link import link
 from tables.link_s import link_s
-from tables.calendars import calendars
-from tables.calendars_s import calendars_s
 from help import print_trim
 
 
@@ -90,6 +91,7 @@ Options:
   --type=C              limit the search to jobs (if C is `j') or jobsets (`d')
   --enable=True|False   search for Enabled (True) or Disabled (False) objects.
   --host=PATTERN        search by host name.
+  --cluster=PATTERN     search by cluster name.
   --calendar=PATTERN    search for jobs and jobsets with the specified
                         calendar.
   --start=TIME          search by start time (HH:MM).
@@ -361,40 +363,41 @@ def find(sql_session, current_cwd, arguments, workload=None):
     """
     try:
         optlist, args = getopt.getopt(arguments, "h",
-                        [
-                            "name=",
-                            "id=",
-                            "type=",
-                            "enable=",
-                            "host=",
-                            "calendar=",
-                            "start=",
-                            "command=",
-                            "parameter=",
-                            "return=",
-                            "user=",
-                            "stdout=",
-                            "stderr=",
-                            "detach=",
-                            "manual=",
-                            "manual-cmd=",
-                            "cgroup=",
-                            "duration=",
-                            "retries=",
-                            "retries-int=",
-                            "limit=",
-                            "user-env=",
-                            "has-env=",
-                            "env=",
-                            "file=",
-                            "description=",
-                            "link=",
-                            "success=",
-                            "failed=",
-                            "avg-duration=",
-                            "day=",
-                            "help"
-                        ])
+                                      [
+                                          "name=",
+                                          "id=",
+                                          "type=",
+                                          "enable=",
+                                          "host=",
+                                          "cluster=",
+                                          "calendar=",
+                                          "start=",
+                                          "command=",
+                                          "parameter=",
+                                          "return=",
+                                          "user=",
+                                          "stdout=",
+                                          "stderr=",
+                                          "detach=",
+                                          "manual=",
+                                          "manual-cmd=",
+                                          "cgroup=",
+                                          "duration=",
+                                          "retries=",
+                                          "retries-int=",
+                                          "limit=",
+                                          "user-env=",
+                                          "has-env=",
+                                          "env=",
+                                          "file=",
+                                          "description=",
+                                          "link=",
+                                          "success=",
+                                          "failed=",
+                                          "avg-duration=",
+                                          "day=",
+                                          "help"
+                                      ])
     except getopt.GetoptError, err:
         sys.stderr.write(_("find: ") + str(err) + "\n")
         return 1
@@ -435,7 +438,7 @@ def find(sql_session, current_cwd, arguments, workload=None):
             except:
                 sql_session.cancel_session(session)
                 sys.stderr.write(
-                        _("find: type must be `j' or `d' (--type=%s)\n") % a)
+                    _("find: type must be `j' or `d' (--type=%s)\n") % a)
                 return 1
 
         elif o == "--enable":
@@ -454,6 +457,16 @@ def find(sql_session, current_cwd, arguments, workload=None):
                 query = query.filter(job_host_s.host_id == hosts.id)
                 query = query.filter(job_host_s.workload_date == workload)
 
+        elif o == "--cluster":
+            query = _filter_pattern(query, clusters.name, a)
+            if workload is None:
+                query = query.filter(job_cluster.job_id == job_main.id)
+                query = query.filter(job_cluster.cluster_id == clusters.id)
+            else:
+                query = query.filter(job_cluster_s.job_id == job_main_s.id)
+                query = query.filter(job_cluster_s.cluster_id == clusters.id)
+                query = query.filter(job_cluster_s.workload_date == workload)
+
         elif o == "--calendar":
             if workload is None:
                 query = _filter_pattern(query, calendars.name, a)
@@ -496,15 +509,17 @@ Should be `H:M' or `H:M AM/PM'\n") % a)
         elif o == "--return":
             try:
                 if workload is None:
-                    query = _filter_numeric(query,
-                                        job_success_return_code.success_ret,
-                                        a)
+                    query = _filter_numeric(
+                        query,
+                        job_success_return_code.success_ret,
+                        a)
                     query = query.filter(job_success_return_code.job_id ==
                                          job_main.id)
                 else:
-                    query = _filter_numeric(query,
-                                        job_success_return_code_s.success_ret,
-                                        a)
+                    query = _filter_numeric(
+                        query,
+                        job_success_return_code_s.success_ret,
+                        a)
                     query = query.filter(job_success_return_code_s.job_id ==
                                          job_main_s.id)
                     query = query.filter(
@@ -549,10 +564,10 @@ Should be `H:M' or `H:M AM/PM'\n") % a)
             else:
                 query = _filter_pattern(query,
                                         job_control_group_s.control_group, a)
-                query = query.filter(
-                                job_control_group_s.job_id == job_main_s.id)
-                query = query.filter(
-                                job_control_group_s.workload_date == workload)
+                query = query.filter(job_control_group_s.job_id ==
+                                     job_main_s.id)
+                query = query.filter(job_control_group_s.workload_date ==
+                                     workload)
 
         elif o == "--duration":
             try:
@@ -595,15 +610,17 @@ Should be `H:M' or `H:M AM/PM'\n") % a)
         elif o == "--retries-int":
             try:
                 if workload is None:
-                    query = _filter_minutes(query,
-                                        job_retries_interval.retries_interval,
-                                        a)
+                    query = _filter_minutes(
+                        query,
+                        job_retries_interval.retries_interval,
+                        a)
                     query = query.filter(job_retries_interval.job_id ==
                                          job_main.id)
                 else:
-                    query = _filter_minutes(query,
-                                     job_retries_interval_s.retries_interval,
-                                     a)
+                    query = _filter_minutes(
+                        query,
+                        job_retries_interval_s.retries_interval,
+                        a)
                     query = query.filter(job_retries_interval_s.job_id ==
                                          job_main_s.id)
                     query = query.filter(
@@ -669,9 +686,9 @@ Should be `H:M' or `H:M AM/PM'\n") % a)
                 query = _filter_pattern(query,
                                         job_manual_command_s.manual_command, a)
                 query = query.filter(job_manual_command_s.job_id ==
-                                        job_main_s.id)
+                                     job_main_s.id)
                 query = query.filter(job_manual_command_s.workload_date ==
-                                        workload)
+                                     workload)
 
         elif o == "--has-env":
             if workload is None:
@@ -755,8 +772,10 @@ Should be `H:M' or `H:M AM/PM'\n") % a)
         elif o == "--avg-duration":
             try:
                 query = query.filter(job_stat.num_success > 0)
-                query = _filter_minutes(query,
-                            job_stat.total_duration / job_stat.num_success, a)
+                query = _filter_minutes(
+                    query,
+                    job_stat.total_duration / job_stat.num_success,
+                    a)
                 if workload is None:
                     query = query.filter(job_stat.job_id == job_main.id)
                 else:
@@ -783,8 +802,8 @@ Should be `H:M' or `H:M AM/PM'\n") % a)
             cals = list()
             for c in q.all():
                 err, idx, cal = cmd_cal.calcomp.str2cal(c.formula, y)
-                if (err == cmd_cal.calcomp.CAL_NOERROR and
-                    cal.calmatch(d, m, y) == cmd_cal.calcomp.CAL_NOERROR):
+                if err == cmd_cal.calcomp.CAL_NOERROR and \
+                   cal.calmatch(d, m, y) == cmd_cal.calcomp.CAL_NOERROR:
                     cals.append(c.id)
             if workload is None:
                 query = query.filter(job_main.cal_id.in_(cals))
