@@ -81,7 +81,14 @@ def ln(sql_session, current_cwd, arguments):
     """
     try:
         optlist, args = getopt.getopt(arguments, "cdfrwh",
-               ["completed", "done", "failed", "running", "waiting", "help"])
+                                      [
+                                          "completed",
+                                          "done",
+                                          "failed",
+                                          "running",
+                                          "waiting",
+                                          "help"
+                                      ])
     except getopt.GetoptError, err:
         sys.stderr.write(_("ln: ") + str(err) + "\n")
         return 1
@@ -153,8 +160,8 @@ def ln(sql_session, current_cwd, arguments):
             continue
         if p.id[-1] in source:
             sys.stderr.write(
-         _("ln: error: `%s' cannot be linked to one of its parent (`%s')\n") %
-                (source, p))
+            _("ln: error: `%s' cannot be linked to one of its parent (`%s')\n")
+                % (source, p))
             error = True
             continue
         # Check that the destination job exists
