@@ -28,11 +28,12 @@ import path
 import path_cal
 import status_utils
 import sql_hierarchy
+import cluster_utils
+import host_utils
 from tables.job_main import job_main
-from tables.job_host import job_host
-from tables.hosts import hosts
+from tables.job_cluster import job_cluster
 from tables.job_main_s import job_main_s
-from tables.job_host_s import job_host_s
+from tables.job_cluster_s import job_cluster_s
 from help import print_trim
 
 
@@ -48,7 +49,7 @@ Options:
       - or d  whether the job/jobset is enabled or disabled
       HHhMM   start time
       CAL     calendar name
-      HOST    host name and TCP port (if not the default port 2006)
+      HOST    cluster or host name and TCP port (if not the default port 2006)
       NAME    job/jobset name
       [--S--> JOB/JOBSET]
               link (the specified JOB/JOBSET must have the status S for the
@@ -94,6 +95,7 @@ def _print1job(session, job, parent_id, long_listing, workload=None):
     if not long_listing:
         print job.name
         return
+    # Start
     if job.start_time >= 0:
         h = job.start_time / 100
         m = job.start_time % 100
@@ -111,19 +113,29 @@ def _print1job(session, job, parent_id, long_listing, workload=None):
                 break
         else:
             h = m = 0
-    if job.job_host is not None:
-        host_id = job.job_host.host_id
+    # host/cluster
+    if job.job_cluster is not None:
+        cluster = cluster_utils.get_cluster_by_id(session,
+                                                  job.job_cluster.cluster_id)
+        host_str = 'c(' + cluster.name + ')'
+    elif job.job_host is not None:
+        host = host_utils.get_host_by_id(session, job.job_host.host_id)
+        host_str = str(host)
     else:
-        in_object, obj = sql_hierarchy.get_by_id(session, parent_id,
-                                  job_host if workload is None else job_host_s,
-                                  workload)
-        host_id = obj.host_id
-    host_obj = session.query(hosts).filter_by(id=host_id).one()
-    if host_obj.portnum == "2006":
-        port = ""
-    else:
-        port = "/%s" % host_obj.portnum
-    host = host_obj.hostname
+        in_object, obj = sql_hierarchy.get_cluster_or_host_by_id(session,
+                                                                 parent_id,
+                                                                 workload)
+        if obj is None:
+            host_str = "None"
+        else:
+            if isinstance(obj, job_cluster) or isinstance(obj, job_cluster_s):
+                cluster = cluster_utils.get_cluster_by_id(session,
+                                                          obj.cluster_id)
+                host_str = 'c(' + cluster.name + ')'
+            else:
+                host = host_utils.get_host_by_id(session, obj.host_id)
+                host_str = str(host)
+    # calendar
     if job.cal_id == 0:
         for i in range(len(parent_id) - 2, -1, -1):
             if workload is None:
@@ -142,6 +154,7 @@ def _print1job(session, job, parent_id, long_listing, workload=None):
         cal_full_name = path_cal.PathCal(session, id=job.cal_id,
                                          workload=workload)
     cal_name = cal_full_name.path.rsplit('/')[-1]
+    # links
     num_links = len(job.links)
     if num_links == 0:
         link = ""
@@ -149,24 +162,25 @@ def _print1job(session, job, parent_id, long_listing, workload=None):
         link = "-----> ..."
     else:
         p = path.id2path(session, job.links[0].job_id_destination, workload)
-        link = "--%s--> %s" % (status_utils.status2char(
-                                                job.links[0].required_status),
-                             p)
+        link = "--%s--> %s" % (
+            status_utils.status2char(job.links[0].required_status),
+            p)
+    # print the result
     print "%(jobset)s%(enabled)s %(h)02dh%(m)02d %(cal)-13s %(host)-15s \
 %(name)s %(link)s " % \
-               {"jobset":   'j' if job.type == 0 else '-',
-                "enabled":  'd' if not job.enabled else '-',
-                "h":        h,
-                "m":        m,
-                "cal":      cal_name,
-                "host":     "%s%s" % (host, port),
-                "name":     job.name,
-                "link":     link}
+        {"jobset":   'j' if job.type == 0 else '-',
+         "enabled":  'd' if not job.enabled else '-',
+         "h":        h,
+         "m":        m,
+         "cal":      cal_name,
+         "host":     host_str,
+         "name":     job.name,
+         "link":     link}
 
 
 def _print_jobs(session, jobs, parent_id, long_listing, workload=None):
     """Print the given jobs."""
-    if config.ISATTY and not long_listing:
+    if config.ISATTY_STDOUT and not long_listing:
         m = reduce(_max, jobs, 0) + _INTERSPACE
         w = console_size.width
         n = w / m
