@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011, 2012 Herve Quatremain
+# Copyright (C) 2011-2013 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -56,6 +56,26 @@ Options:
                           If not set, same as the parent jobset.
   --stderr=FILE           command error file (stored on the Schedwi agent).
                           If not set, same as the parent jobset.
+  --detach=True|False     start the job in detach mode (True) or not (False).
+                          In detach mode, Schedwi will not wait for the
+                          completion of the job but immediately set the status
+                          of the job on whether the job has successfully
+                          started or not. The detach mode can be useful to
+                          start daemons, services or long running processes.
+                          If not set, same as the parent jobset.
+  --manual=True|False     ask confirmation (True) to operators to start the
+                          job or not (False).  If not set, same as the parent
+                          jobset.
+  --manual-cmd=COMMAND    for manual jobs, command/script to run to alert
+                          operators that a job is waiting for a start
+                          confirmation. The following environment variables
+                          are set and can be used in the command/script:
+                          SCHEDWI_TEMPLATE (the path to a text file that
+                          contains the message to send to operators),
+                          SCHEDWI_JOBPATH, SCHEDWI_JOBID, SCHEDWI_START_TIME,
+                          SCHEDWI_START_TIME_EPOCH, SCHEDWI_TIME_LIMIT and
+                          SCHEDWI_TIME_LIMIT_EPOCH.
+                          If not set, same as the parent jobset.
   --duration=MINUTES      maximum number of minutes for the job to
                           complete once running.  If not set, same as the
                           parent jobset.
