@@ -69,7 +69,7 @@ def rm_recursive(session, p, force, recursive, cwd=None):
         return 1
     # Job
     if job.type == 1:
-        if force == False:
+        if force is False:
             if links:
                 print _("The following jobs/jobsets have links to this job:")
                 print "\n".join(map(lambda i: i.path, links))
@@ -85,10 +85,10 @@ def rm_recursive(session, p, force, recursive, cwd=None):
         session.delete(job)
         return 0
     # Jobset
-    if recursive == False:
+    if recursive is False:
         sys.stderr.write(_("rm: cannot remove `%s': Is a jobset\n") % p)
         return 1
-    if force == False:
+    if force is False:
         if links:
             print _("The following jobs/jobsets have links to this jobset:")
             print "\n".join(map(lambda i: i.path, links))
@@ -116,7 +116,7 @@ def rm_recursive(session, p, force, recursive, cwd=None):
         return 1
     if empty:
         try:
-            idx = cwd.id.index(p.id[-1])
+            cwd.id.index(p.id[-1])
         except:
             pass
         else:
@@ -157,12 +157,12 @@ def rm(sql_session, current_cwd, arguments):
         for arg in args:
             paths.extend(path.get_paths(sql_session, arg, current_cwd))
     else:
-        if force == False:
+        if force is False:
             sys.stderr.write(_("rm: missing job or jobset name\n"))
             return 1
         return 0
     if not paths:
-        if force == False:
+        if force is False:
             sys.stderr.write(_("rm: no such job or jobset\n"))
             return 1
         return 0
