@@ -42,9 +42,11 @@ from tables.job_command import job_command
 from tables.job_arguments import job_arguments
 from tables.job_environment import job_environment
 from tables.job_host import job_host
+from tables.job_cluster import job_cluster
 from tables.constraint_file import constraint_file
 import path_cal
 import host_utils
+import cluster_utils
 import environments_utils
 
 
@@ -56,8 +58,11 @@ Change a job or jobset parameter.
 Options:
   --enable=True|False     enable (True) or disable (False) the job/jobset.
   --host=HOSTNAME[:PORT]  host on which the job/jobset must be running.
-  --delhost               remove the hostname so this is the one from the
-                          parent jobset which is going to be used instead.
+  --delhost               remove the hostname so that the one from the
+                          parent jobset is going to be used instead.
+  --cluster=NAME          cluster on which the job/jobset must be running.
+  --delcluster            remove the cluster so that the one from the
+                          parent jobset is going to be used instead.
   --calendar=CAL_NAME     calendar name.
   --delcalendar           remove the calendar so the job/jobset will use the
                           same calendar as its parent jobset.
@@ -155,54 +160,56 @@ def parse_args(argv):
 
     """
     optlist, args = getopt.getopt(argv, "h",
-            [
-                "enable=",
-                "host=",
-                "delhost",
-                "calendar=",
-                "delcalendar",
-                "start=",
-                "delstart",
-                "command=",
-                "delcommand",
-                "parameter=",
-                "delparameter",
-                "noparameter",
-                "return=",
-                "delreturn",
-                "user=",
-                "deluser",
-                "stdout=",
-                "delstdout",
-                "stderr=",
-                "delstderr",
-                "detach=",
-                "deldetach",
-                "manual=",
-                "delmanual",
-                "manual-cmd=",
-                "delmanual-cmd",
-                "cgroup=",
-                "delcgroup",
-                "duration=",
-                "delduration",
-                "retries=",
-                "delretries",
-                "retries-int=",
-                "delretries-int",
-                "limit=",
-                "dellimit",
-                "user-env=",
-                "deluser-env",
-                "addenv=",
-                "delenv=",
-                "enableenv",
-                "disableenv",
-                "description=",
-                "addfile=",
-                "delfile=",
-                "help"
-            ])
+                                  [
+                                      "enable=",
+                                      "host=",
+                                      "delhost",
+                                      "cluster=",
+                                      "delcluster",
+                                      "calendar=",
+                                      "delcalendar",
+                                      "start=",
+                                      "delstart",
+                                      "command=",
+                                      "delcommand",
+                                      "parameter=",
+                                      "delparameter",
+                                      "noparameter",
+                                      "return=",
+                                      "delreturn",
+                                      "user=",
+                                      "deluser",
+                                      "stdout=",
+                                      "delstdout",
+                                      "stderr=",
+                                      "delstderr",
+                                      "detach=",
+                                      "deldetach",
+                                      "manual=",
+                                      "delmanual",
+                                      "manual-cmd=",
+                                      "delmanual-cmd",
+                                      "cgroup=",
+                                      "delcgroup",
+                                      "duration=",
+                                      "delduration",
+                                      "retries=",
+                                      "delretries",
+                                      "retries-int=",
+                                      "delretries-int",
+                                      "limit=",
+                                      "dellimit",
+                                      "user-env=",
+                                      "deluser-env",
+                                      "addenv=",
+                                      "delenv=",
+                                      "enableenv",
+                                      "disableenv",
+                                      "description=",
+                                      "addfile=",
+                                      "delfile=",
+                                      "help"
+                                  ])
     return (optlist, args)
 
 
@@ -227,6 +234,7 @@ def set(session, current_cwd, current_cwd_cal, job, opts):
                 job.enabled = 1
             else:
                 job.enabled = 0
+
         elif o == "--host":
             try:
                 host = host_utils.name2host(session, a)
@@ -238,10 +246,35 @@ def set(session, current_cwd, current_cwd_cal, job, opts):
 name (--host=%s)\n") % a)
                 return 1
             job.job_host = job_host(host.id)
+            del job.job_cluster
 
         elif o == "--delhost":
             del job.job_host
 
+        elif o == "--cluster":
+            try:
+                cluster = cluster_utils.name2cluster(session, a)
+            except NoResultFound:
+                sys.stderr.write(_("No such cluster (--cluster=%s)\n") % a)
+                return 1
+            except MultipleResultsFound:
+                sys.stderr.write(_("More than one cluster match the provided \
+name (--cluster=%s)\n") % a)
+                return 1
+            job.job_cluster = job_cluster(cluster.id)
+            del job.job_host
+            if cluster_utils.num_host_in_cluster(session, cluster.id) == 0:
+                sys.stderr.write(_("Warning: the given cluster (--cluster=%s) \
+does not contain any host.\n") % a)
+                sys.stderr.write(_("When this %s will start, the parent \
+host/cluster details are then going to be used instead.\n") %
+                                 (_("jobset") if job.type == 0 else _("job")))
+                sys.stderr.write(_("You may however add hosts to this cluster \
+which the `clust set --host=HOSTNAME[:PORT] \"%s\"' command.\n") % a)
+
+        elif o == "--delcluster":
+            del job.job_cluster
+
         elif o == "--calendar":
             c = path_cal.PathCal(session, path=a, cwd=current_cwd_cal)
             if not c:
@@ -292,8 +325,8 @@ name (--host=%s)\n") % a)
                 if v < 0 or v > 255:
                     raise ValueError
             except:
-                sys.stderr.write(
-                  _("Wrong value for --return.  Must be between 0 and 255\n"))
+                sys.stderr.write(_(
+                    "Wrong value for --return.  Must be between 0 and 255\n"))
                 return 1
             job.job_success_return_code = job_success_return_code(v)
 
@@ -475,8 +508,9 @@ name %s (--addfile=%s)\n") % (h, a))
                 try:
                     h, filename = a.split(',', 1)
                 except:
-                    sys.stderr.write(
-                    _("Wrong format for --delfile.  Must be <host>,<file>\n"))
+                    sys.stderr.write(_(
+                        "Wrong format for --delfile.  Must be <host>,<file>\n")
+                        )
                     return 1
             try:
                 host = host_utils.name2host(session, h)
