@@ -43,11 +43,13 @@ from tables.job_command_s import job_command_s
 from tables.job_arguments_s import job_arguments_s
 from tables.job_environment_s import job_environment_s
 from tables.job_host_s import job_host_s
+from tables.job_cluster_s import job_cluster_s
 from tables.commands import commands
 from tables.constraint_file_s import constraint_file_s
 from tables.job_status import job_status
 import cmd_wl.start
 import host_utils
+import cluster_utils
 import environments_utils
 import status_utils
 import parse_config
@@ -60,8 +62,11 @@ Change a job or jobset parameter.
 
 Options:
   --host=HOSTNAME[:PORT]  host on which the job/jobset must be running.
-  --delhost               remove the hostname so this is the one from the
-                          parent jobset which is going to be used instead.
+  --delhost               remove the hostname so that the one from the
+                          parent jobset is going to be used instead.
+  --cluster=NAME          cluster on which the job/jobset must be running.
+  --delcluster            remove the cluster so that the one from the
+                          parent jobset is going to be used instead.
   --start=TIME            start time of the job (HH:MM).
   --delstart              use the start time of the parent jobset.
   --command=COMMAND       command to run (if set to `-', no command will be
@@ -164,52 +169,54 @@ def parse_args(argv):
 
     """
     optlist, args = getopt.getopt(argv, "h",
-            [
-                "host=",
-                "delhost",
-                "start=",
-                "delstart",
-                "command=",
-                "delcommand",
-                "parameter=",
-                "delparameter",
-                "noparameter",
-                "return=",
-                "delreturn",
-                "user=",
-                "deluser",
-                "stdout=",
-                "delstdout",
-                "stderr=",
-                "delstderr",
-                "detach",
-                "deldetach",
-                "manual=",
-                "delmanual",
-                "manual-cmd=",
-                "delmanual-cmd",
-                "cgroup=",
-                "delcgroup",
-                "duration=",
-                "delduration",
-                "retries=",
-                "delretries",
-                "retries-int=",
-                "delretries-int",
-                "limit=",
-                "dellimit",
-                "user-env=",
-                "deluser-env",
-                "addenv=",
-                "delenv=",
-                "enableenv",
-                "disableenv",
-                "description=",
-                "addfile=",
-                "delfile=",
-                "status=",
-                "help"
-            ])
+                                  [
+                                      "host=",
+                                      "delhost",
+                                      "cluster=",
+                                      "delcluster",
+                                      "start=",
+                                      "delstart",
+                                      "command=",
+                                      "delcommand",
+                                      "parameter=",
+                                      "delparameter",
+                                      "noparameter",
+                                      "return=",
+                                      "delreturn",
+                                      "user=",
+                                      "deluser",
+                                      "stdout=",
+                                      "delstdout",
+                                      "stderr=",
+                                      "delstderr",
+                                      "detach",
+                                      "deldetach",
+                                      "manual=",
+                                      "delmanual",
+                                      "manual-cmd=",
+                                      "delmanual-cmd",
+                                      "cgroup=",
+                                      "delcgroup",
+                                      "duration=",
+                                      "delduration",
+                                      "retries=",
+                                      "delretries",
+                                      "retries-int=",
+                                      "delretries-int",
+                                      "limit=",
+                                      "dellimit",
+                                      "user-env=",
+                                      "deluser-env",
+                                      "addenv=",
+                                      "delenv=",
+                                      "enableenv",
+                                      "disableenv",
+                                      "description=",
+                                      "addfile=",
+                                      "delfile=",
+                                      "status=",
+                                      "help"
+                                  ])
     return (optlist, args)
 
 
@@ -240,10 +247,35 @@ def set(session, job, opts, workload):
 name (--host=%s)\n") % a)
                 return 1
             job.job_host = job_host_s(host.id, workload)
+            del job.job_cluster
 
         elif o == "--delhost":
             del job.job_host
 
+        elif o == "--cluster":
+            try:
+                cluster = cluster_utils.name2cluster(session, a)
+            except NoResultFound:
+                sys.stderr.write(_("No such cluster (--cluster=%s)\n") % a)
+                return 1
+            except MultipleResultsFound:
+                sys.stderr.write(_("More than one cluster match the provided \
+name (--cluster=%s)\n") % a)
+                return 1
+            job.job_cluster = job_cluster_s(cluster.id, workload)
+            del job.job_host
+            if cluster_utils.num_host_in_cluster(session, cluster.id) == 0:
+                sys.stderr.write(_("Warning: the given cluster (--cluster=%s) \
+does not contain any host.\n") % a)
+                sys.stderr.write(_("When this %s will start, the parent \
+host/cluster details are then going to be used instead.\n") %
+                                 (_("jobset") if job.type == 0 else _("job")))
+                sys.stderr.write(_("You may however add hosts to this cluster \
+which the `clust set --host=HOSTNAME[:PORT] \"%s\"' command.\n") % a)
+
+        elif o == "--delcluster":
+            del job.job_cluster
+
         elif o == "--start":
             for fmt in ("%H:%M", "%I:%M %p", "%Hh%M", "%Ih%M %p"):
                 try:
@@ -284,8 +316,8 @@ name (--host=%s)\n") % a)
                 if v < 0 or v > 255:
                     raise ValueError
             except:
-                sys.stderr.write(
-                  _("Wrong value for --return.  Must be between 0 and 255\n"))
+                sys.stderr.write(_(
+                    "Wrong value for --return.  Must be between 0 and 255\n"))
                 return 1
             job.job_success_return_code = job_success_return_code_s(v,
                                                                     workload)
@@ -467,8 +499,9 @@ name %s (--addfile=%s)\n") % (h, a))
                 try:
                     h, filename = a.split(',', 1)
                 except:
-                    sys.stderr.write(
-                    _("Wrong format for --delfile.  Must be <host>,<file>\n"))
+                    sys.stderr.write(_(
+                        "Wrong format for --delfile.  Must be <host>,<file>\n")
+                        )
                     return 1
             try:
                 host = host_utils.name2host(session, h)
