@@ -83,9 +83,10 @@ def _get_status(session, id, options, workload):
 
     if not options['show_status']:
         return (s, '', '', '')
-    return (s, status_utils.status2color(s),
-               space + status_utils.status2char(s) + space,
-               colors.NORMAL)
+    return (s,
+            status_utils.status2color(s),
+            space + status_utils.status2char(s) + space,
+            colors.NORMAL)
 
 
 def _print_job(session, job, id, last, prefix, counters, options, workload):
@@ -104,16 +105,22 @@ def _print_job(session, job, id, last, prefix, counters, options, workload):
         counters['status'][s] += 1
         if not options['indentation']:
             print "%s%s%s%s%s" % (status_color, status_char, status_reset,
-                                   name, type_char)
+                                  name, type_char)
         else:
             if last:
                 print "%s`--%s%s%s%s%s" % (prefix,
-                                   status_color, status_char, status_reset,
-                                   name, type_char)
+                                           status_color,
+                                           status_char,
+                                           status_reset,
+                                           name,
+                                           type_char)
             else:
                 print "%s|--%s%s%s%s%s" % (prefix,
-                                   status_color, status_char, status_reset,
-                                   name, type_char)
+                                           status_color,
+                                           status_char,
+                                           status_reset,
+                                           name,
+                                           type_char)
 
 
 def _print_recur(session, id, prefix, level, counters, options, workload):
@@ -184,7 +191,7 @@ def tree(sql_session, current_cwd, arguments, workload=None):
                'sort_by_jobsets': False,
                'indentation': True,
                'show_status': True
-              }
+               }
     for o, a in optlist:
         if o == "-d":
             options['only_dir'] = True
@@ -245,21 +252,25 @@ def tree(sql_session, current_cwd, arguments, workload=None):
             print _("\n%d jobsets, %d jobs") % (counters["jobsets"],
                                                 counters["jobs"])
         if workload is not None:
-            print "%4d %s%s%s" % (counters['status'][status_utils.WAITING],
-                            status_utils.status2color(status_utils.WAITING),
-                            status_utils.status2string(status_utils.WAITING),
-                            colors.NORMAL)
-            print "%4d %s%s%s" % (counters['status'][status_utils.RUNNING],
-                            status_utils.status2color(status_utils.RUNNING),
-                            status_utils.status2string(status_utils.RUNNING),
-                            colors.NORMAL)
-            print "%4d %s%s%s" % (counters['status'][status_utils.COMPLETED],
-                            status_utils.status2color(status_utils.COMPLETED),
-                            status_utils.status2string(status_utils.COMPLETED),
-                            colors.NORMAL)
-            print "%4d %s%s%s" % (counters['status'][status_utils.FAILED],
-                            status_utils.status2color(status_utils.FAILED),
-                            status_utils.status2string(status_utils.FAILED),
-                            colors.NORMAL)
+            print "%4d %s%s%s" % (
+                counters['status'][status_utils.WAITING],
+                status_utils.status2color(status_utils.WAITING),
+                status_utils.status2string(status_utils.WAITING),
+                colors.NORMAL)
+            print "%4d %s%s%s" % (
+                counters['status'][status_utils.RUNNING],
+                status_utils.status2color(status_utils.RUNNING),
+                status_utils.status2string(status_utils.RUNNING),
+                colors.NORMAL)
+            print "%4d %s%s%s" % (
+                counters['status'][status_utils.COMPLETED],
+                status_utils.status2color(status_utils.COMPLETED),
+                status_utils.status2string(status_utils.COMPLETED),
+                colors.NORMAL)
+            print "%4d %s%s%s" % (
+                counters['status'][status_utils.FAILED],
+                status_utils.status2color(status_utils.FAILED),
+                status_utils.status2string(status_utils.FAILED),
+                colors.NORMAL)
     sql_session.close_session(session)
     return 0
