@@ -90,6 +90,6 @@ def start(sql_session, current_cwd, arguments, workload):
     for p in paths:
         start_id(session, p.id[-1], workload)
     sql_session.close_session(session)
-    if config.ISATTY:
+    if config.ISATTY_STDOUT:
         print _("This may take up to a minute to be taken into account")
     return 0
