@@ -29,7 +29,7 @@ import simple_queries_wl
 
 def usage():
     """Print a usage message on STDOUT."""
-    print_trim(_("""Usage: wl [-h] [WORKLOAD]
+    print_trim(_("""Usage: wl [WORKLOAD]
     List all workloads, or, if WORKLOAD is given, enter the specified workload
     (all subsequent commands will apply to this workload objects - type `exit'
     to leave this mode).
@@ -71,7 +71,7 @@ def parse(sql_session, w):
     # Check that the workload exists
     if not simple_queries_wl.does_workload_exist(sql_session, workload):
         return (None, _("`%s': no such workload") % w)
-    return  (workload, "")
+    return (workload, "")
 
 
 def _print_workload(lst):
