@@ -33,8 +33,8 @@ def parse_jobid(jobid_str, sql_session, only_dir=False):
 
     @param jobid_str:
                 the job ID to look for in the database.  It can be a simple
-                ID (for example 12) or a workload_ID string (for example
-                20130104_12)
+                ID (12 for instance) or a workload_ID string (20130104_12
+                for instance)
     @param sql_session:
                 SQLAlchemy session (it can be an opened session)
     @param only_dir:
@@ -245,7 +245,7 @@ def get_paths(sql_session, path, cwd=None, only_dir=False, workload=None):
         res.append(Path(sql_session, id=job, workload=workload))
 
     # No job/jobset found.  Check if it is a SCHEDWI_JOBID string
-    # (20130101_12 for example)
+    # (20130101_12 for instance)
     if not res:
         try:
             w, i = parse_jobid(path, session, only_dir)
