@@ -26,11 +26,11 @@ from sqlalchemy import create_engine
 class SqlSession(object):
 
     _dialects = {
-            'mssql': ['pyodbc', 'mxodbc', 'pymssql', 'zxjdbc', 'adodbapi'],
-            'pgsql': ['psycopg2', 'pypostgresql', 'pg8000', 'zxjdbc'],
-            'mysql': ['mysqldb', 'oursql', 'pymysql', 'mysqlconnector',
-                      'gaerdbms', 'pyodbc', 'zxjdbc'],
-            'sqlite': ['pysqlite']}
+        'mssql': ['pyodbc', 'mxodbc', 'pymssql', 'zxjdbc', 'adodbapi'],
+        'pgsql': ['psycopg2', 'pypostgresql', 'pg8000', 'zxjdbc'],
+        'mysql': ['mysqldb', 'oursql', 'pymysql', 'mysqlconnector',
+                  'gaerdbms', 'pyodbc', 'zxjdbc'],
+        'sqlite': ['pysqlite']}
 
     def __init__(self,
                  drivername='sqlite3',
@@ -40,8 +40,10 @@ class SqlSession(object):
                  dbname='schedwidb',
                  dbdir='.'):
         drivername = drivername.lower()
+        connect_args = dict()
         urls = list()
         if drivername == 'sqlite3' or drivername == 'sqlite':
+            connect_args = {'timeout': 15}
             urls.append('sqlite:///' + dbdir + '/' + dbname)
             for dialect in self._dialects['sqlite']:
                 urls.append('sqlite+' + dialect + ':///' +
@@ -55,8 +57,8 @@ class SqlSession(object):
                 urls.append('postgresql://' + path)
                 for dialect in self._dialects['pgsql']:
                     urls.append('postgresql+' + dialect + '://' + path)
-            elif drivername == 'mssql' or drivername == 'msql' or \
-                 drivername == 'freetds':
+            elif (drivername == 'mssql' or drivername == 'msql' or
+                  drivername == 'freetds'):
                 urls.append('mssql://' + path)
                 for dialect in self._dialects['mssql']:
                     urls.append('mssql+' + dialect + '://' + path)
@@ -70,7 +72,7 @@ class SqlSession(object):
         for url in urls:
             try:
 #               self.engine = create_engine(url, echo=True)
-                self.engine = create_engine(url)
+                self.engine = create_engine(url, connect_args=connect_args)
             except Exception as error:
                 pass
             else:
