@@ -18,7 +18,7 @@
 
 from sqlalchemy.schema import Column
 from sqlalchemy.types import Integer, Text, String
-from sqlalchemy.orm import relation, backref
+from sqlalchemy.orm import relation
 
 from base import Base, convert2unicode
 
