@@ -25,9 +25,10 @@ from base import Base
 class host_environment_s(Base):
     __tablename__ = 'host_environment_s'
     __table_args__ = (
-            ForeignKeyConstraint(['env_id', 'workload_date'],
-                        ['environments_s.id', 'environments_s.workload_date']),
-            {})
+        ForeignKeyConstraint(
+            ['env_id', 'workload_date'],
+            ['environments_s.id', 'environments_s.workload_date']),
+        {})
 
     host_id = Column(Integer, ForeignKey('hosts.id'), primary_key=True)
     env_id = Column(Integer, primary_key=True)
