@@ -18,7 +18,7 @@
 
 from sqlalchemy.schema import Column
 from sqlalchemy.types import Integer, Text, String
-from sqlalchemy.orm import relation, backref
+from sqlalchemy.orm import relation
 
 from base import Base, convert2unicode
 
@@ -50,8 +50,17 @@ class hosts(Base):
         self.sslcert = convert2unicode(sslcert)
         self.description = convert2unicode(description)
 
-    def __str__(self):
+    def __unicode__(self):
         if self.hostname.find(':') >= 0:
-            return "[%s]:%s" % (self.hostname, self.portnum)
+            if self.portnum == "2006":
+                return "[%s]" % self.hostname
+            else:
+                return "[%s]:%s" % (self.hostname, self.portnum)
         else:
-            return "%s:%s" % (self.hostname, self.portnum)
+            if self.portnum == "2006":
+                return "%s" % self.hostname
+            else:
+                return "%s:%s" % (self.hostname, self.portnum)
+
+    def __str__(self):
+        return unicode(self).encode('utf-8')
