@@ -25,12 +25,13 @@ from base import Base
 class job_environment_s(Base):
     __tablename__ = 'job_environment_s'
     __table_args__ = (
-            ForeignKeyConstraint(['job_id', 'workload_date'],
-                                ['job_main_s.id', 'job_main_s.workload_date']),
-            ForeignKeyConstraint(
-                        ['env_id', 'workload_date'],
-                        ['environments_s.id', 'environments_s.workload_date']),
-            {})
+        ForeignKeyConstraint(
+            ['job_id', 'workload_date'],
+            ['job_main_s.id', 'job_main_s.workload_date']),
+        ForeignKeyConstraint(
+            ['env_id', 'workload_date'],
+            ['environments_s.id', 'environments_s.workload_date']),
+        {})
 
     job_id = Column(Integer, primary_key=True)
     env_id = Column(Integer, primary_key=True)
