@@ -26,6 +26,7 @@ from muntjac.event.shortcut_action import KeyCode
 
 from web.boxes import DeleteBox, QuestionBox, BoxCloseListener
 from web.jobwindow import JobWindow
+from web.forcewindow import ForceWindow
 from web.autorefresh import AutoRefresh
 from path import id2path
 from simple_queries_job import sql_get_job, sql_get_children
@@ -78,11 +79,12 @@ def _delete_job(obj, item_id):
     @param item_id:
                     container item ID to remove.
     """
-    d = DeleteBox(obj, _("Delete"),
-                  _('Are you sure you want to permanently delete "%s"?') % \
-                                obj.get_name(item_id),
-  _('If you delete a jobset, all its content will also be permanently lost.') \
-                          if obj.is_jobset(item_id) else \
+    d = DeleteBox(obj,
+                  _("Delete"),
+                  _('Are you sure you want to permanently delete "%s"?') %
+                  obj.get_name(item_id),
+                  _('If you delete a jobset, all its content will also be \
+                     permanently lost.') if obj.is_jobset(item_id) else
                   _('If you delete a job, it will be permanently lost.'))
     d.addListener(DeleteConfirmed(obj, item_id))
 
@@ -138,55 +140,56 @@ def _start_stop_job(obj, item_id, do_start):
     if do_start:
         if s.status == status_utils.RUNNING:
             n = Notification(
-                        _('"%s" is already running') % obj.get_name(item_id),
-                        Notification.TYPE_WARNING_MESSAGE)
+                _('"%s" is already running') % obj.get_name(item_id),
+                Notification.TYPE_WARNING_MESSAGE)
             n.setDelayMsec(3000)
             obj.getWindow().showNotification(n)
+            return
         else:
-            d = QuestionBox(obj, _("Start"),
-                            _('Are you sure you want to start "%s" now?') % \
-                                obj.get_name(item_id))
+            d = QuestionBox(obj,
+                            _("Start"),
+                            _('Are you sure you want to start "%s" now?') %
+                            obj.get_name(item_id))
     else:
         if s.status != status_utils.RUNNING:
             n = Notification(
-                        _('"%s" is already stopped') % obj.get_name(item_id),
-                        Notification.TYPE_WARNING_MESSAGE)
+                _('"%s" is already stopped') % obj.get_name(item_id),
+                Notification.TYPE_WARNING_MESSAGE)
             n.setDelayMsec(3000)
             obj.getWindow().showNotification(n)
+            return
         else:
-            d = QuestionBox(obj, _("Stop"),
-                            _('Are you sure you want to stop "%s" now?') % \
-                                obj.get_name(item_id),
-                _("The job will be killed.") if not obj.is_jobset(item_id) \
-                else _("All the children will be killed recursively."))
+            d = QuestionBox(obj,
+                            _("Stop"),
+                            _('Are you sure you want to stop "%s" now?') %
+                            obj.get_name(item_id),
+                            _("The job will be killed.")
+                            if not obj.is_jobset(item_id) else
+                            _("All the children will be killed recursively."))
     d.addListener(StartStopConfirmed(obj, item_id, do_start))
 
 
 class GenericContextMenu(IHandler):
 
-    # Possible actions
-    _ACTION_EDIT = Action(_('Edit...'), ThemeResource('icons/edit.png'))
-    _ACTION_CUT = Action(_('Cut'), ThemeResource('icons/cut.png'))
-    _ACTION_COPY = Action(_('Copy'), ThemeResource('icons/copy.png'))
-    _ACTION_DELETE = Action(_('Delete'), ThemeResource('icons/delete.png'))
-    _ACTION_ADD = Action(_('Add...'), ThemeResource('icons/add.png'))
-    _ACTION_START = Action(_('Force Start'), ThemeResource('icons/start.png'))
-    _ACTION_STOP = Action(_('Stop'), ThemeResource('icons/stop.png'))
-
     def __init__(self):
         super(GenericContextMenu, self).__init__()
+        # Possible actions
+        self._ACTION_EDIT = Action(_('Edit...'),
+                                   ThemeResource('icons/edit.png'))
+        self._ACTION_CUT = Action(_('Cut'), ThemeResource('icons/cut.png'))
+        self._ACTION_COPY = Action(_('Copy'), ThemeResource('icons/copy.png'))
+        self._ACTION_DELETE = Action(_('Delete'),
+                                     ThemeResource('icons/delete.png'))
+        self._ACTION_ADD = Action(_('Add...'), ThemeResource('icons/add.png'))
+        self._ACTION_START = Action(_('Force Start'),
+                                    ThemeResource('icons/start.png'))
+        self._ACTION_STOP = Action(_('Stop'), ThemeResource('icons/stop.png'))
+        self._ACTION_FORCE = Action(_('Set Status'),
+                                    ThemeResource('icons/force.png'))
 
 
 class CutCopyPasteMenu(GenericContextMenu):
 
-    # Actions for the context menu
-    _ACTION_PASTE = Action(_('Paste Into Jobset'),
-                           ThemeResource('icons/paste.png'))
-    _ACTION_NEWJOB = Action(_('Create New Job...'),
-                            ThemeResource('icons/job-new.png'))
-    _ACTION_NEWJOBSET = Action(_('Create New Jobset...'),
-                               ThemeResource('icons/jobset-new.png'))
-
     def __init__(self, obj, sql_session, workload=None):
         """Initialize the object.
 
@@ -202,6 +205,13 @@ class CutCopyPasteMenu(GenericContextMenu):
         self._sql_session = sql_session
         self._workload = workload
         self._c = obj
+        # Actions for the context menu
+        self._ACTION_PASTE = Action(_('Paste Into Jobset'),
+                                    ThemeResource('icons/paste.png'))
+        self._ACTION_NEWJOB = Action(_('Create New Job...'),
+                                     ThemeResource('icons/job-new.png'))
+        self._ACTION_NEWJOBSET = Action(_('Create New Jobset...'),
+                                        ThemeResource('icons/jobset-new.png'))
 
     def handleAction(self, a, sender, target):
         global _SELECTED_ID, _IS_CUT
@@ -242,10 +252,14 @@ class CutCopyPasteMenu(GenericContextMenu):
         elif a.getCaption() == self._ACTION_START.getCaption():
             self.do_start(target)
 
-        # stop
+        # Stop
         elif a.getCaption() == self._ACTION_STOP.getCaption():
             self.do_stop(target)
 
+        # Set status
+        elif a.getCaption() == self._ACTION_FORCE.getCaption():
+            self.do_force(target)
+
     def _get_name(self, target):
         """Get a new name for the job/jobset to copy or move.
 
@@ -260,7 +274,7 @@ class CutCopyPasteMenu(GenericContextMenu):
         p = id2path(self._sql_session, target, self._workload)
         if _SELECTED_ID in p.id:
             self._c.getWindow().showNotification(
-                _("Cannot move a jobset into itself") if _IS_CUT else \
+                _("Cannot move a jobset into itself") if _IS_CUT else
                 _("Cannot copy a jobset into itself"),
                 _("<br/>The destination jobset is inside the source jobset."),
                 Notification.TYPE_ERROR_MESSAGE)
@@ -274,9 +288,9 @@ class CutCopyPasteMenu(GenericContextMenu):
         except:
             self._sql_session.close_session(session)
             self._c.getWindow().showNotification(
-                                _("Cannot get the source job details"),
-                                _("<br/>Maybe someone else just removed it."),
-                                Notification.TYPE_ERROR_MESSAGE)
+                _("Cannot get the source job details"),
+                _("<br/>Maybe someone else just removed it."),
+                Notification.TYPE_ERROR_MESSAGE)
             return None
         name = job.name
 
@@ -310,9 +324,9 @@ class CutCopyPasteMenu(GenericContextMenu):
         except:
             self._sql_session.close_session(session)
             self._c.getWindow().showNotification(
-                                _("Cannot get the source job details"),
-                                _("<br/>Maybe someone else just removed it."),
-                                Notification.TYPE_ERROR_MESSAGE)
+                _("Cannot get the source job details"),
+                _("<br/>Maybe someone else just removed it."),
+                Notification.TYPE_ERROR_MESSAGE)
         else:
             src_job.parent = target
             src_job.name = name
@@ -335,9 +349,9 @@ class CutCopyPasteMenu(GenericContextMenu):
         except:
             self._sql_session.close_session(session)
             self._c.getWindow().showNotification(
-                                _("Cannot get the source job details"),
-                                _("<br/>Maybe someone else just removed it."),
-                                Notification.TYPE_ERROR_MESSAGE)
+                _("Cannot get the source job details"),
+                _("<br/>Maybe someone else just removed it."),
+                Notification.TYPE_ERROR_MESSAGE)
             return
         # Destination jobset
         try:
@@ -345,9 +359,9 @@ class CutCopyPasteMenu(GenericContextMenu):
         except:
             self._sql_session.close_session(session)
             self._c.getWindow().showNotification(
-                                _("Cannot get the destination jobset details"),
-                                _("<br/>Maybe someone else just removed it."),
-                                Notification.TYPE_ERROR_MESSAGE)
+                _("Cannot get the destination jobset details"),
+                _("<br/>Maybe someone else just removed it."),
+                Notification.TYPE_ERROR_MESSAGE)
             return
         self._sql_session.close_session(session)
 
@@ -407,6 +421,15 @@ class CutCopyPasteMenu(GenericContextMenu):
         """
         _start_stop_job(self._c, target, False)
 
+    def do_force(self, target):
+        """Edit the job or jobset.
+
+        @param target:
+                database ID of the job or jobset to edit.
+        """
+        ForceWindow(self._c, target, self._c.getWindow(),
+                    self._sql_session, self._workload)
+
     def do_cut(self, target):
         """Cut the job or jobset.
 
@@ -481,15 +504,15 @@ class CutCopyPasteMenuJobsetTree(CutCopyPasteMenu):
     _ROOT_JOBSET_ID = 1
 
     def __init__(self, jobsetTree):
-        super(CutCopyPasteMenuJobsetTree, self).__init__(jobsetTree,
-                                                       jobsetTree._sql_session,
-                                                       jobsetTree._workload)
+        super(CutCopyPasteMenuJobsetTree, self).__init__(
+            jobsetTree, jobsetTree._sql_session, jobsetTree._workload)
 
     def getActions(self, target, sender):
         if target is not None:
             if self._workload is not None:
                 return [self._ACTION_EDIT,
-                        self._ACTION_START, self._ACTION_STOP]
+                        self._ACTION_START, self._ACTION_STOP,
+                        self._ACTION_FORCE]
             if target == self._ROOT_JOBSET_ID:
                 # Root Jobset
                 return [self._ACTION_EDIT, self._ACTION_PASTE]
@@ -515,7 +538,8 @@ class CutCopyPasteMenuJobTable(CutCopyPasteMenu):
                 return None
 
         if self._workload is not None:
-            return [self._ACTION_EDIT, self._ACTION_START, self._ACTION_STOP]
+            return [self._ACTION_EDIT,
+                    self._ACTION_START, self._ACTION_STOP, self._ACTION_FORCE]
         if self._c.is_jobset(target):
             # Jobset
             return [self._ACTION_EDIT, self._ACTION_CUT,
