@@ -42,6 +42,7 @@ import path
 import simple_queries_job
 from web.selectenvwidget import SelectEnvGroup
 from web.autorefresh import AutoRefresh
+import web.selecthostwidget
 
 
 class EnvWidget(VerticalLayout):
@@ -59,7 +60,7 @@ class EnvWidget(VerticalLayout):
                     environment group" popup.
         @param host_widget:
                     the L{web.jobwidgets.Host} object (used to retrieve the
-                    host id associated with the job/jobset
+                    host id associated with the job/jobset)
         @param sql_session:
                     SQLAlchemy session.
         @param workload:
@@ -551,10 +552,10 @@ class AddEnvGroup(IClickListener):
             c = self._c.get_datasource()
             if c.containsId(item_id):
                 self._c._application_window.showNotification(
-                            _("Environment group already in job/jobset"),
-                            _("<br/>The selected environment group is already \
-                             associated with the job/jobset."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                    _("Environment group already in job/jobset"),
+                    _("<br/>The selected environment group is already \
+                       associated with the job/jobset."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 return
             item = c.addItem(item_id)
             # try clause to get around a strange exception in
@@ -721,7 +722,7 @@ class ShowVariablesPopup(IClickListener):
                 if self._c._workload is None:
                     query = session.query(environment_var)
                     query = query.filter(environment_var.env_id ==
-                                        envgroup['env_id'])
+                                         envgroup['env_id'])
                     query = query.order_by(desc(environment_var.position))
                 else:
                     query = session.query(environment_var_s)
@@ -736,47 +737,48 @@ class ShowVariablesPopup(IClickListener):
                         'env_key': ev.env_key,
                         'env_value': ev.env_value,
                         'alreadydefined': (True
-                                          if ev.env_key in already_defined
-                                          else False)})
+                                           if ev.env_key in already_defined
+                                           else False)})
                     already_defined.append(ev.env_key)
             env_vars[job_id] = lst
 
+        lst = list()
         # Get the host associated with this job/jobset to retrieve the
         # environment variables defined at its level
-        host_id = self._c._host_widget.get_selected()
-        if self._c._workload is None:
-            query = session.query(host_environment)
-            query = query.filter(host_environment.host_id == host_id)
-            query = query.order_by(desc(host_environment.position))
-        else:
-            query = session.query(host_environment_s)
-            query = query.filter(host_environment_s.host_id == host_id)
-            query = query.filter(host_environment_s.workload_date ==
-                                 self._c._workload)
-            query = query.order_by(desc(host_environment_s.position))
-        lst = list()
-        for he in query.all():
-            e = environments_utils.get_env(session, he.env_id,
-                                           self._c._workload)
+        type_obj, host_id = self._c._host_widget.get_selected()
+        if type_obj == web.selecthostwidget._HOST_TYPE:
             if self._c._workload is None:
-                query = session.query(environment_var)
-                query = query.filter(environment_var.env_id == he.env_id)
-                query = query.order_by(desc(environment_var.position))
+                query = session.query(host_environment)
+                query = query.filter(host_environment.host_id == host_id)
+                query = query.order_by(desc(host_environment.position))
             else:
-                query = session.query(environment_var_s)
-                query = query.filter(environment_var_s.env_id == he.env_id)
-                query = query.filter(environment_var_s.workload_date ==
+                query = session.query(host_environment_s)
+                query = query.filter(host_environment_s.host_id == host_id)
+                query = query.filter(host_environment_s.workload_date ==
                                      self._c._workload)
-                query = query.order_by(desc(environment_var_s.position))
-            for ev in query.all():
-                lst.append({
-                    'name': e.name,
-                    'env_key': ev.env_key,
-                    'env_value': ev.env_value,
-                    'alreadydefined': (True
-                                      if ev.env_key in already_defined
-                                      else False)})
-                already_defined.append(ev.env_key)
+                query = query.order_by(desc(host_environment_s.position))
+            for he in query.all():
+                e = environments_utils.get_env(session, he.env_id,
+                                               self._c._workload)
+                if self._c._workload is None:
+                    query = session.query(environment_var)
+                    query = query.filter(environment_var.env_id == he.env_id)
+                    query = query.order_by(desc(environment_var.position))
+                else:
+                    query = session.query(environment_var_s)
+                    query = query.filter(environment_var_s.env_id == he.env_id)
+                    query = query.filter(environment_var_s.workload_date ==
+                                         self._c._workload)
+                    query = query.order_by(desc(environment_var_s.position))
+                for ev in query.all():
+                    lst.append({
+                        'name': e.name,
+                        'env_key': ev.env_key,
+                        'env_value': ev.env_value,
+                        'alreadydefined': (True
+                                           if ev.env_key in already_defined
+                                           else False)})
+                    already_defined.append(ev.env_key)
 
         # Build the result XHTML string
         result_str = ''
@@ -833,12 +835,11 @@ class ShowVariablesPopup(IClickListener):
                         result_str += '<li class="envwidgetenvdefined">'
                     else:
                         result_str += '<li>'
-                    result_str += (env_vars[job_id][j]['env_key'].encode(
-                                                                'utf-8') +
-                                   '=' +
-                                   env_vars[job_id][j]['env_value'].encode(
-                                                                'utf-8') +
-                                   '</li>')
+                    result_str += (
+                        env_vars[job_id][j]['env_key'].encode('utf-8') +
+                        '=' +
+                        env_vars[job_id][j]['env_value'].encode('utf-8') +
+                        '</li>')
                 else:
                     result_str += '</ol>'
         self._c._sql_session.close_session(session)
