@@ -283,9 +283,9 @@ class EnvWindow(Window, IClickListener):
                 for v in e.environment_var:
                     item = c.addItem(c.generateId())
                     item.getItemProperty('env_key').setValue(
-                                                 v.env_key.encode('utf-8'))
+                        v.env_key.encode('utf-8'))
                     item.getItemProperty('env_value').setValue(
-                                                 v.env_value.encode('utf-8'))
+                        v.env_value.encode('utf-8'))
             self._sql_session.close_session(session)
         self._var_table.setContainerDataSource(c)
         self._var_table.setVisibleColumns(['env_key', 'env_value'])
@@ -300,8 +300,8 @@ class EnvWindow(Window, IClickListener):
                                                   self._workload):
             item = c.addItem(e.id)
             item.getItemProperty('env').setValue(e.name.encode('utf-8'))
-            item.getItemProperty('descr').setValue(e.description.encode(
-                                                                    'utf-8'))
+            item.getItemProperty('descr').setValue(
+                e.description.encode('utf-8'))
         self._list_group.setContainerDataSource(c)
         self._list_group.setItemCaptionPropertyId('env')
 
@@ -516,9 +516,9 @@ class EnvWindow(Window, IClickListener):
             except:
                 self._sql_session.close_session(session)
                 self._main_window.showNotification(
-                        _("Cannot get the selected environment group details"),
-                        _("<br/>Maybe someone else just removed it."),
-                        Notification.TYPE_ERROR_MESSAGE)
+                    _("Cannot get the selected environment group details"),
+                    _("<br/>Maybe someone else just removed it."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 self.refresh_env_group()
                 return
             e.environment_var = new_list
@@ -611,7 +611,7 @@ class DeleteConfirmed(BoxCloseListener):
             session.delete(e)
         self._c._sql_session.close_session(session)
         self._c.refresh_env_group(
-                            self._c.get_previous_env_group_id(self._env_id))
+            self._c.get_previous_env_group_id(self._env_id))
 
 
 class EnvGroupDel(IClickListener):
@@ -642,15 +642,18 @@ class EnvGroupDel(IClickListener):
             if cmd_env.whatuses.is_used(session, e, self._c._workload):
                 self._c._sql_session.close_session(session)
                 self._c._main_window.showNotification(
-                        _("This environment is still in used"),
-                        _("<br/>%s is in used somewhere else and cannot be \
-                        deleted from the database.") % str(name),
-                        Notification.TYPE_ERROR_MESSAGE)
+                    _("This environment is still in used"),
+                    _("<br/>%s is in used somewhere else and cannot be \
+                       deleted from the database.") % str(name),
+                    Notification.TYPE_ERROR_MESSAGE)
             else:
                 self._c._sql_session.close_session(session)
-                d = DeleteBox(self._c._main_window, _("Delete"),
-                  _('Are you sure you want to delete this environment group?'),
-                  _('%s and all its variables will be destroyed.') % str(name))
+                d = DeleteBox(self._c._main_window,
+                              _("Delete"),
+                              _('Are you sure you want to delete this \
+                                 environment group?'),
+                              _('%s and all its variables will be destroyed.')
+                              % str(name))
                 d.addListener(DeleteConfirmed(self._c, selected_item_id))
 
 
@@ -677,9 +680,9 @@ class EnvGroupWhere(IClickListener):
             except:
                 self._c._sql_session.close_session(session)
                 self._c._main_window.showNotification(
-                        _("Cannot get the selected environment group details"),
-                        _("<br/>Maybe someone else just removed it."),
-                        Notification.TYPE_ERROR_MESSAGE)
+                    _("Cannot get the selected environment group details"),
+                    _("<br/>Maybe someone else just removed it."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 self._c.refresh_env_group()
                 return
             # The items (job, jobset, host) that are using this environment
@@ -691,9 +694,8 @@ class EnvGroupWhere(IClickListener):
             self._c._sql_session.close_session(session)
             if not self._gathered:
                 self._c._main_window.showNotification(
-                        _("Not used"),
-                        _("<br/>%s is not used.") % \
-                                str(e.name.encode('utf-8')))
+                    _("Not used"),
+                    _("<br/>%s is not used.") % str(e.name.encode('utf-8')))
             else:
                 WhereWindow(self._c, self._gathered)
 
@@ -781,10 +783,10 @@ class NewEnvGroup(IClickListener):
             name = self._name.getValue().strip()
             if not name:
                 self._c._main_window.showNotification(
-                            _("Name is empty"),
-                            _("<br/>The environment group name cannot \
-                                  be empty or contain just spaces."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                    _("Name is empty"),
+                    _("<br/>The environment group name cannot \
+                       be empty or contain just spaces."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 self._name.focus()
                 return
             descr = self._descr.getValue().strip()
@@ -929,8 +931,10 @@ class VarMenu(GenericContextMenu):
             r = self._c.get_item_details_var(target)
             VarPopup(self._c, params=r)
         elif a.getCaption() == self._ACTION_DELETE.getCaption():
-            d = DeleteBox(self._c._main_window, _("Delete"),
-                  _('Are you sure you want to remove this variable?'))
+            d = DeleteBox(
+                self._c._main_window,
+                _("Delete"),
+                _('Are you sure you want to remove this variable?'))
             d.addListener(DeleteVarConfirmed(self._c, target))
 
 
@@ -1031,8 +1035,9 @@ class VarDel(IClickListener):
         self._c = env_window_obj
 
     def buttonClick(self, event):
-        d = DeleteBox(self._c._main_window, _("Delete"),
-                  _('Are you sure you want to remove this variable?'))
+        d = DeleteBox(self._c._main_window,
+                      _("Delete"),
+                      _('Are you sure you want to remove this variable?'))
         d.addListener(DeleteVarConfirmed(self._c, self._c.get_selected_var()))
 
 
@@ -1185,10 +1190,11 @@ class VarPopup(IClickListener):
         self._key.focus()
         self._key.setWidth('100%')
         self._key.setImmediate(True)
-        self._key.addValidator(RegexpValidator('^[A-Za-z_][A-Za-z_0-9]*$',
-                      True,
-                      _("Only letters, numbers, and underscores, and \
-                       beginning with a letter or underscore")))
+        self._key.addValidator(RegexpValidator(
+            '^[A-Za-z_][A-Za-z_0-9]*$',
+            True,
+            _("Only letters, numbers, and underscores, and \
+               beginning with a letter or underscore")))
         h.addComponent(self._key)
         h.setExpandRatio(self._key, 1.0)
 
@@ -1226,11 +1232,11 @@ class VarPopup(IClickListener):
         name = self._key.getValue().strip()
         if not name or not re.match('^[A-Za-z_][A-Za-z_0-9]*$', name):
             self._c._main_window.showNotification(
-               _("Invalid variable name"),
-               _("<br/>The variable name cannot be empty. It must contain \
-                only <br/>letters, numbers, and underscores, and begin with a \
-                <br/>letter or underscore."),
-               Notification.TYPE_ERROR_MESSAGE)
+                _("Invalid variable name"),
+                _("<br/>The variable name cannot be empty. It must contain \
+                   only <br/>letters, numbers, and underscores, and begin \
+                   with a <br/>letter or underscore."),
+                Notification.TYPE_ERROR_MESSAGE)
             self._key.focus()
             return
         val = self._val.getValue()
