@@ -189,8 +189,8 @@ class Files(HorizontalLayout, JobTableListener):
                 query = query.order_by(desc(constraint_file.exist))
             else:
                 query = session.query(constraint_file_s, hosts)
-                query = query.filter(
-                             constraint_file_s.workload_date == self._workload)
+                query = query.filter(constraint_file_s.workload_date ==
+                                     self._workload)
                 query = query.filter_by(job_id=job)
                 query = query.filter(constraint_file_s.host_id == hosts.id)
                 query = query.order_by(desc(constraint_file_s.exist))
@@ -200,11 +200,10 @@ class Files(HorizontalLayout, JobTableListener):
                 item = self._container.addItem(i)
                 name = f.filename.encode('utf-8')
                 item.getItemProperty('name').setValue(name)
-                s = '%s (%s/SSL)' if h.sslenable else '%s (%s)'
-                item.getItemProperty('host').setValue(s %
-                    (h.hostname.encode('utf-8'), h.portnum.encode('utf-8')))
+                s = '%s (SSL)' if h.sslenable else '%s'
+                item.getItemProperty('host').setValue(s % str(h))
                 item.getItemProperty('must').setValue(
-                       _('exist') if f.exist else _('not exist'))
+                    _('exist') if f.exist else _('not exist'))
                 item.getItemProperty('must_bool').setValue(f.exist)
                 item.getItemProperty('host_id').setValue(long(f.host_id))
     #            if f.filename == filename and f.host_id == host_id:
@@ -284,9 +283,11 @@ class DeleteBtHandler(IClickListener):
         AutoRefresh.reset()
         if self._c._selected is not None:
             r = self._c.getFileDetails(self._c._selected)
-            d = DeleteBox(self._c, _("Delete"),
-                  _('Are you sure you want to delete this constraint?'),
-                  _('%s on %s') % (r['name'], str(r['host'])))
+            d = DeleteBox(
+                self._c,
+                _("Delete"),
+                _('Are you sure you want to delete this constraint?'),
+                _('%s on %s') % (r['name'], str(r['host'])))
             d.addListener(DeleteConfirmed(self._c, r['host_id'], r['name']))
 
 
@@ -317,9 +318,9 @@ class DeleteConfirmed(BoxCloseListener):
         except:
             self._c._sql_session.close_session(session)
             self._c.getWindow().showNotification(
-                            _("Cannot get the selected job details"),
-                            _("<br/>Maybe someone else just removed it."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                _("Cannot get the selected job details"),
+                _("<br/>Maybe someone else just removed it."),
+                Notification.TYPE_ERROR_MESSAGE)
             return
         # Retrieve the constraint file to remove
         for cf in job.constraint_file:
@@ -367,9 +368,11 @@ class FileContextMenu(GenericContextMenu):
 
         elif a.getCaption() == self._ACTION_DELETE.getCaption():
             r = self._c.getFileDetails(target)
-            d = DeleteBox(self._c, _("Delete"),
-                  _('Are you sure you want to delete this constraint?'),
-                  _('%s on %s') % (r['name'], str(r['host'])))
+            d = DeleteBox(
+                self._c,
+                _("Delete"),
+                _('Are you sure you want to delete this constraint?'),
+                _('%s on %s') % (r['name'], str(r['host'])))
             d.addListener(DeleteConfirmed(self._c, r['host_id'], r['name']))
 
 
@@ -418,9 +421,9 @@ class WindowFiles(IClickListener):
         v.addComponent(t)
 
         s = SelectHost(self._c._sql_session, _("Host:"),
-                        _("Host on which the file will be monitored"),
-                        params['host_id'] if params and 'host_id' in params \
-                                          else None)
+                       _("Host on which the file will be monitored"),
+                       params['host_id'] if params and 'host_id' in params
+                       else None)
         self._host = s
         s.setWidth('100%')
         v.addComponent(s)
@@ -430,8 +433,8 @@ class WindowFiles(IClickListener):
         if params is None:
             o.select(_(self._must_labels[0]))
         elif 'must_bool' in params:
-            o.select(_(self._must_labels[0]) if params['must_bool'] \
-                                             else _(self._must_labels[1]))
+            o.select(_(self._must_labels[0]) if params['must_bool']
+                     else _(self._must_labels[1]))
         self._must = o
         v.addComponent(o)
 
@@ -459,10 +462,10 @@ class WindowFiles(IClickListener):
             name = self._name.getValue().strip()
             if not name:
                 self._c.getWindow().showNotification(
-                            _("File/Directory name is empty"),
-                            _("<br/>The file or directory name cannot \
-                                  be empty or contain just spaces."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                    _("File/Directory name is empty"),
+                    _("<br/>The file or directory name cannot \
+                       be empty or contain just spaces."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 self._name.focus()
                 return
             host_id = self._host.getValue()
@@ -478,9 +481,9 @@ class WindowFiles(IClickListener):
             except:
                 self._c._sql_session.close_session(session)
                 self._c.getWindow().showNotification(
-                            _("Cannot get the selected job details"),
-                            _("<br/>Maybe someone else just removed it."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                    _("Cannot get the selected job details"),
+                    _("<br/>Maybe someone else just removed it."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 # Close the window
                 self._c.getWindow().removeWindow(self._w)
                 return
