@@ -42,6 +42,7 @@ from tables.environments_s import environments_s
 from tables.environment_var import environment_var
 from tables.environment_var_s import environment_var_s
 from tables.hosts import hosts
+from tables.clusters import clusters
 from tables.job_arguments import job_arguments
 from tables.job_arguments_s import job_arguments_s
 from tables.job_command import job_command
@@ -68,10 +69,12 @@ class Find(HorizontalLayout, IClickListener):
     """Find text entry widget."""
 
     _LIMIT = 20
-    _NONE, _JOB, _ENV, _HOST, _CAL = 0, 1, 2, 3, 4
-    (_JOB_FILE, _ENV_NAME, _ENV_DESCR,
-    _ENV_VAR_NAME, _ENV_VAR_VAL, _CAL_NAME, _CAL_DESCR, _HOST_NAME,
-    _HOST_PORT, _HOST_DESCR) = (1, 2, 3, 4, 5, 6, 7, 8, 9, 10)
+    _NONE, _JOB, _ENV, _HOST, _CAL, _CLUSTER = 0, 1, 2, 3, 4, 5
+    (_JOB_FILE,
+     _ENV_NAME, _ENV_DESCR, _ENV_VAR_NAME, _ENV_VAR_VAL,
+     _CAL_NAME, _CAL_DESCR,
+     _HOST_NAME, _HOST_PORT, _HOST_DESCR,
+     _CLUSTER_NAME, _CLUSTER_DESCR) = (1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12)
 
     def __init__(self, parent_widget, application, sql_session, workload=None):
         """Create the widget.
@@ -139,7 +142,7 @@ class Find(HorizontalLayout, IClickListener):
         @param obj_name:
                     the name of the found item.
         @param obj_type:
-                    type of object (_NONE, _JOB, _ENV, _HOST or _CAL)
+                    type of object (_NONE, _JOB, _ENV, _HOST, _CAL or _CLUSTER)
         @param attr:
                     in the object, field name in which the item has been found
                     (_ENV_NAME, _ENV_DESCR, _ENV_VAR_NAME, _ENV_VAR_VAL,
@@ -192,13 +195,13 @@ class Find(HorizontalLayout, IClickListener):
                     obj_id=0,
                     attr=web.jobwindow.FOCUS_NAME)
             q = session.query(job_main).filter(
-                                            job_main.description.ilike(tofind))
+                job_main.description.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 self._add_result(
                     container=c,
                     label=_("Job description") if j.type
-                                               else _("Jobset description"),
+                    else _("Jobset description"),
                     obj_name=unicode(path.id2path(session, j.id,
                                      self._workload)),
                     obj_type=self._JOB,
@@ -215,7 +218,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_DESCR)
             # job_command
             q = session.query(job_command).filter(
-                                            job_command.command.ilike(tofind))
+                job_command.command.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 job = simple_queries_job.sql_get_job(session, j.job_id,
@@ -223,7 +226,7 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Job command") if job.type
-                                           else _("Jobset command"),
+                    else _("Jobset command"),
                     obj_name=unicode(path.id2path(session, j.job_id,
                                                   self._workload)),
                     obj_type=self._JOB,
@@ -241,7 +244,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_CMD)
             # job_manual_command
             q = session.query(job_manual_command).filter(
-                              job_manual_command.manual_command.ilike(tofind))
+                job_manual_command.manual_command.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 job = simple_queries_job.sql_get_job(session, j.job_id,
@@ -266,7 +269,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_MANUALCMD)
             # job_arguments
             q = session.query(job_arguments).filter(
-                                        job_arguments.argument.ilike(tofind))
+                job_arguments.argument.ilike(tofind))
             list_ids = list()
             i = 0
             for j in q.limit(self._LIMIT):
@@ -276,7 +279,7 @@ class Find(HorizontalLayout, IClickListener):
                     self._add_result(
                         container=c,
                         label=_("Job command arg") if job.type
-                                                 else _("Jobset command arg"),
+                        else _("Jobset command arg"),
                         obj_name=unicode(path.id2path(session, j.job_id,
                                                       self._workload)),
                         obj_type=self._JOB,
@@ -295,7 +298,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_ARG)
             # job_file_out
             q = session.query(job_file_out).filter(
-                                           job_file_out.file_out.ilike(tofind))
+                job_file_out.file_out.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 job = simple_queries_job.sql_get_job(session, j.job_id,
@@ -303,7 +306,7 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Job output file") if job.type
-                                               else _("Jobset output file"),
+                    else _("Jobset output file"),
                     obj_name=unicode(path.id2path(session, j.job_id,
                                                   self._workload)),
                     obj_type=self._JOB,
@@ -321,7 +324,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_OUT)
             # job_file_err
             q = session.query(job_file_err).filter(
-                                           job_file_err.file_err.ilike(tofind))
+                job_file_err.file_err.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 job = simple_queries_job.sql_get_job(session, j.job_id,
@@ -329,7 +332,7 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Job error file") if job.type
-                                              else _("Jobset error file"),
+                    else _("Jobset error file"),
                     obj_name=unicode(path.id2path(session, j.job_id,
                                                   self._workload)),
                     obj_type=self._JOB,
@@ -347,7 +350,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_ERR)
             # job_control_group
             q = session.query(job_control_group).filter(
-                               job_control_group.control_group.ilike(tofind))
+                job_control_group.control_group.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 job = simple_queries_job.sql_get_job(session, j.job_id,
@@ -355,7 +358,7 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Job Control Group") if job.type
-                                             else _("Jobset Control Group"),
+                    else _("Jobset Control Group"),
                     obj_name=unicode(path.id2path(session, j.job_id,
                                                   self._workload)),
                     obj_type=self._JOB,
@@ -373,7 +376,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_CGROUP)
             # job_username
             q = session.query(job_username).filter(
-                                           job_username.username.ilike(tofind))
+                job_username.username.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 job = simple_queries_job.sql_get_job(session, j.job_id,
@@ -398,7 +401,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_USER)
             # constraint_file
             q = session.query(constraint_file).filter(
-                                        constraint_file.filename.ilike(tofind))
+                constraint_file.filename.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 job = simple_queries_job.sql_get_job(session, j.job_id,
@@ -406,7 +409,7 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Job constraint file") if job.type
-                                              else _("Jobset constraint file"),
+                    else _("Jobset constraint file"),
                     obj_name=unicode(path.id2path(session, j.job_id,
                                                   self._workload)),
                     obj_type=self._JOB,
@@ -424,7 +427,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=self._JOB_FILE)
             # environments
             q = session.query(environments).filter(
-                                               environments.name.ilike(tofind))
+                environments.name.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 self._add_result(
@@ -444,7 +447,7 @@ class Find(HorizontalLayout, IClickListener):
                     obj_id=0,
                     attr=self._ENV_NAME)
             q = session.query(environments).filter(
-                                        environments.description.ilike(tofind))
+                environments.description.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 self._add_result(
@@ -465,7 +468,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=self._ENV_DESCR)
             # environment_var
             q = session.query(environment_var).filter(
-                                        environment_var.env_key.ilike(tofind))
+                environment_var.env_key.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 e = environments_utils.get_env(session, j.env_id,
@@ -488,7 +491,7 @@ class Find(HorizontalLayout, IClickListener):
                     obj_id=0,
                     attr=self._ENV_VAR_NAME)
             q = session.query(environment_var).filter(
-                                       environment_var.env_value.ilike(tofind))
+                environment_var.env_value.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 e = environments_utils.get_env(session, j.env_id,
@@ -517,9 +520,11 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Calendar directory name") if j.entry_type
-                                                       else _("Calendar name"),
-                    obj_name=unicode(path_cal.PathCal(session, id=j.id,
-                                                     workload=self._workload)),
+                    else _("Calendar name"),
+                    obj_name=unicode(
+                        path_cal.PathCal(session,
+                                         id=j.id,
+                                         workload=self._workload)),
                     obj_type=self._CAL,
                     obj_id=j.id,
                     attr=self._CAL_NAME)
@@ -533,15 +538,17 @@ class Find(HorizontalLayout, IClickListener):
                     obj_id=0,
                     attr=self._CAL_NAME)
             q = session.query(calendars).filter(
-                                           calendars.description.ilike(tofind))
+                calendars.description.ilike(tofind))
             i = 0
             for j in q.limit(self._LIMIT):
                 self._add_result(
                     container=c,
                     label=_("Calendar directory description") if j.entry_type
-                                                else _("Calendar description"),
-                    obj_name=unicode(path_cal.PathCal(session, id=j.id,
-                                                    workload=self._workload)),
+                    else _("Calendar description"),
+                    obj_name=unicode(
+                        path_cal.PathCal(session,
+                                         id=j.id,
+                                         workload=self._workload)),
                     obj_type=self._CAL,
                     obj_id=j.id,
                     attr=self._CAL_DESCR)
@@ -578,14 +585,14 @@ class Find(HorizontalLayout, IClickListener):
                     obj_id=0,
                     attr=web.jobwindow.FOCUS_NAME)
             q = session.query(job_main_s).filter(
-                                          job_main_s.description.ilike(tofind))
+                job_main_s.description.ilike(tofind))
             q = q.filter(job_main_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
                 self._add_result(
                     container=c,
                     label=_("Job description") if j.type
-                                               else _("Jobset description"),
+                    else _("Jobset description"),
                     obj_name=unicode(path.id2path(session, j.id,
                                      self._workload)),
                     obj_type=self._JOB,
@@ -602,7 +609,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_DESCR)
             # job_command
             q = session.query(job_command_s).filter(
-                                           job_command_s.command.ilike(tofind))
+                job_command_s.command.ilike(tofind))
             q = q.filter(job_command_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -611,7 +618,7 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Job command") if job.type
-                                           else _("Jobset command"),
+                    else _("Jobset command"),
                     obj_name=unicode(path.id2path(session, j.job_id,
                                                   self._workload)),
                     obj_type=self._JOB,
@@ -629,7 +636,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_CMD)
             # job_manual_command
             q = session.query(job_manual_command_s).filter(
-                             job_manual_command_s.manual_command.ilike(tofind))
+                job_manual_command_s.manual_command.ilike(tofind))
             q = q.filter(job_manual_command_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -655,7 +662,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_MANUALCMD)
             # job_arguments
             q = session.query(job_arguments_s).filter(
-                                        job_arguments_s.argument.ilike(tofind))
+                job_arguments_s.argument.ilike(tofind))
             q = q.filter(job_arguments_s.workload_date == self._workload)
             list_ids = list()
             i = 0
@@ -666,7 +673,7 @@ class Find(HorizontalLayout, IClickListener):
                     self._add_result(
                         container=c,
                         label=_("Job command arg") if job.type
-                                                 else _("Jobset command arg"),
+                        else _("Jobset command arg"),
                         obj_name=unicode(path.id2path(session, j.job_id,
                                                       self._workload)),
                         obj_type=self._JOB,
@@ -685,7 +692,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_ARG)
             # job_file_out
             q = session.query(job_file_out_s).filter(
-                                         job_file_out_s.file_out.ilike(tofind))
+                job_file_out_s.file_out.ilike(tofind))
             q = q.filter(job_file_out_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -694,7 +701,7 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Job output file") if job.type
-                                               else _("Jobset output file"),
+                    else _("Jobset output file"),
                     obj_name=unicode(path.id2path(session, j.job_id,
                                                   self._workload)),
                     obj_type=self._JOB,
@@ -712,7 +719,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_OUT)
             # job_file_err
             q = session.query(job_file_err_s).filter(
-                                         job_file_err_s.file_err.ilike(tofind))
+                job_file_err_s.file_err.ilike(tofind))
             q = q.filter(job_file_err_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -721,7 +728,7 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Job error file") if job.type
-                                              else _("Jobset error file"),
+                    else _("Jobset error file"),
                     obj_name=unicode(path.id2path(session, j.job_id,
                                                   self._workload)),
                     obj_type=self._JOB,
@@ -739,7 +746,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_ERR)
             # job_control_group
             q = session.query(job_control_group_s).filter(
-                             job_control_group_s.control_group.ilike(tofind))
+                job_control_group_s.control_group.ilike(tofind))
             q = q.filter(job_control_group_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -748,7 +755,7 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Job Control Group") if job.type
-                                              else _("Jobset Control Group"),
+                    else _("Jobset Control Group"),
                     obj_name=unicode(path.id2path(session, j.job_id,
                                                   self._workload)),
                     obj_type=self._JOB,
@@ -766,7 +773,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_CGROUP)
             # job_username
             q = session.query(job_username_s).filter(
-                                         job_username_s.username.ilike(tofind))
+                job_username_s.username.ilike(tofind))
             q = q.filter(job_username_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -792,7 +799,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=web.jobwindow.FOCUS_USER)
             # constraint_file
             q = session.query(constraint_file_s).filter(
-                                      constraint_file_s.filename.ilike(tofind))
+                constraint_file_s.filename.ilike(tofind))
             q = q.filter(constraint_file_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -801,7 +808,7 @@ class Find(HorizontalLayout, IClickListener):
                 self._add_result(
                     container=c,
                     label=_("Job constraint file") if job.type
-                                              else _("Jobset constraint file"),
+                    else _("Jobset constraint file"),
                     obj_name=unicode(path.id2path(session, j.job_id,
                                                   self._workload)),
                     obj_type=self._JOB,
@@ -819,7 +826,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=self._JOB_FILE)
             # environments
             q = session.query(environments_s).filter(
-                                             environments_s.name.ilike(tofind))
+                environments_s.name.ilike(tofind))
             q = q.filter(environments_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -840,7 +847,7 @@ class Find(HorizontalLayout, IClickListener):
                     obj_id=0,
                     attr=self._ENV_NAME)
             q = session.query(environments_s).filter(
-                                      environments_s.description.ilike(tofind))
+                environments_s.description.ilike(tofind))
             q = q.filter(environments_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -862,7 +869,7 @@ class Find(HorizontalLayout, IClickListener):
                     attr=self._ENV_DESCR)
             # environment_var
             q = session.query(environment_var_s).filter(
-                                       environment_var_s.env_key.ilike(tofind))
+                environment_var_s.env_key.ilike(tofind))
             q = q.filter(environment_var_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -886,7 +893,7 @@ class Find(HorizontalLayout, IClickListener):
                     obj_id=0,
                     attr=self._ENV_VAR_NAME)
             q = session.query(environment_var_s).filter(
-                                     environment_var_s.env_value.ilike(tofind))
+                environment_var_s.env_value.ilike(tofind))
             q = q.filter(environment_var_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
@@ -911,16 +918,18 @@ class Find(HorizontalLayout, IClickListener):
                     attr=self._ENV_VAR_NAME)
             # calendars
             q = session.query(calendars_s).filter(
-                                                calendars_s.name.ilike(tofind))
+                calendars_s.name.ilike(tofind))
             q = q.filter(calendars_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
                 self._add_result(
                     container=c,
                     label=_("Calendar directory name") if j.entry_type
-                                                       else _("Calendar name"),
-                    obj_name=unicode(path_cal.PathCal(session, id=j.id,
-                                                     workload=self._workload)),
+                    else _("Calendar name"),
+                    obj_name=unicode(
+                        path_cal.PathCal(session,
+                                         id=j.id,
+                                         workload=self._workload)),
                     obj_type=self._CAL,
                     obj_id=j.id,
                     attr=self._CAL_NAME)
@@ -934,16 +943,18 @@ class Find(HorizontalLayout, IClickListener):
                     obj_id=0,
                     attr=self._CAL_NAME)
             q = session.query(calendars_s).filter(
-                                         calendars_s.description.ilike(tofind))
+                calendars_s.description.ilike(tofind))
             q = q.filter(calendars_s.workload_date == self._workload)
             i = 0
             for j in q.limit(self._LIMIT):
                 self._add_result(
                     container=c,
                     label=_("Calendar directory description") if j.entry_type
-                                                else _("Calendar description"),
-                    obj_name=unicode(path_cal.PathCal(session, id=j.id,
-                                                    workload=self._workload)),
+                    else _("Calendar description"),
+                    obj_name=unicode(
+                        path_cal.PathCal(session,
+                                         id=j.id,
+                                         workload=self._workload)),
                     obj_type=self._CAL,
                     obj_id=j.id,
                     attr=self._CAL_DESCR)
@@ -956,26 +967,61 @@ class Find(HorizontalLayout, IClickListener):
                     obj_type=self._NONE,
                     obj_id=0,
                     attr=self._CAL_DESCR)
+
+        # clusters
+        q = session.query(clusters).filter(clusters.name.ilike(tofind))
+        i = 0
+        for j in q.limit(self._LIMIT):
+            self._add_result(container=c,
+                             label=_("Cluster name"),
+                             obj_name=j.name,
+                             obj_type=self._CLUSTER,
+                             obj_id=j.id,
+                             attr=self._CLUSTER_NAME)
+            i += 1
+        if i >= self._LIMIT:
+            self._add_result(container=c,
+                             label=_("..."),
+                             obj_name=_("more cluster names"),
+                             obj_type=self._NONE,
+                             obj_id=0,
+                             attr=self._CLUSTER_NAME)
+        q = session.query(clusters).filter(clusters.description.ilike(tofind))
+        i = 0
+        for j in q.limit(self._LIMIT):
+            self._add_result(container=c,
+                             label=_("Cluster description"),
+                             obj_name=j.name,
+                             obj_type=self._CLUSTER,
+                             obj_id=j.id,
+                             attr=self._CLUSTER_DESCR)
+            i += 1
+        if i >= self._LIMIT:
+            self._add_result(container=c,
+                             label=_("..."),
+                             obj_name=_("more cluster descriptions"),
+                             obj_type=self._NONE,
+                             obj_id=0,
+                             attr=self._CLUSTER_NAME)
+
         # hosts
         q = session.query(hosts).filter(hosts.hostname.ilike(tofind))
         i = 0
         for j in q.limit(self._LIMIT):
-            self._add_result(
-                container=c,
-                label=_("Host name"),
-                obj_name="%s(%s)" % (j.hostname, j.portnum),
-                obj_type=self._HOST,
-                obj_id=j.id,
-                attr=self._HOST_NAME)
+            self._add_result(container=c,
+                             label=_("Host name"),
+                             obj_name=unicode(j),
+                             obj_type=self._HOST,
+                             obj_id=j.id,
+                             attr=self._HOST_NAME)
             i += 1
         if i >= self._LIMIT:
-            self._add_result(
-                    container=c,
-                    label=_("..."),
-                    obj_name=_("more host names"),
-                    obj_type=self._NONE,
-                    obj_id=0,
-                    attr=self._HOST_NAME)
+            self._add_result(container=c,
+                             label=_("..."),
+                             obj_name=_("more host names"),
+                             obj_type=self._NONE,
+                             obj_id=0,
+                             attr=self._HOST_NAME)
         q = session.query(hosts).filter(hosts.portnum.ilike(tofind))
         i = 0
         for j in q.limit(self._LIMIT):
@@ -988,33 +1034,30 @@ class Find(HorizontalLayout, IClickListener):
                 attr=self._HOST_PORT)
             i += 1
         if i >= self._LIMIT:
-            self._add_result(
-                    container=c,
-                    label=_("..."),
-                    obj_name=_("more host ports"),
-                    obj_type=self._NONE,
-                    obj_id=0,
-                    attr=self._HOST_PORT)
+            self._add_result(container=c,
+                             label=_("..."),
+                             obj_name=_("more host ports"),
+                             obj_type=self._NONE,
+                             obj_id=0,
+                             attr=self._HOST_PORT)
         self._sql_session.close_session(session)
         q = session.query(hosts).filter(hosts.description.ilike(tofind))
         i = 0
         for j in q.limit(self._LIMIT):
-            self._add_result(
-                container=c,
-                label=_("Host description"),
-                obj_name="%s(%s)" % (j.hostname, j.portnum),
-                obj_type=self._HOST,
-                obj_id=j.id,
-                attr=self._HOST_DESCR)
+            self._add_result(container=c,
+                             label=_("Host description"),
+                             obj_name=unicode(j),
+                             obj_type=self._HOST,
+                             obj_id=j.id,
+                             attr=self._HOST_DESCR)
             i += 1
         if i >= self._LIMIT:
-            self._add_result(
-                    container=c,
-                    label=_("..."),
-                    obj_name=_("more host descriptions"),
-                    obj_type=self._NONE,
-                    obj_id=0,
-                    attr=self._HOST_DESCR)
+            self._add_result(container=c,
+                             label=_("..."),
+                             obj_name=_("more host descriptions"),
+                             obj_type=self._NONE,
+                             obj_id=0,
+                             attr=self._HOST_DESCR)
         ResultPopup(self, c)
 
 
@@ -1141,18 +1184,24 @@ class ResultPopup(IClickListener):
                       self._c._sql_session,
                       self._c._workload,
                       obj_id)
+        elif obj_type == Find._CLUSTER:
+            HostWindow(self._c._parent_widget,
+                       self._c._parent_widget.getWindow(),
+                       self._c._sql_session,
+                       self._c._workload,
+                       cluster_id_to_select=obj_id)
         elif obj_type == Find._HOST:
             HostWindow(self._c._parent_widget,
                        self._c._parent_widget.getWindow(),
                        self._c._sql_session,
                        self._c._workload,
-                       obj_id)
+                       host_id_to_select=obj_id)
         elif obj_type == Find._CAL:
             CalendarWindow(self._c._parent_widget,
-                      self._c._parent_widget.getWindow(),
-                      self._c._sql_session,
-                      self._c._workload,
-                      obj_id)
+                           self._c._parent_widget.getWindow(),
+                           self._c._sql_session,
+                           self._c._workload,
+                           obj_id)
 
     def buttonClick(self, event):
         # Close the window
