@@ -42,14 +42,14 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
 
     _ROOT_JOBSET_ID = 1
     _ICON_STATUS = {
-        status_utils.WAITING:
-            ThemeResource(status_utils.status2icon(status_utils.WAITING)),
-        status_utils.RUNNING:
-            ThemeResource(status_utils.status2icon(status_utils.RUNNING)),
-        status_utils.COMPLETED:
-            ThemeResource(status_utils.status2icon(status_utils.COMPLETED)),
-        status_utils.FAILED:
-            ThemeResource(status_utils.status2icon(status_utils.FAILED))
+        status_utils.WAITING: ThemeResource(
+            status_utils.status2icon(status_utils.WAITING)),
+        status_utils.RUNNING: ThemeResource(
+            status_utils.status2icon(status_utils.RUNNING)),
+        status_utils.COMPLETED: ThemeResource(
+            status_utils.status2icon(status_utils.COMPLETED)),
+        status_utils.FAILED: ThemeResource(
+            status_utils.status2icon(status_utils.FAILED))
         }
 
     def __init__(self, application, sql_session, workload=None):
@@ -132,7 +132,7 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
                                              self._ROOT_JOBSET_ID,
                                              self._workload)
             item.getItemProperty('icon').setValue(
-                                            self._ICON_STATUS[status.status])
+                self._ICON_STATUS[status.status])
         return c
 
     def add_listener(self, obj):
@@ -211,15 +211,15 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
                 status = status_utils.get_status(session, child_id,
                                                  self._workload)
                 item.getItemProperty('icon').setValue(
-                                            self._ICON_STATUS[status.status])
+                    self._ICON_STATUS[status.status])
             c.setParent(child_id, jobset_id)
             # Only show the expand arrow if the jobset has children
             if sql_count_children(session, child_id, True, self._workload):
                 c.setChildrenAllowed(child_id, True)
             else:
                 c.setChildrenAllowed(child_id, False)
-            if (self._selected == child_id and
-                self._tree.getValue() != self._selected):
+            if self._selected == child_id and \
+               self._tree.getValue() != self._selected:
                 self._tree.select(child_id)
         self._sql_session.close_session(session)
 
@@ -426,7 +426,7 @@ class BreadCrumb(HorizontalLayout, JobsetTreeListener):
                 del self._hierarchy_buttons[jobset_id]
         self._hierarchy_buttons[jobset_hierarchy[-1]].addStyleName("displayed")
         self._hierarchy_buttons[jobset_hierarchy[-1]].removeStyleName(
-                                                            "notdisplayed")
+            "notdisplayed")
 
 
 class BreadCrumbJobsetHandler(IClickListener):
