@@ -36,13 +36,14 @@ from tables.job_main import job_main
 from tables.job_main_s import job_main_s
 from tables.job_host import job_host
 from tables.job_host_s import job_host_s
-from tables.hosts import hosts
 import sql_hierarchy
 import path_cal
 from web.cutcopypastemenu import (CutCopyPasteMenuJobTable, DeleteShortcut,
                                   CutCopyPasteMenuListener)
 from web.autorefresh import AutoRefresh
 import status_utils
+import host_utils
+import cluster_utils
 from simple_queries_stat import sql_get_stat_ratio_completion
 from simple_queries_ack import (sql_get_acknowledge_request_by_job_id,
                                 sql_update_acknowledge_request)
@@ -58,14 +59,14 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
     _ICON_JOBSET = ThemeResource('icons/jobset.png')
     _ICON_ENABLED = ThemeResource('icons/check.png')
     _ICON_STATUS = {
-        status_utils.WAITING:
-            ThemeResource(status_utils.status2icon(status_utils.WAITING)),
-        status_utils.RUNNING:
-            ThemeResource(status_utils.status2icon(status_utils.RUNNING)),
-        status_utils.COMPLETED:
-            ThemeResource(status_utils.status2icon(status_utils.COMPLETED)),
-        status_utils.FAILED:
-            ThemeResource(status_utils.status2icon(status_utils.FAILED))
+        status_utils.WAITING: ThemeResource(
+            status_utils.status2icon(status_utils.WAITING)),
+        status_utils.RUNNING: ThemeResource(
+            status_utils.status2icon(status_utils.RUNNING)),
+        status_utils.COMPLETED: ThemeResource(
+            status_utils.status2icon(status_utils.COMPLETED)),
+        status_utils.FAILED: ThemeResource(
+            status_utils.status2icon(status_utils.FAILED))
         }
 
     def __init__(self, sql_session, workload=None):
@@ -162,7 +163,7 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
             b = NativeButton()
             b.setIcon(ThemeResource('icons/paste.png'))
             b.setDescription(
-                    _("Paste the previously copied or cut job or jobset"))
+                _("Paste the previously copied or cut job or jobset"))
             b.setStyleName('toolbutton')
             b.setEnabled(False)
             b.addListener(PasteBtHandler(self), IClickListener)
@@ -196,6 +197,15 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
             btbox.addComponent(b)
             self._bttrigger = b
 
+            b = NativeButton()
+            b.setIcon(ThemeResource('icons/force.png'))
+            b.setDescription(_("Force the status"))
+            b.setStyleName('toolbutton')
+            b.setEnabled(False)
+            b.addListener(ForceBtHandler(self), IClickListener)
+            btbox.addComponent(b)
+            self._btforce = b
+
         # Job/jobset table
         self._table = Table()
         self._table.setSizeFull()
@@ -213,21 +223,37 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
 
         # Columns
         if workload is None:
-            self._table.setVisibleColumns(['type', 'name',
-                                       'enabled', 'host', 'calendar', 'start'])
-            self._table.setColumnHeaders([_('Type'), _('Name'),
-                                      _('Enabled'), _('Host'),
-                                      _('Calendar'), _('Start Time')])
+            self._table.setVisibleColumns(['type',
+                                           'name',
+                                           'enabled',
+                                           'host',
+                                           'calendar',
+                                           'start'])
+            self._table.setColumnHeaders([_('Type'),
+                                          _('Name'),
+                                          _('Enabled'),
+                                          _('Host/Cluster'),
+                                          _('Calendar'),
+                                          _('Start Time')])
         else:
-            self._table.setVisibleColumns(['type', 'status', 'name',
-                                       'progress',
-                                       'enabled', 'host', 'calendar', 'start',
-                                       'message'])
-            self._table.setColumnHeaders([_('Type'), _("Status"), _('Name'),
-                                      _("Progress"),
-                                      _('Enabled'), _('Host'),
-                                      _('Calendar'), _('Start Time'),
-                                      _("Message")])
+            self._table.setVisibleColumns(['type',
+                                           'status',
+                                           'name',
+                                           'progress',
+                                           'enabled',
+                                           'host',
+                                           'calendar',
+                                           'start',
+                                           'message'])
+            self._table.setColumnHeaders([_('Type'),
+                                          _("Status"),
+                                          _('Name'),
+                                          _("Progress"),
+                                          _('Enabled'),
+                                          _('Host/Cluster'),
+                                          _('Calendar'),
+                                          _('Start Time'),
+                                          _("Message")])
             self._table.setColumnWidth('status', 45)
             self._table.setColumnAlignment('status', Table.ALIGN_CENTER)
         self._table.setColumnWidth('type', 30)
@@ -321,11 +347,11 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                 else:
                     self._btstart.setEnabled(False)
                     self._btstop.setEnabled(True)
+                self._btforce.setEnabled(True)
                 if s.status == status_utils.WAITING:
                     try:
-                        ack = sql_get_acknowledge_request_by_job_id(session,
-                                                                self._selected,
-                                                                self._workload)
+                        ack = sql_get_acknowledge_request_by_job_id(
+                            session, self._selected, self._workload)
                     except:
                         self._bttrigger.setEnabled(False)
                     else:
@@ -346,6 +372,7 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                 self._btstart.setEnabled(False)
                 self._btstop.setEnabled(False)
                 self._bttrigger.setEnabled(False)
+                self._btforce.setEnabled(False)
         if self._workload is None:
             if self._popup_menu.is_cut_or_copy():
                 self._btpaste.setEnabled(True)
@@ -447,19 +474,30 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
             if job.enabled:
                 e = Embedded(source=self._ICON_ENABLED)
                 item.getItemProperty('enabled').setValue(e)
-            # Host
-            in_object, obj = sql_hierarchy.get_by_id(session,
-                            jobset_ids,
-                            job_host if self._workload is None else job_host_s,
-                            self._workload)
-            host = session.query(hosts).filter_by(id=obj.host_id).one()
-            s = '%s (%s/SSL)' if host.sslenable else '%s (%s)'
-            hostname = host.hostname.encode('utf-8')
-            if isinstance(host.portnum, int):
-                portnum = str(host.portnum)
-            else:
-                portnum = host.portnum.encode('utf-8')
-            item.getItemProperty('host').setValue(s % (hostname, portnum))
+            # Host/Cluster
+            # If the job is running, then display the host on which it is
+            # running rather than the cluster/host defined for this job.
+            host = None
+            if self._workload is not None:
+                st = status_utils.get_status(session, job.id, self._workload)
+                if st.status == status_utils.RUNNING and st.host_id:
+                    try:
+                        host = host_utils.get_host_by_id(session, st.host_id)
+                    except:
+                        host = None
+            if host is None:
+                in_object, obj = sql_hierarchy.get_cluster_or_host_by_id(
+                    session, jobset_ids, self._workload)
+                if isinstance(obj, job_host) or isinstance(obj, job_host_s):
+                    host = host_utils.get_host_by_id(session, obj.host_id)
+                else:
+                    cluster = cluster_utils.get_cluster_by_id(session,
+                                                              obj.cluster_id)
+                    item.getItemProperty('host').setValue(
+                        _('%s (cluster)') % cluster.name.encode('utf-8'))
+            if host is not None:
+                s = '%s (SSL)' if host.sslenable else '%s'
+                item.getItemProperty('host').setValue(s % str(host))
             jobset_ids.pop()
             # Calendar
             if job.cal_id == 0:
@@ -471,14 +509,14 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                     s = path_cal.PathCal(session, id=obj.cal_id,
                                          workload=self._workload)
                     item.getItemProperty('calendar').setValue(
-                                                unicode(s).encode('utf-8'))
+                        unicode(s).encode('utf-8'))
                 else:
                     item.getItemProperty('calendar').setValue(_('Everyday'))
             else:
                 s = path_cal.PathCal(session, id=job.cal_id,
                                      workload=self._workload)
                 item.getItemProperty('calendar').setValue(
-                                                unicode(s).encode('utf-8'))
+                    unicode(s).encode('utf-8'))
             # Start time
             hour_str = None
             if self._workload is not None:
@@ -487,22 +525,21 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                 if status.status != status_utils.WAITING:
                     if status.error_msg:
                         item.getItemProperty('message').setValue(
-                                            status.error_msg.encode('utf-8'))
+                            status.error_msg.encode('utf-8'))
                     # Display the status change time
                     st = time.localtime(status.start_time)
                     hour_str = "%02dh%02d" % (st.tm_hour, st.tm_min)
                 else:
                     item.getItemProperty('message').setValue(
-                                status.get_waiting_message().encode('utf-8'))
+                        status.get_waiting_message().encode('utf-8'))
                 e = Embedded(source=self._ICON_STATUS[status.status])
                 e.setDescription(status_utils.status2string(status.status))
                 item.getItemProperty('status').setValue(e)
             if hour_str is None:
                 if job.start_time < 0:
                     # Retrieve the start time from a parent jobset (inherited)
-                    in_object, obj = sql_hierarchy.get_start_time_id(session,
-                                                               jobset_ids,
-                                                               self._workload)
+                    in_object, obj = sql_hierarchy.get_start_time_id(
+                        session, jobset_ids, self._workload)
                     if obj is not None:
                         start_time = obj.start_time
                         hour_str = "%02dh%02d" % (start_time / 100,
@@ -834,20 +871,39 @@ class TriggerBtHandler(IClickListener):
                                            self._c._workload)
         except:
             self._c.getWindow().showNotification(
-                    _("Internal error."),
-                    _("<br/>Job/jobset (%d_%d) not found in the database.") %
-                        (self._c.workload_date, self._c.get_selected()),
-                    Notification.TYPE_ERROR_MESSAGE)
+                _("Internal error."),
+                _("<br/>Job/jobset (%d_%d) not found in the database.") %
+                (self._c.workload_date, self._c.get_selected()),
+                Notification.TYPE_ERROR_MESSAGE)
         else:
             n = Notification(
-                    _("Acknowledgement taken into account."),
-                    _("<br/>This may take up to a minute to be taken into \
-                       account."),
-                    Notification.TYPE_WARNING_MESSAGE)
+                _("Acknowledgement taken into account."),
+                _("<br/>This may take up to a minute to be taken into \
+                   account."),
+                Notification.TYPE_WARNING_MESSAGE)
             n.setDelayMsec(5000)
             self._c.getWindow().showNotification(n)
 
 
+class ForceBtHandler(IClickListener):
+
+    """Callback for the Force status button."""
+
+    def __init__(self, job_table_obj):
+        """Initialize the callback.
+
+        @param job_table_obj:
+                    the associated L{JobTable} object.
+        @type job_table_obj:    L{JobTable}
+        """
+        super(ForceBtHandler, self).__init__()
+        self._c = job_table_obj
+
+    def buttonClick(self, event):
+        AutoRefresh.reset()
+        self._c._popup_menu.do_force(self._c.get_selected())
+
+
 class DoubleClick(IItemClickListener):
 
     """Double-click callback."""
@@ -872,4 +928,5 @@ class DoubleClick(IItemClickListener):
                 map(lambda obj: obj.select(p), self._c._select_listeners)
             else:
                 self._c._popup_menu.do_edit(item_id,
-                                    event.getClientX(), event.getClientY())
+                                            event.getClientX(),
+                                            event.getClientY())
