@@ -26,6 +26,8 @@ from muntjac.ui.button import IClickListener
 import sql_hierarchy
 from tables.job_host import job_host
 from tables.job_host_s import job_host_s
+from tables.job_cluster import job_cluster
+from tables.job_cluster_s import job_cluster_s
 from tables.job_max_duration import job_max_duration
 from tables.job_max_duration_s import job_max_duration_s
 from tables.job_retries import job_retries
@@ -54,8 +56,8 @@ from tables.job_manual import job_manual
 from tables.job_manual_s import job_manual_s
 from tables.job_manual_command import job_manual_command
 from tables.job_manual_command_s import job_manual_command_s
-from web.selecthostwidget import SelectHost
 from web.autorefresh import AutoRefresh
+import web.selecthostwidget
 
 
 class JobWidget(IClickListener):
@@ -207,20 +209,42 @@ class JobWidgetSimple(JobWidget):
                                                              workload)
 
 
-class Host(JobWidgetSimple):
+class Host(JobWidget):
     def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
-        super(Host, self).__init__(jobset_ids, sql_session,
-                          job_host_s if workload else job_host,
-                          workload, job_id)
+        super(Host, self).__init__(jobset_ids,
+                                   sql_session,
+                                   workload,
+                                   job_id)
+        # Retrieve the current and the default value
+        ids = list(jobset_ids)
+        if job_id is not None:
+            ids.append(job_id)
+        from_obj, obj = sql_hierarchy.get_cluster_or_host_by_id(sql_session,
+                                                                ids, workload)
+        if job_id is None or not from_obj:
+            self._obj = None
+            self._default_obj = obj.copy()
+        else:
+            self._obj = obj.copy()
+            foo, obj = sql_hierarchy.get_cluster_or_host_by_id(sql_session,
+                                                               jobset_ids,
+                                                               workload)
+            if obj is not None:
+                self._default_obj = obj.copy()
+            else:
+                self._default_obj = None
+
         self._savedValue = None
-        self._w = SelectHost(sql_session, None,
-                             _("Host on which the job/jobset must run"))
+        self._w = web.selecthostwidget.SelectHostCluster(
+            sql_session,
+            None,
+            _("Host/Cluster on which the job/jobset must run"))
         self._addInheritedWidget(self._w)
 
         if self._obj is not None:
-            self._w.setValue(self._obj.host_id)
+            self._w.set_value(self._obj)
         else:
-            self._savedValue = self._default_obj.host_id
+            self._savedValue = self._w.get_internal_id(self._default_obj)
             self._setDefaultValue()
             self._inherited.setValue(True)
             self._doGreyOut()
@@ -229,7 +253,7 @@ class Host(JobWidgetSimple):
         return self._w
 
     def _setDefaultValue(self):
-        self._w.setValue(self._default_obj.host_id)
+        self._w.set_value(self._default_obj)
 
     def _saveValue(self):
         self._savedValue = self._w.getValue()
@@ -241,30 +265,49 @@ class Host(JobWidgetSimple):
         self._w.focus()
 
     def get_selected(self):
-        return self._w.getValue()
+        return self._w.get_selected_id()
 
     def get_selected_name(self):
         return self._w.get_selected_name()
 
     def updateJob(self, job):
-        if self.isInherited():
+        type_obj, id_obj = self._w.get_selected_id()
+        if self.isInherited() or type_obj is None or id_obj is None:
+            try:
+                del job.job_host
+                del job.job_cluster
+            except:
+                pass
+            return None
+        if type_obj == web.selecthostwidget._HOST_TYPE:
+            try:
+                del job.job_cluster
+            except:
+                pass
+            if self._workload is None:
+                job.job_host = job_host(id_obj)
+            else:
+                job.job_host = job_host_s(id_obj, self._workload)
+        else:
             try:
                 del job.job_host
             except:
                 pass
-            return None
-        if self._workload is None:
-            job.job_host = job_host(self._w.getValue())
-        else:
-            job.job_host = job_host_s(self._w.getValue(), self._workload)
+            if self._workload is None:
+                job.job_cluster = job_cluster(id_obj)
+            else:
+                job.job_cluster = job_cluster_s(id_obj, self._workload)
         return None
 
 
 class MaxDuration(JobWidgetSimple):
     def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
-        super(MaxDuration, self).__init__(jobset_ids, sql_session,
-                          job_max_duration_s if workload else job_max_duration,
-                          workload, job_id)
+        super(MaxDuration, self).__init__(
+            jobset_ids,
+            sql_session,
+            job_max_duration_s if workload else job_max_duration,
+            workload,
+            job_id)
         self._savedValue = ''
         self._hb = HorizontalLayout()
         self._hb.setSpacing(True)
@@ -327,9 +370,12 @@ class MaxDuration(JobWidgetSimple):
 
 class Retries(JobWidgetSimple):
     def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
-        super(Retries, self).__init__(jobset_ids, sql_session,
-                          job_retries_s if workload else job_retries,
-                          workload, job_id)
+        super(Retries, self).__init__(
+            jobset_ids,
+            sql_session,
+            job_retries_s if workload else job_retries,
+            workload,
+            job_id)
         self._savedValue = ''
         self._w = TextField()
         self._w.addValidator(IntegerValidator(_("Must be a number")))
@@ -387,9 +433,12 @@ class Retries(JobWidgetSimple):
 
 class RetryInterval(JobWidgetSimple):
     def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
-        super(RetryInterval, self).__init__(jobset_ids, sql_session,
-                  job_retries_interval_s if workload else job_retries_interval,
-                  workload, job_id)
+        super(RetryInterval, self).__init__(
+            jobset_ids,
+            sql_session,
+            job_retries_interval_s if workload else job_retries_interval,
+            workload,
+            job_id)
         self._savedValue = ''
         self._hb = HorizontalLayout()
         self._hb.setSpacing(True)
@@ -453,16 +502,19 @@ class RetryInterval(JobWidgetSimple):
 
 class ReturnCode(JobWidgetSimple):
     def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
-        super(ReturnCode, self).__init__(jobset_ids, sql_session,
+        super(ReturnCode, self).__init__(
+            jobset_ids,
+            sql_session,
             job_success_return_code_s if workload else job_success_return_code,
-            workload, job_id)
+            workload,
+            job_id)
         self._savedValue = ''
         self._w = TextField()
         self._w.addValidator(
-                IntegerValidator(_("Must be a number between 0 and 254")))
+            IntegerValidator(_("Must be a number between 0 and 254")))
         self._w.setColumns(3)
         self._w.setDescription(_("A return code greater than \
-                                this value means failure"))
+                                  this value means failure"))
         self._w.setImmediate(True)
         self._addInheritedWidget(self._w)
 
@@ -508,16 +560,19 @@ class ReturnCode(JobWidgetSimple):
         if self._workload is None:
             job.job_success_return_code = job_success_return_code(v)
         else:
-            job.job_success_return_code = job_success_return_code_s(v,
-                                                               self._workload)
+            job.job_success_return_code = job_success_return_code_s(
+                v, self._workload)
         return None
 
 
 class StartLimit(JobWidgetSimple):
     def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
-        super(StartLimit, self).__init__(jobset_ids, sql_session,
-                  job_start_limit_s if workload else job_start_limit,
-                  workload, job_id)
+        super(StartLimit, self).__init__(
+            jobset_ids,
+            sql_session,
+            job_start_limit_s if workload else job_start_limit,
+            workload,
+            job_id)
         self._savedValue = ''
         self._hb = HorizontalLayout()
         self._hb.setSpacing(True)
@@ -580,9 +635,12 @@ class StartLimit(JobWidgetSimple):
 
 class LoadEnv(JobWidgetSimple):
     def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
-        super(LoadEnv, self).__init__(jobset_ids, sql_session,
+        super(LoadEnv, self).__init__(
+            jobset_ids,
+            sql_session,
             job_loadenv_s if workload else job_loadenv,
-            workload, job_id)
+            workload,
+            job_id)
         self._savedValue = ''
         self._w = CheckBox('Load user environment')
         self._w.setDescription(_("Whether the user environment (.profile, ...)\
@@ -630,9 +688,12 @@ class LoadEnv(JobWidgetSimple):
 
 class Detach(JobWidgetSimple):
     def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
-        super(Detach, self).__init__(jobset_ids, sql_session,
+        super(Detach, self).__init__(
+            jobset_ids,
+            sql_session,
             job_detach_s if workload else job_detach,
-            workload, job_id)
+            workload,
+            job_id)
         self._savedValue = ''
         #self._w = CheckBox('Start in detach mode')
         self._w = CheckBox()
@@ -682,9 +743,12 @@ class Detach(JobWidgetSimple):
 
 class Manual(JobWidgetSimple):
     def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
-        super(Manual, self).__init__(jobset_ids, sql_session,
+        super(Manual, self).__init__(
+            jobset_ids,
+            sql_session,
             job_manual_s if workload else job_manual,
-            workload, job_id)
+            workload,
+            job_id)
         self._savedValue = ''
         self._w = CheckBox()
         self._w.setDescription(_("Whether a confirmation must be asked to\
@@ -741,7 +805,7 @@ class StartTimeError(Exception):
 class StartTime(JobWidget):
     def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
         super(StartTime, self).__init__(jobset_ids, sql_session,
-                  workload, job_id)
+                                        workload, job_id)
 
         # Retrieve the current and default value
         ids = list(jobset_ids)
@@ -755,9 +819,7 @@ class StartTime(JobWidget):
         else:
             self._obj = obj
             foo, self._default_obj = sql_hierarchy.get_start_time_id(
-                                                             sql_session,
-                                                             jobset_ids,
-                                                             workload)
+                sql_session, jobset_ids, workload)
         self._savedValue_h = ''
         self._savedValue_m = ''
         self._hb = HorizontalLayout()
@@ -901,9 +963,13 @@ class JobWidgetSimpleText(JobWidgetSimple):
 class Command(JobWidgetSimpleText):
     def __init__(self, jobset_ids, sql_session, descr,
                  workload=None, job_id=None):
-        super(Command, self).__init__(jobset_ids, sql_session,
-                                job_command_s if workload else job_command,
-                                descr, workload, job_id)
+        super(Command, self).__init__(
+            jobset_ids,
+            sql_session,
+            job_command_s if workload else job_command,
+            descr,
+            workload,
+            job_id)
         if self._obj is not None:
             self._w.setValue(self._obj.command.encode('utf-8'))
         else:
@@ -943,9 +1009,13 @@ class Command(JobWidgetSimpleText):
 class Username(JobWidgetSimpleText):
     def __init__(self, jobset_ids, sql_session, descr,
                  workload=None, job_id=None):
-        super(Username, self).__init__(jobset_ids, sql_session,
-                                job_username_s if workload else job_username,
-                                descr, workload, job_id)
+        super(Username, self).__init__(
+            jobset_ids,
+            sql_session,
+            job_username_s if workload else job_username,
+            descr,
+            workload,
+            job_id)
         if self._obj is not None:
             self._w.setValue(self._obj.username.encode('utf-8'))
         else:
@@ -977,9 +1047,13 @@ class Username(JobWidgetSimpleText):
 class Stdout(JobWidgetSimpleText):
     def __init__(self, jobset_ids, sql_session, descr,
                  workload=None, job_id=None):
-        super(Stdout, self).__init__(jobset_ids, sql_session,
-                                job_file_out_s if workload else job_file_out,
-                                descr, workload, job_id)
+        super(Stdout, self).__init__(
+            jobset_ids,
+            sql_session,
+            job_file_out_s if workload else job_file_out,
+            descr,
+            workload,
+            job_id)
         if self._obj is not None:
             self._w.setValue(self._obj.file_out.encode('utf-8'))
         else:
@@ -1011,9 +1085,13 @@ class Stdout(JobWidgetSimpleText):
 class Stderr(JobWidgetSimpleText):
     def __init__(self, jobset_ids, sql_session, descr,
                  workload=None, job_id=None):
-        super(Stderr, self).__init__(jobset_ids, sql_session,
-                                job_file_err_s if workload else job_file_err,
-                                descr, workload, job_id)
+        super(Stderr, self).__init__(
+            jobset_ids,
+            sql_session,
+            job_file_err_s if workload else job_file_err,
+            descr,
+            workload,
+            job_id)
         if self._obj is not None:
             self._w.setValue(self._obj.file_err.encode('utf-8'))
         else:
@@ -1045,10 +1123,13 @@ class Stderr(JobWidgetSimpleText):
 class CGroup(JobWidgetSimpleText):
     def __init__(self, jobset_ids, sql_session, descr,
                  workload=None, job_id=None):
-        super(CGroup, self).__init__(jobset_ids, sql_session,
-                                job_control_group_s if workload \
-                                                    else job_control_group,
-                                descr, workload, job_id)
+        super(CGroup, self).__init__(
+            jobset_ids,
+            sql_session,
+            job_control_group_s if workload else job_control_group,
+            descr,
+            workload,
+            job_id)
         if self._obj is not None:
             self._w.setValue(self._obj.control_group.encode('utf-8'))
         else:
@@ -1080,15 +1161,19 @@ class CGroup(JobWidgetSimpleText):
 class ManualCommand(JobWidgetSimpleText):
     def __init__(self, jobset_ids, sql_session, descr,
                  workload=None, job_id=None):
-        super(ManualCommand, self).__init__(jobset_ids, sql_session,
-                      job_manual_command_s if workload else job_manual_command,
-                      descr, workload, job_id)
+        super(ManualCommand, self).__init__(
+            jobset_ids,
+            sql_session,
+            job_manual_command_s if workload else job_manual_command,
+            descr,
+            workload,
+            job_id)
         if self._obj is not None:
             self._w.setValue(self._obj.manual_command.encode('utf-8'))
         else:
             if self._default_obj:
                 self._savedValue = self._default_obj.manual_command.encode(
-                                                                    'utf-8')
+                    'utf-8')
             else:
                 self._savedValue = ''
             self._setDefaultValue()
