@@ -198,7 +198,7 @@ class JobWindow(Window, IClickListener):
                 self._name.setEnabled(job.rw_name)
 
         # General/Host Name
-        l = Label(_("Host:"))
+        l = Label(_("Host/Cluster:"))
         l.setWidth(None)
         t1.addComponent(l, 0, 2)
         t1.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
@@ -236,7 +236,7 @@ class JobWindow(Window, IClickListener):
         t1.addComponent(l, 0, 4)
         t1.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
         w = web.jobwidgets.RetryInterval(self._jobset_ids, session,
-                                          self._workload, self._job_id)
+                                         self._workload, self._job_id)
         t1.addComponent(w.getFieldWidget(), 1, 4)
         if workload is not None and job.rw_job_retries_interval is False:
             w.getFieldWidget().setEnabled(False)
@@ -285,7 +285,7 @@ class JobWindow(Window, IClickListener):
         t2.addComponent(l, 0, 1)
         t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
         w = web.jobwidgets.StartTime(self._jobset_ids, session,
-                                      self._workload, self._job_id)
+                                     self._workload, self._job_id)
         t2.addComponent(w.getFieldWidget(), 1, 1)
         if workload is not None and job.rw_start_time is False:
             w.getFieldWidget().setEnabled(False)
@@ -348,17 +348,16 @@ class JobWindow(Window, IClickListener):
         l.setWidth(None)
         t2.addComponent(l, 0, 5)
         t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.ManualCommand(self._jobset_ids, session,
-                                _("Command to run to alert of a waiting manual\
-                                job. If empty no command will be run. The\
-                                following environment variables are set:\
-                                SCHEDWI_TEMPLATE (the path to a text file that\
-                                contains the message to send to operators),\
-                                SCHEDWI_JOBPATH, SCHEDWI_JOBID,\
-                                SCHEDWI_START_TIME, SCHEDWI_START_TIME_EPOCH,\
-                                SCHEDWI_TIME_LIMIT and\
-                                SCHEDWI_TIME_LIMIT_EPOCH"),
-                            self._workload, self._job_id)
+        w = web.jobwidgets.ManualCommand(
+            self._jobset_ids,
+            session,
+            _("Command to run to alert of a waiting manual job. If empty no \
+               command will be run. The following environment variables are \
+               set: SCHEDWI_TEMPLATE (the path to a text file that contains \
+               the message to send to operators), SCHEDWI_JOBPATH, \
+               SCHEDWI_JOBID, SCHEDWI_START_TIME, SCHEDWI_START_TIME_EPOCH, \
+               SCHEDWI_TIME_LIMIT and SCHEDWI_TIME_LIMIT_EPOCH"),
+            self._workload, self._job_id)
         t2.addComponent(w.getFieldWidget(), 1, 5)
         if workload is not None and job.rw_job_manual_command is False:
             w.getFieldWidget().setEnabled(False)
@@ -382,10 +381,12 @@ class JobWindow(Window, IClickListener):
         l.setWidth(None)
         t3.addComponent(l, 0, 0)
         t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.Command(self._jobset_ids, session,
-                                _("Command to run (without its arguments) \
-                                If empty no command will be run"),
-                            self._workload, self._job_id)
+        w = web.jobwidgets.Command(self._jobset_ids,
+                                   session,
+                                   _("Command to run (without its arguments) \
+                                      If empty no command will be run"),
+                                   self._workload,
+                                   self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 0)
         if workload is not None and job.rw_job_command is False:
             w.getFieldWidget().setEnabled(False)
@@ -400,9 +401,12 @@ class JobWindow(Window, IClickListener):
         l.setWidth(None)
         t3.addComponent(l, 0, 1)
         t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.Username(self._jobset_ids, session,
-                            _("System user name used to run the command"),
-                            self._workload, self._job_id)
+        w = web.jobwidgets.Username(
+            self._jobset_ids,
+            session,
+            _("System user name used to run the command"),
+            self._workload,
+            self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 1)
         if workload is not None and job.rw_job_username is False:
             w.getFieldWidget().setEnabled(False)
@@ -417,9 +421,11 @@ class JobWindow(Window, IClickListener):
         l.setWidth(None)
         t3.addComponent(l, 0, 2)
         t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.Stdout(self._jobset_ids, session,
-                            _("Output file name (empty means no file)"),
-                            self._workload, self._job_id)
+        w = web.jobwidgets.Stdout(self._jobset_ids,
+                                  session,
+                                  _("Output file name (empty means no file)"),
+                                  self._workload,
+                                  self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 2)
         if workload is not None and job.rw_job_file_out is False:
             w.getFieldWidget().setEnabled(False)
@@ -434,9 +440,11 @@ class JobWindow(Window, IClickListener):
         l.setWidth(None)
         t3.addComponent(l, 0, 3)
         t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.Stderr(self._jobset_ids, session,
-                            _("Error file name (empty means no file)"),
-                            self._workload, self._job_id)
+        w = web.jobwidgets.Stderr(self._jobset_ids,
+                                  session,
+                                  _("Error file name (empty means no file)"),
+                                  self._workload,
+                                  self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 3)
         if workload is not None and job.rw_job_file_err is False:
             w.getFieldWidget().setEnabled(False)
@@ -468,7 +476,7 @@ class JobWindow(Window, IClickListener):
         t3.addComponent(l, 0, 5)
         t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
         w = web.jobwidgets.Detach(self._jobset_ids, session,
-                                   self._workload, self._job_id)
+                                  self._workload, self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 5)
         if workload is not None and job.rw_job_detach is False:
             w.getFieldWidget().setEnabled(False)
@@ -483,9 +491,11 @@ class JobWindow(Window, IClickListener):
         l.setWidth(None)
         t3.addComponent(l, 0, 6)
         t3.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.CGroup(self._jobset_ids, session,
-                            _("Control Group name"),
-                            self._workload, self._job_id)
+        w = web.jobwidgets.CGroup(self._jobset_ids,
+                                  session,
+                                  _("Control Group name"),
+                                  self._workload,
+                                  self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 6)
         if workload is not None and job.rw_job_control_group is False:
             w.getFieldWidget().setEnabled(False)
@@ -509,8 +519,6 @@ class JobWindow(Window, IClickListener):
                                      Alignment.MIDDLE_RIGHT)
         self._args = w
 
-        self._sql_session.close_session(session)
-
         # Environments
         t4 = VerticalLayout()
         t4.setSizeFull()
@@ -534,6 +542,8 @@ class JobWindow(Window, IClickListener):
             le.addComponent(w.getInheritedCheckbox())
         self._loadenv = w
 
+        self._sql_session.close_session(session)
+
         # Environments/Environment groups
         e = web.envwidget.EnvWidget(self._jobset_ids, application_window,
                                     self._host,
@@ -598,10 +608,10 @@ class JobWindow(Window, IClickListener):
             name = self._name.getValue().strip()
             if not name:
                 self._application_window.showNotification(
-                            _("Name is empty"),
-                            _("<br/>The job or jobset name cannot \
-                                  be empty or contain just spaces."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                    _("Name is empty"),
+                    _("<br/>The job or jobset name cannot \
+                       be empty or contain just spaces."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 self._ts.setSelectedTab(self._t1)
                 self._name.focus()
                 return
@@ -614,9 +624,9 @@ class JobWindow(Window, IClickListener):
                              jobs[0].id != self._job_id):
                     self._sql_session.cancel_session(session)
                     self._application_window.showNotification(
-                            _("The name is already used"),
-                            _("<br/>The specified name is already taken."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                        _("The name is already used"),
+                        _("<br/>The specified name is already taken."),
+                        Notification.TYPE_ERROR_MESSAGE)
                     self._ts.setSelectedTab(self._t1)
                     self._name.focus()
                     return
@@ -628,8 +638,9 @@ class JobWindow(Window, IClickListener):
             except web.jobwidgets.StartTimeError as e:
                 self._sql_session.cancel_session(session)
                 self._application_window.showNotification(
-                        _("Wrong value for the start time"), '<br/>' + str(e),
-                        Notification.TYPE_ERROR_MESSAGE)
+                    _("Wrong value for the start time"),
+                    '<br/>' + str(e),
+                    Notification.TYPE_ERROR_MESSAGE)
                 self._ts.setSelectedTab(self._t1)
                 return
             if self._job_id is None:
@@ -639,18 +650,18 @@ class JobWindow(Window, IClickListener):
                                    description, 0, 0, cal_id, start_time)
                 else:
                     job = job_main_s(self._jobset_ids[-1], name,
-                                   1 if self._is_job else 0, int(enabled), 1,
-                                   description, 0, 0, cal_id, start_time,
-                                   self._workload)
+                                     1 if self._is_job else 0, int(enabled), 1,
+                                     description, 0, 0, cal_id, start_time,
+                                     self._workload)
             else:
                 try:
                     job = sql_get_job(session, self._job_id, self._workload)
                 except:
                     self._sql_session.cancel_session(session)
                     self._application_window.showNotification(
-                            _("Cannot get the edited job/jobset details"),
-                            _("<br/>Maybe someone else just removed it."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                        _("Cannot get the edited job/jobset details"),
+                        _("<br/>Maybe someone else just removed it."),
+                        Notification.TYPE_ERROR_MESSAGE)
                     # Close the window
                     self._application_window.removeWindow(self)
                     return
@@ -663,34 +674,36 @@ class JobWindow(Window, IClickListener):
             if msg:
                 self._sql_session.cancel_session(session)
                 self._application_window.showNotification(
-                        _("Wrong value for the start limit"), '<br/>' + msg,
-                        Notification.TYPE_ERROR_MESSAGE)
+                    _("Wrong value for the start limit"),
+                    '<br/>' + msg,
+                    Notification.TYPE_ERROR_MESSAGE)
                 self._ts.setSelectedTab(self._t1)
                 return
             msg = self._max_duration.updateJob(job)
             if msg:
                 self._sql_session.cancel_session(session)
                 self._application_window.showNotification(
-                        _("Wrong value for the max duration"), '<br/>' + msg,
-                        Notification.TYPE_ERROR_MESSAGE)
+                    _("Wrong value for the max duration"),
+                    '<br/>' + msg,
+                    Notification.TYPE_ERROR_MESSAGE)
                 self._ts.setSelectedTab(self._t1)
                 return
             msg = self._retries.updateJob(job)
             if msg:
                 self._sql_session.cancel_session(session)
                 self._application_window.showNotification(
-                        _("Wrong value for the number of retries"),
-                        '<br/>' + msg,
-                        Notification.TYPE_ERROR_MESSAGE)
+                    _("Wrong value for the number of retries"),
+                    '<br/>' + msg,
+                    Notification.TYPE_ERROR_MESSAGE)
                 self._ts.setSelectedTab(self._t1)
                 return
             msg = self._retry_interval.updateJob(job)
             if msg:
                 self._sql_session.cancel_session(session)
                 self._application_window.showNotification(
-                        _("Wrong value for the retry interval"),
-                        '<br/>' + msg,
-                        Notification.TYPE_ERROR_MESSAGE)
+                    _("Wrong value for the retry interval"),
+                    '<br/>' + msg,
+                    Notification.TYPE_ERROR_MESSAGE)
                 self._ts.setSelectedTab(self._t1)
                 return
             self._host.updateJob(job)
@@ -709,9 +722,9 @@ class JobWindow(Window, IClickListener):
             if msg:
                 self._sql_session.cancel_session(session)
                 self._application_window.showNotification(
-                        _("Wrong value for the return code"),
-                        '<br/>' + msg,
-                        Notification.TYPE_ERROR_MESSAGE)
+                    _("Wrong value for the return code"),
+                    '<br/>' + msg,
+                    Notification.TYPE_ERROR_MESSAGE)
                 self._ts.setSelectedTab(self._t3)
                 return
             if self._job_id is None:
