@@ -95,8 +95,8 @@ class LoginWindow(Window, ILoginListener):
         h.addComponent(b)
 
     def _authenticate(self, username, password):
-        if (username == parse_config.GUI_USERNAME and
-            password == parse_config.GUI_PASSWORD):
+        if username == parse_config.GUI_USERNAME and \
+           password == parse_config.GUI_PASSWORD:
             logging.info(_("%s authenticated (local)") % username)
             self._c.setUser(username)
             return True
