@@ -49,12 +49,13 @@ class Main(Application, SqlSession):
 
     def __init__(self):
         """Initialize the object."""
-        SqlSession.__init__(self, drivername=parse_config.DBI_DRIVERNAME,
-                                  user=parse_config.DBI_USER,
-                                  password=parse_config.DBI_PASSWORD,
-                                  hostname=parse_config.DBI_DBHOSTNAME,
-                                  dbname=parse_config.DBI_DBNAME,
-                                  dbdir=parse_config.DBI_DBDIR)
+        SqlSession.__init__(self,
+                            drivername=parse_config.DBI_DRIVERNAME,
+                            user=parse_config.DBI_USER,
+                            password=parse_config.DBI_PASSWORD,
+                            hostname=parse_config.DBI_DBHOSTNAME,
+                            dbname=parse_config.DBI_DBNAME,
+                            dbdir=parse_config.DBI_DBDIR)
 
         self._login_window = None
         self._select_activity_window = None
@@ -90,8 +91,8 @@ class Main(Application, SqlSession):
         self._select_activity_window = SelectActivityWindow(self)
         self._select_activity_window.setName('activity')
         self.setMainWindow(self._select_activity_window)
-        self._login_window.open(ExternalResource(
-                                    self._select_activity_window.getURL()))
+        self._login_window.open(
+            ExternalResource(self._select_activity_window.getURL()))
 
     def state_main(self, workload=None, workload_str=None):
         """Transition to the main window."""
@@ -108,11 +109,20 @@ class Main(Application, SqlSession):
 
     def getWindow(self, name):
         w = super(Main, self).getWindow(name)
-        if w == None and name.find('schedwi-') == 0:
+        if w is None and name.find('schedwi-') == 0:
             w = TriggerManualJobWindow(self, name)
             self.addWindow(w)
         return w
 
+    def getURL(self):
+        """Return the URL.
+        If https is used, the Application getURL() method does not seem to
+        return a proper URL (`http://' instead of `https://')
+        This function overrides the parent's one.
+        """
+        url = super(Main, self).getURL()
+        return url.replace('http://', 'https://', 1)
+
 
 class SchedwiWindow(Window):
 
