@@ -78,23 +78,24 @@ class TopBar(HorizontalLayout, RefreshListener):
             button_box.setComponentAlignment(h, Alignment.MIDDLE_RIGHT)
 
             self._label_waiting = Label("1")
-            self._label_waiting.setStyleName("label-" +
-                        status_utils.status2colorname(status_utils.WAITING))
+            self._label_waiting.setStyleName(
+                "label-" + status_utils.status2colorname(status_utils.WAITING))
             h.addComponent(self._label_waiting)
 
             self._label_running = Label("2")
-            self._label_running.setStyleName("label-" +
-                        status_utils.status2colorname(status_utils.RUNNING))
+            self._label_running.setStyleName(
+                "label-" + status_utils.status2colorname(status_utils.RUNNING))
             h.addComponent(self._label_running)
 
             self._label_completed = Label("3")
-            self._label_completed.setStyleName("label-" +
-                        status_utils.status2colorname(status_utils.COMPLETED))
+            self._label_completed.setStyleName(
+                "label-" +
+                status_utils.status2colorname(status_utils.COMPLETED))
             h.addComponent(self._label_completed)
 
             self._label_failed = Label("4")
-            self._label_failed.setStyleName("label-" +
-                        status_utils.status2colorname(status_utils.FAILED))
+            self._label_failed.setStyleName(
+                "label-" + status_utils.status2colorname(status_utils.FAILED))
             h.addComponent(self._label_failed)
 
             self._refresher = Refresher()
@@ -106,7 +107,7 @@ class TopBar(HorizontalLayout, RefreshListener):
         if tool_buttons:
             b = NativeButton()
             b.setIcon(ThemeResource('icons/agents.png'))
-            b.setDescription(_("Hosts"))
+            b.setDescription(_("Hosts and Clusters"))
             b.setStyleName('btleft')
             b.addListener(HostPopup(self), IClickListener)
             button_box.addComponent(b)
@@ -173,8 +174,8 @@ class TopBar(HorizontalLayout, RefreshListener):
     def refresh(self, source=None):
         TOTAL_WIDTH = 280
         num_waiting, num_running, num_completed, num_failed = \
-                simple_queries_wl.num_jobs_by_status(self._sql_session,
-                                                     self._workload)
+            simple_queries_wl.num_jobs_by_status(self._sql_session,
+                                                 self._workload)
         total = num_waiting + num_running + num_completed + num_failed
 
         pct_waiting = 100.0 * num_waiting / total
@@ -191,7 +192,7 @@ class TopBar(HorizontalLayout, RefreshListener):
         pct_running = 100.0 * num_running / total
         if pct_running >= 20.0:
             self._label_running.setValue('%d (%.1f%%)' %
-                                     (num_running, pct_running))
+                                         (num_running, pct_running))
         else:
             self._label_running.setValue(int(num_running))
         self._label_running.setDescription(_("Running (%d - %.1f%%)") %
@@ -202,7 +203,7 @@ class TopBar(HorizontalLayout, RefreshListener):
         pct_completed = 100.0 * num_completed / total
         if pct_completed >= 20.0:
             self._label_completed.setValue('%d (%.1f%%)' %
-                                       (num_completed, pct_completed))
+                                           (num_completed, pct_completed))
         else:
             self._label_completed.setValue(int(num_completed))
         self._label_completed.setDescription(_("Completed (%d - %.1f%%)") %
@@ -213,7 +214,7 @@ class TopBar(HorizontalLayout, RefreshListener):
         pct_failed = 100.0 * num_failed / total
         if pct_failed >= 20.0:
             self._label_failed.setValue('%d (%.1f%%)' %
-                                    (num_failed, pct_failed))
+                                        (num_failed, pct_failed))
         else:
             self._label_failed.setValue(int(num_failed))
         self._label_failed.setDescription(_("Failed (%d - %.1f%%)") %
