@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2011 Herve Quatremain
+   Copyright (C) 2011-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -82,6 +82,7 @@ extern int errno;
 #include <lib_functions.h>
 #include <utils.h>
 #include <lwc_log.h>
+#include <conf.h>
 #include <cert_utils.h>
 #include <cert_ca.h>
 
@@ -179,7 +180,8 @@ free_host_names (char **lst)
 
 
 /*
- * Return the know names of the current host.
+ * Return the know names of the current host (or the SSLCommonName
+ * configuration parameter)
  *
  * Return:
  *  The NULL terminated array of hostnames (to be free by free_host_names()) OR
@@ -191,11 +193,28 @@ get_host_names ()
 	char **lst, host[NI_MAXHOST], *hostname;
 	struct ifaddrs *ifaddr, *ifa;
 	int i, j, family, ret;
+	const char *conf_cn;
 
-	hostname = get_hostname ();
-	if (hostname == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return NULL;
+
+	ret  = conf_get_param_string ("SSLCommonName", &conf_cn);
+#if HAVE_ASSERT_H
+	assert (ret == 0);
+#endif
+
+	if (conf_cn != NULL && conf_cn[0] != '\0') {
+		hostname = (char *) malloc (schedwi_strlen (conf_cn) + 1);
+		if (hostname == NULL) {
+			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
+			return NULL;
+		}
+		strcpy (hostname, conf_cn);
+	}
+	else {
+		hostname = get_hostname ();
+		if (hostname == NULL) {
+			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
+			return NULL;
+		}
 	}
 
 	if (getifaddrs (&ifaddr) < 0) {
@@ -487,11 +506,24 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 	int ret, days;
 	char bin_serial[5];
 	FILE *file;
+	const char *conf_c, *conf_o, *conf_ou, *conf_l, *conf_st,
+		   *conf_cn, *conf_email;
 
 	if (key == NULL || outfile == NULL) {
 		return 0;
 	}
 
+	ret  = conf_get_param_string ("SSLCACountry", &conf_c);
+	ret += conf_get_param_string ("SSLCAOrganization", &conf_o);
+	ret += conf_get_param_string ("SSLCAUnit", &conf_ou);
+	ret += conf_get_param_string ("SSLCALocality", &conf_l);
+	ret += conf_get_param_string ("SSLCAState", &conf_st);
+	ret += conf_get_param_string ("SSLCACommonName", &conf_cn);
+	ret += conf_get_param_string ("SSLCAEmail", &conf_email);
+#if HAVE_ASSERT_H
+	assert (ret == 0);
+#endif
+
 	ret = gnutls_x509_crt_init (&crt);
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
@@ -502,71 +534,66 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 
 	/* Set the DN */
 	ret = gnutls_x509_crt_set_dn_by_oid (crt,
-					GNUTLS_OID_X520_COUNTRY_NAME, 0,
-					COUNTRY,
-					schedwi_strlen (COUNTRY));
+				GNUTLS_OID_X520_COUNTRY_NAME, 0,
+				conf_c, schedwi_strlen (conf_c));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the COUNTRY (%s): %s"),
-			COUNTRY, gnutls_strerror (ret));
+			conf_c, gnutls_strerror (ret));
 		gnutls_x509_crt_deinit (crt);
 		return -1;
 	}
 
 	ret = gnutls_x509_crt_set_dn_by_oid (crt,
-					GNUTLS_OID_X520_ORGANIZATION_NAME, 0,
-					ORGANIZATION,
-					schedwi_strlen (ORGANIZATION));
+			GNUTLS_OID_X520_ORGANIZATION_NAME, 0,
+			conf_o, schedwi_strlen (conf_o));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the ORGANIZATION (%s): %s"),
-			ORGANIZATION, gnutls_strerror (ret));
+			conf_o, gnutls_strerror (ret));
 		gnutls_x509_crt_deinit (crt);
 		return -1;
 	}
 
 	ret = gnutls_x509_crt_set_dn_by_oid (crt,
 				GNUTLS_OID_X520_ORGANIZATIONAL_UNIT_NAME, 0,
-				OU, schedwi_strlen (OU));
+				conf_ou, schedwi_strlen (conf_ou));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the ORGANIZATIONAL UNIT (%s): %s"),
-			OU, gnutls_strerror (ret));
+			conf_ou, gnutls_strerror (ret));
 		gnutls_x509_crt_deinit (crt);
 		return -1;
 	}
 
 	ret = gnutls_x509_crt_set_dn_by_oid (crt,
-					GNUTLS_OID_X520_LOCALITY_NAME, 0,
-					LOCALITY,
-					schedwi_strlen (LOCALITY));
+				GNUTLS_OID_X520_LOCALITY_NAME, 0,
+				conf_l, schedwi_strlen (conf_l));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the LOCALITY (%s): %s"),
-			LOCALITY, gnutls_strerror (ret));
+			conf_l, gnutls_strerror (ret));
 		gnutls_x509_crt_deinit (crt);
 		return -1;
 	}
 
 	ret = gnutls_x509_crt_set_dn_by_oid (crt,
 				GNUTLS_OID_X520_STATE_OR_PROVINCE_NAME, 0,
-				STATE,
-				schedwi_strlen (STATE));
+				conf_st, schedwi_strlen (conf_st));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the STATE (%s): %s"),
-			STATE, gnutls_strerror (ret));
+			conf_st, gnutls_strerror (ret));
 		gnutls_x509_crt_deinit (crt);
 		return -1;
 	}
 
-	ret =
-	gnutls_x509_crt_set_dn_by_oid (crt, GNUTLS_OID_X520_COMMON_NAME, 0,
-					CA_CN, schedwi_strlen (CA_CN));
+	ret = gnutls_x509_crt_set_dn_by_oid (crt, GNUTLS_OID_X520_COMMON_NAME,
+					0, conf_cn, schedwi_strlen (conf_cn));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the COMMON NAME (%s): %s"),
-			CA_CN, gnutls_strerror (ret));
+			conf_cn, gnutls_strerror (ret));
 		gnutls_x509_crt_deinit (crt);
 		return -1;
 	}
@@ -621,16 +648,19 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 	}
 
 	/* Email */
-	ret = gnutls_x509_crt_set_subject_alt_name (crt, GNUTLS_SAN_RFC822NAME,
-						CA_EMAIL,
-						schedwi_strlen (CA_EMAIL),
-						GNUTLS_FSAN_APPEND);
-	if (ret < 0) {
-		lwc_writeLog (LOG_ERR,
-			_("SSL: Cannot set the alt name (%s): %s"),
-			CA_EMAIL, gnutls_strerror (ret));
-		gnutls_x509_crt_deinit (crt);
-		return -1;
+	if (conf_email != NULL && conf_email[0] != '\0') {
+		ret = gnutls_x509_crt_set_subject_alt_name (crt,
+					GNUTLS_SAN_RFC822NAME,
+					conf_email,
+					schedwi_strlen (conf_email),
+					GNUTLS_FSAN_APPEND);
+		if (ret < 0) {
+			lwc_writeLog (LOG_ERR,
+				_("SSL: Cannot set the alt name (%s): %s"),
+				conf_email, gnutls_strerror (ret));
+			gnutls_x509_crt_deinit (crt);
+			return -1;
+		}
 	}
 
 	/* Certificate usages */
@@ -1042,7 +1072,7 @@ cert_revoke (	gnutls_x509_privkey_t ca_key,
 		}
 	}
 
-#if GNUTLS_VERSION_NUMBER <= 0x020b00	
+#if GNUTLS_VERSION_NUMBER <= 0x020b00
 	ret = gnutls_x509_crl_sign (crl, ca_cert, ca_key);
 #else
 	{
@@ -1176,7 +1206,7 @@ cert_check_and_create (	const char *file_ca_cert,
 		&& (missing_file_ca_key != 0 || missing_file_key != 0))
 	{
 		lwc_writeLog (LOG_INFO,
-	_("Creating SSL keys and certificates (may take several minutes)..."));	
+	_("Creating SSL keys and certificates (may take several minutes)..."));
 	}
 	if (missing_file_ca_key) {
 		if (build_ca (file_ca_cert, file_ca_key, user, group) != 0) {
