@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2010 Herve Quatremain
+   Copyright (C) 2007-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -412,13 +412,12 @@ const char *
 check_int (const char *s)
 {
 	char *ptr;
-	long int unused;
 
 #if HAVE_ASSERT_H
 	assert (s != NULL);
 #endif
 
-	unused = strtol (s, &ptr, 0);
+	(void)strtol (s, &ptr, 0);
 	while (*ptr != 0 && isspace (*ptr) != 0) {
 		ptr++;
 	}
