@@ -76,6 +76,8 @@ static conf_param_t params_clnt[] = {
 	{ "GUI_PORT", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_GUI_PORT},
 	{ "GUI_LOG_FILE", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_GUI_LOGFILE},
 	{ "GUI_CONTEXT_ROOT", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_GUI_CONTEXT_ROOT},
+	{ "GUI_SSLCertificateFile", STRING, {0}, 0, 0, 0, ""},
+	{ "GUI_SSLCertificateKeyFile", STRING, {0}, 0, 0, 0, ""},
 	{ "PAM_AUTH", BOOL, {0}, check_bool, 0, 0, "0"},
 	{ "PAM_AUTH_SERVICE", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_PAM_AUTH_SERVICE},
 	{ "MODULE_DIR", FUNCTION, {0}, 0, module_path, 0, 0},
