@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -56,6 +56,13 @@
  *      COMPLETED
  *      FAILED
  *
+ * In addition to the SCHEDWI_JOBID and SCHEDWI_JOBPATH environment variables,
+ * the following variables are also set:
+ *   SCHEDWI_START_TIME (expected start time of the job - HH:MM)
+ *   SCHEDWI_START_TIME_EPOCH (expected start time in second since EPOCH)
+ *   SCHEDWI_TIME_LIMIT (optionnal - time limit for the job to start - HH:MM)
+ *   SCHEDWI_TIME_LIMIT_EPOCH (optionnal - time limit for the job to start)
+ *
  * The directives can be used more than one time to define several commands.
  * These commands will be run one after the other, in no particular order.
  * However, if several MODULE:mod_shell:CMD_CHECK commands are provided,
@@ -99,37 +106,12 @@
 #endif
 #endif
 
-#if HAVE_STDIO_H
-#include <stdio.h>
-#endif
-
-#if HAVE_SYS_WAIT_H
-# include <sys/wait.h>
-#endif
-#ifndef WEXITSTATUS
-# define WEXITSTATUS(stat_val) ((unsigned)(stat_val) >> 8)
-#endif
-#ifndef WIFEXITED
-# define WIFEXITED(stat_val) (((stat_val) & 255) == 0)
-#endif
-
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
-#if HAVE_SIGNAL_H
-#include <signal.h>
-#endif
-
 #include <lib_functions.h>
+#include <schedwi_system.h>
 #include <schedwi_jobtree.h>
 #include <job_status_state.h>
 
 
-#define SHELL_PATH "/bin/sh"	/* Path of the shell.  */
-#define SHELL_NAME "sh"		/* Name to give it.  */
-
-
 /*
  * Command structure
  */
@@ -206,126 +188,6 @@ cmds_list_search (struct cmds *head, const char *cmd)
 }
 
 
-/*
- * Run the provided command (in `line').  The other parameters are used to
- * set the environement of the command.
- *
- * Return:
- *    -1 --> System error
- *   127 --> Failed to start the command
- *   300 --> The command has not exited normally (killed, ...)
- * other --> Command return code
- */
-static int
-my_system (	const char *line,
-		int workload, const schedwi_jobtree_node_ptr job,
-		char *old_status_env, char *new_status_env)
-{
-#if HAVE_PID_T
-	pid_t p;
-#else
-	int p;
-#endif
-	char *env_jobpath;
-	char env_job_id[100];
-	sigset_t mask, omask;
-	struct sigaction sa;
-	int status, i;
-
-	if (line == NULL || line[0] == '\0') {
-		return 0;
-	}
-
-	/* Build the environment variables */
-	env_jobpath = (char *) malloc (schedwi_strlen (job->path) + 30);
-	if (env_jobpath == NULL) {
-		return -1;
-	}
-	strcpy (env_jobpath, "SCHEDWI_JOBPATH=");
-	strcat (env_jobpath, job->path);
-	sprintf (env_job_id, "SCHEDWI_JOBID=%d_%lld", workload, job->id);
-
-	if (	   sigemptyset (&mask) != 0
-		|| sigaddset (&mask,  SIGCHLD) != 0
-		|| sigprocmask (SIG_BLOCK, &mask, &omask) != 0)
-	{
-		free (env_jobpath);
-		return -1;
-	}
-
-	p = fork ();
-	if (p < 0) {
-		sigprocmask (SIG_SETMASK, &omask, NULL);
-		free (env_jobpath);
-		return -1;
-	}
-
-	if (p == 0) {
-		/* Child */
-		const char *new_argv[4];
-		const char *new_env[5];
-
-		new_argv[0] = SHELL_NAME;
-		new_argv[1] = "-c";
-		new_argv[2] = line;
-		new_argv[3] = NULL;
-
-		new_env[0] = env_job_id;
-		new_env[1] = env_jobpath;
-		new_env[2] = old_status_env;
-		new_env[3] = new_status_env;
-		new_env[4] = NULL;
-
-		/* Close all files */
-		for (i = getdtablesize () - 1; i >= 0; i--) {
-			close (i);
-		}
-
-		/* Clear the environment */
-#ifndef CYGWIN_IN_USE
-#if HAVE_CLEARENV
-		clearenv ();
-#elif _GNU_SOURCE
-		environ = NULL;
-#endif
-#endif
-
-		/* Clear the signal actions and mask */
-		schedwi_memset (&sa, 0, sizeof (struct sigaction));
-		sa.sa_handler = SIG_DFL;
-		sigemptyset (&sa.sa_mask);
-		for (i = 0; i < 128; i++) {
-			sigaction (i, &sa, NULL);
-		}
-		sigfillset (&mask);
-		sigprocmask (SIG_UNBLOCK, &mask, NULL);
-
-		execve (SHELL_PATH,	(char *const *) new_argv,
-					(char *const *) new_env);
-
-		exit (127);
-	}
-
-	free (env_jobpath);
-
-	/* Parent */
-	if (waitpid (p, &status, 0) != p) {
-		sigprocmask (SIG_SETMASK, &omask, NULL);
-		return -1;
-	}
-
-	sigprocmask (SIG_SETMASK, &omask, NULL);
-
-	if (WIFEXITED (status) != 0) {
-		return WEXITSTATUS (status);
-	}
-	else {
-		return 300;
-	}
-}
-
-
-
 /** libtool aliases for the exported symbols.  These aliases are used in order
  * to avoid symbol conflicts on some operating systems.  Each symbol
  * (schedwi_init, schedwi_exit, schedwi_conf, schedwi_status and schedwi_check)
@@ -447,43 +309,43 @@ int
 schedwi_status (int workload, const schedwi_jobtree_node_ptr job,
 		job_status_state old_state, job_status_state new_state)
 {
-	char *old_status_env, *new_status_env;
+	const char *env[2];
 	struct cmds *ptr;
 	int ret;
 
 	switch (old_state) {
 		case JOB_STATUS_STATE_WAITING:
-			old_status_env = "SCHEDWI_STATUS_OLD=WAITING";
+			env[0] = "SCHEDWI_STATUS_OLD=WAITING";
 			break;
 		case JOB_STATUS_STATE_RUNNING:
-			old_status_env = "SCHEDWI_STATUS_OLD=RUNNING";
+			env[0] = "SCHEDWI_STATUS_OLD=RUNNING";
 			break;
 		case JOB_STATUS_STATE_COMPLETED:
-			old_status_env = "SCHEDWI_STATUS_OLD=COMPLETED";
+			env[0] = "SCHEDWI_STATUS_OLD=COMPLETED";
 			break;
 		case JOB_STATUS_STATE_FAILED:
-			old_status_env = "SCHEDWI_STATUS_OLD=FAILED";
+			env[0] = "SCHEDWI_STATUS_OLD=FAILED";
 			break;
 		default:
-			old_status_env = "SCHEDWI_STATUS_OLD=UNKNOWN";
+			env[0] = "SCHEDWI_STATUS_OLD=UNKNOWN";
 			break;
 	}
 
 	switch (new_state) {
 		case JOB_STATUS_STATE_WAITING:
-			new_status_env = "SCHEDWI_STATUS_NEW=WAITING";
+			env[1] = "SCHEDWI_STATUS_NEW=WAITING";
 			break;
 		case JOB_STATUS_STATE_RUNNING:
-			new_status_env = "SCHEDWI_STATUS_NEW=RUNNING";
+			env[1] = "SCHEDWI_STATUS_NEW=RUNNING";
 			break;
 		case JOB_STATUS_STATE_COMPLETED:
-			new_status_env = "SCHEDWI_STATUS_NEW=COMPLETED";
+			env[1] = "SCHEDWI_STATUS_NEW=COMPLETED";
 			break;
 		case JOB_STATUS_STATE_FAILED:
-			new_status_env = "SCHEDWI_STATUS_NEW=FAILED";
+			env[1] = "SCHEDWI_STATUS_NEW=FAILED";
 			break;
 		default:
-			new_status_env = "SCHEDWI_STATUS_NEW=UNKNOWN";
+			env[1] = "SCHEDWI_STATUS_NEW=UNKNOWN";
 			break;
 	}
 
@@ -493,9 +355,7 @@ schedwi_status (int workload, const schedwi_jobtree_node_ptr job,
 	 */
 	ret = 0;
 	for (ptr = cmds_status; ptr != NULL; ptr = ptr->next) {
-		if (my_system (ptr->cmd, workload, job,
-				old_status_env, new_status_env) != 0)
-		{
+		if (schedwi_system (ptr->cmd, workload, job, env, 2) != 0) {
 			ret = -1;
 		}
 	}
@@ -524,7 +384,7 @@ schedwi_check (int workload, const schedwi_jobtree_node_ptr job)
 	int ret;
 
 	for (ptr = cmds_check; ptr != NULL; ptr = ptr->next) {
-		ret = my_system (ptr->cmd, workload, job, NULL, NULL);
+		ret = schedwi_system (ptr->cmd, workload, job, NULL, 0);
 		if (ret < 0 || ret == 127 || ret >= 300) {
 			return -1; /* System error */
 		}
