@@ -249,7 +249,7 @@ net_utils_server_thread (void *data)
 	 * SSL
 	 */
 	in.trusted_cert_ptr = (gnutls_certificate_credentials_t *) malloc (
-				sizeof (gnutls_certificate_credentials));
+				sizeof (gnutls_certificate_credentials_t));
 	if (in.trusted_cert_ptr == NULL) {
 		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
 		if (client_certificate != NULL) {
@@ -691,7 +691,7 @@ net_client (	const char *port_number, const char *hostname, char use_ssl,
 	 */
 	out->use_ssl = 1;
 	out->trusted_cert_ptr = (gnutls_certificate_credentials_t *) malloc (
-				sizeof (gnutls_certificate_credentials));
+				sizeof (gnutls_certificate_credentials_t));
 	if (out->trusted_cert_ptr == NULL) {
 		free (out);
 		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
