@@ -42,19 +42,23 @@ typedef struct _schedwi_BIO schedwi_BIO;
 
 extern int net_init OF((const char *schedwisrv_crt_file,
 			const char *schedwisrv_key_file,
+			const char *schedwisrv_ca_file,
+			const char *schedwisrv_crl_file,
 			char quick_random));
 extern int net_init_server OF(());
 extern void net_destroy OF(());
-extern int net_accept OF((	int sock,
+extern int net_accept_sock OF((	fd_set *sock_set, int sock_max,
+				const char *allow_from, char ***names));
+extern int net_accept OF((	fd_set *sock_set, int sock_max,
+				const char *allow_from,
 				int (*run)(schedwi_BIO *, void *),
 				void *user_data));
 extern schedwi_BIO *net_client OF((const char *port_number,
 			const char *hostname, char use_ssl,
 			char *remote_crt, unsigned int remote_crt_len));
-extern int net_read OF((schedwi_BIO *in, char **buff, unsigned int *len));
+extern int net_read OF((schedwi_BIO *in, char **buff, size_t *len));
 extern int net_read_result OF((schedwi_BIO *in, char **result_msg));
 extern int net_write OF((schedwi_BIO *out, const char *buff, int len));
-extern int net_write_eof OF((schedwi_BIO *out));
 extern void net_close OF((schedwi_BIO *out));
 
 #ifdef __cplusplus
