@@ -32,8 +32,6 @@
 #include <stdio.h>
 #endif
 
-#include <lwc_linkedlist.h>
-
 #define ERROR_MSG_LEN 255
 
 /* Allow the use in C++ code.  */
@@ -42,9 +40,9 @@ extern "C" {
 #endif
 
 struct result_str {
-        char *job_id;
+	char *job_id;
 	unsigned int job_id_len;
-        time_t duration;
+	time_t duration;
 	char was_killed;
 	int exit_code;
 };
@@ -54,8 +52,8 @@ extern result_t *new_result OF(());
 extern void destroy_result OF((result_t *r));
 extern int result_copy OF((const result_t *src, result_t *dst));
 extern int result_to_str OF((result_t *r, char **buffer, size_t *buffer_len));
-extern int str_to_results OF((	const char *buffer, size_t buffer_size,
-				lwc_LL **list));
+extern int str_to_result OF((	const char *buffer, int buffer_size,
+				result_t **result));
 extern int write_job_ended_to_file OF((	const char *file_name,
 					const char *job_id,
 					int exit_code,
