@@ -168,7 +168,7 @@ set_schedwi_jobtree_node (	schedwi_jobtree_node_ptr ptr,
 
 	if (sql_status_get (	workload_date, ptr->id, &current_status,
 				&start_time, &(ptr->retry_num),
-				&(ptr->wait_reason), NULL,
+				&(ptr->wait_reason), NULL, NULL,
 				sql_get_error_logger, NULL) != 0)
 	{
 		return -1;
@@ -1248,7 +1248,7 @@ do_transition (	schedwi_date workload_date,
 						ptr,
 						(ret == 2)
 						   ? JOB_STATUS_STATE_COMPLETED
-						   : JOB_STATUS_STATE_FAILED,
+						   : JOB_STATUS_STATE_WAITING,
 						current_time,
 						0, 0,
 						reply);
