@@ -487,7 +487,7 @@ sign_csr (const char *agent_name)
 
 	/* Retrieve the agent details from the database */
 	host_details = NULL;
-	ret = sql_host_get_main_row_names (	names, p, &host_details,
+	ret = sql_host_get_by_name (	names, p, &host_details,
 						NULL, NULL);
 	free (p);
 	destroy_client_names (names);
@@ -625,7 +625,7 @@ revoke_crt (const char *agent_name)
 
 	/* Retrieve the agent details from the database */
 	host_details = NULL;
-	ret = sql_host_get_main_row_names (	names, port, &host_details,
+	ret = sql_host_get_by_name (	names, port, &host_details,
 						NULL, NULL);
 	free (port);
 	destroy_client_names (names);
