@@ -1091,6 +1091,115 @@ check_job_host ()
 }
 
 
+/*
+ * Callback functions for sql_check_id() when an error is detected
+ */
+static int
+check_job_cluster_cb1 (void *data, row_item_t *id, row_item_t *host_id)
+{
+	unsigned long long int jobid;
+
+	jobid = (unsigned long long int) sql_row_item2ll (id);
+	switch (verbose_level) {
+		case NORMAL:
+		case VERBOSE:
+			printf (
+		_("job/cluster: error: unknown job/jobset Id `%lld'\n"),
+				jobid);
+			break;
+		default:
+			break;
+	}
+	if (autofix == 1) {
+		switch (verbose_level) {
+			case NORMAL:
+			case VERBOSE:
+				fputs (_("\tDeleting.\n"), stdout);
+				break;
+			default:
+				break;
+		}
+		sql_check_delete1 (	"job_cluster", "job_id", jobid,
+					sql_error_logger, NULL);
+	}
+	return 0;
+}
+
+static int
+check_job_cluster_cb2 (void *data, row_item_t *id, row_item_t *job_id)
+{
+	unsigned long long int clusterid;
+
+	clusterid = (unsigned long long int) sql_row_item2ll (id);
+	switch (verbose_level) {
+		case NORMAL:
+		case VERBOSE:
+			printf (
+			_("job/cluster: error: unknown cluster Id `%lld'\n"),
+				clusterid);
+			break;
+		default:
+			break;
+	}
+	if (autofix == 1) {
+		switch (verbose_level) {
+			case NORMAL:
+			case VERBOSE:
+				fputs (_("\tDeleting.\n"), stdout);
+				break;
+			default:
+				break;
+		}
+		sql_check_delete1 (	"job_cluster", "cluster_id", clusterid,
+					sql_error_logger, NULL);
+	}
+	return 0;
+}
+
+
+/*
+ * Check the association clusters/jobs
+ */
+static int
+check_job_cluster ()
+{
+	int ret;
+
+	if (verbose_level == VERBOSE) {
+		fputs (
+		    _("Checking the association between jobs and clusters:\n"),
+			stdout);
+	}
+
+	ret = 0;
+	switch (sql_check_id (	"job_cluster", "job_id",
+				"job_main", "id", "cluster_id",
+				check_job_cluster_cb1, NULL,
+				sql_error_logger, NULL))
+	{
+		case 0: break;
+		case 2: ret = 2; break;
+		default: return -1;
+	}
+
+	switch (sql_check_id (	"job_cluster", "cluster_id",
+				"clusters", "id", "job_id",
+				check_job_cluster_cb2, NULL,
+				sql_error_logger, NULL))
+	{
+		case 0: break;
+		case 2: ret = 2; break;
+		default: return -1;
+	}
+
+	if (ret == 0 && verbose_level == VERBOSE) {
+		fputs (_("\tOK\n"), stdout);
+	}
+
+	return ret;
+}
+
+
 /*
  * Callback functions for sql_check_id() when an error is detected
  */
@@ -1317,6 +1426,115 @@ check_host_environment ()
 }
 
 
+/*
+ * Callback functions for sql_check_id() when an error is detected
+ */
+static int
+check_host_cluster_cb1 (void *data, row_item_t *id, row_item_t *env_id)
+{
+	unsigned long long int hostid;
+
+	hostid = (unsigned long long int) sql_row_item2ll (id);
+	switch (verbose_level) {
+		case NORMAL:
+		case VERBOSE:
+			printf (
+			_("host/cluster: error: unknown host Id `%lld'\n"),
+				hostid);
+			break;
+		default:
+			break;
+	}
+	if (autofix == 1) {
+		switch (verbose_level) {
+			case NORMAL:
+			case VERBOSE:
+				fputs (_("\tDeleting.\n"), stdout);
+				break;
+			default:
+				break;
+		}
+		sql_check_delete1 (	"host_clusters", "host_id", hostid,
+					sql_error_logger, NULL);
+	}
+	return 0;
+}
+
+static int
+check_host_cluster_cb2 (void *data, row_item_t *id, row_item_t *host_id)
+{
+	unsigned long long int clusterid;
+
+	clusterid = (unsigned long long int) sql_row_item2ll (id);
+	switch (verbose_level) {
+		case NORMAL:
+		case VERBOSE:
+			printf (
+		_("host/cluster: error: unknown cluster Id `%lld'\n"),
+				clusterid);
+			break;
+		default:
+			break;
+	}
+	if (autofix == 1) {
+		switch (verbose_level) {
+			case NORMAL:
+			case VERBOSE:
+				fputs (_("\tDeleting.\n"), stdout);
+				break;
+			default:
+				break;
+		}
+		sql_check_delete1 ("host_clusters", "cluster_id", clusterid,
+					sql_error_logger, NULL);
+	}
+	return 0;
+}
+
+
+/*
+ * Check the association hosts/clusters
+ */
+static int
+check_host_cluster ()
+{
+	int ret;
+
+	if (verbose_level == VERBOSE) {
+		fputs (
+		_("Checking the association between hosts and clusters:\n"),
+			stdout);
+	}
+
+	ret = 0;
+	switch (sql_check_id (	"host_clusters", "host_id",
+				"hosts", "id", "cluster_id",
+				check_host_cluster_cb1, NULL,
+				sql_error_logger, NULL))
+	{
+		case 0: break;
+		case 2: ret = 2; break;
+		default: return -1;
+	}
+
+	switch (sql_check_id (	"host_clusters", "cluster_id",
+				"clusters", "id", "host_id",
+				check_host_cluster_cb2, NULL,
+				sql_error_logger, NULL))
+	{
+		case 0: break;
+		case 2: ret = 2; break;
+		default: return -1;
+	}
+
+	if (ret == 0 && verbose_level == VERBOSE) {
+		fputs (_("\tOK\n"), stdout);
+	}
+
+	return ret;
+}
+
+
 /*
  * Callback function for sql_check_id() when an error is detected
  */
@@ -1732,6 +1950,30 @@ main (int argc, char **argv)
 		global_ret = 2;
 	}
 
+	ret = check_job_cluster ();
+	if (ret < 0) {
+		end_sql ();
+		conf_destroy_srv ();
+		module_exit ();
+		free (lost_found_name);
+		return 1;
+	}
+	if (ret != 0) {
+		global_ret = 2;
+	}
+
+	ret = check_host_cluster ();
+	if (ret < 0) {
+		end_sql ();
+		conf_destroy_srv ();
+		module_exit ();
+		free (lost_found_name);
+		return 1;
+	}
+	if (ret != 0) {
+		global_ret = 2;
+	}
+
 	ret = check_calendars ();
 	if (ret < 0) {
 		end_sql ();
