@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2010 Herve Quatremain
+   Copyright (C) 2007-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -37,7 +37,6 @@
 #define SQLCOMMAND_ADD "INSERT INTO commands (workload_date,job_id,username,command,parameter) VALUES (%d,%s,%s,%d,%d)"
 #define SQLCOMMAND_DONE "UPDATE commands SET command_status=1 WHERE workload_date=%d AND job_id=%s AND command=%d AND parameter=%d"
 #define SQLCOMMAND_FAILED "UPDATE commands SET command_status=2 WHERE workload_date=%d AND job_id=%s AND command=%d AND parameter=%d"
-#define SQLCOMMAND_PURGE "DELETE FROM commands WHERE insert_time < %s"
 
 
 /*
@@ -247,34 +246,4 @@ sql_command_failed (	int workload_date, const char *job_id,
 	return 0;
 }
 
-
-/*
- * Remove the old completed and failed commands
- *
- * Return:
- *     0 --> No error
- *    -1 --> Memory allocation error.  If err_msg is not NULL it contains
- *           an error message to be freed by the caller by free()
- *    -2 --> SQL error.  If err_msg is not NULL it contains
- *           an error message to be freed by the caller by free()
- */
-int
-sql_command_purge (char **err_msg)
-{
-	int ret;
-	char *d;
-
-	d = sql_date_interval (-24 * 60 * 60); /* now - 1 day */
-	if (d == NULL) {
-		return -1;
-	}
-
-	ret = sql_non_select (	NULL, NULL, err_msg, NULL, NULL, NULL,
-				SQLCOMMAND_PURGE,
-				SQL_STRING, d,
-				SQL_END);
-	free (d);
-	return ret;
-}
-
 /*-----------------============== End Of File ==============-----------------*/
