@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2010 Herve Quatremain
+   Copyright (C) 2007-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -41,6 +41,10 @@
 #include <time.h>
 #endif
 
+#if HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #if HAVE_ASSERT_H
 #include <assert.h>
 #endif
@@ -309,7 +313,7 @@ sql_request (dbi_conn sql, dbi_result *result,
 {
 	sql_args_t args[MAX_NUM_ARGS];
 	sql_type t;
-	int i, ret;
+	int i, ret, try;
 	char c;
 	char *s;
 	unsigned char *us;
@@ -598,8 +602,29 @@ sql_request (dbi_conn sql, dbi_result *result,
 
 	free_args (args, MAX_NUM_ARGS);
 
-	/* Run the request */
-	*result = dbi_conn_query (sql, req);
+	/*
+	 * Run the request.
+	 * In case of failure, retry several times because in the case of
+	 * SQLite, the database may be locked temporarily by an other
+	 * process (schedwi or schedwigui).
+	 */
+	try = 0;
+	do {
+		if (++try > 1) {
+#if HAVE_NANOSLEEP
+			struct timespec time_req;
+
+			time_req.tv_sec = 1;
+			time_req.tv_nsec = 0;
+			nanosleep (&time_req, NULL);
+#elif HAVE_SLEEP
+			sleep (1);
+#else
+			usleep (1000000);
+#endif
+		}
+		*result = dbi_conn_query (sql, req);
+	} while (*result == NULL && dbi_conn_error (sql, NULL) && try < 5);
 	if (req_to_free != 0) {
 		free (req);
 	}
