@@ -246,6 +246,8 @@ get_job_path (unsigned long long int job_id, char **path, char **err_msg)
  * Get the hierarchy list of a job.  This list can then be passed as a
  * parameter to the get_job_parameters() and get_job_parameter() functions and
  * must be freed by the caller.
+ * The first item of the list is the ID of the provided job (`job_id') and
+ * the last one is the root jobset
  *
  * Return:
  *     The list to be freed by the caller using
@@ -374,6 +376,43 @@ get_hierarchy_list (	int workload_date, unsigned long long int job_id,
 }
 
 
+/*
+ * Convert a hierarchy array to a string of job IDs separated by commas
+ *
+ * Return:
+ *   0 --> No error.  result is set and must be freed by the caller by free()
+ *  -1 --> Memory allocation error
+ */
+int
+hierarchy_array_to_str(unsigned long long int *a, unsigned int l,
+		       char **result)
+{
+	char *s;
+	unsigned int i, j, n;
+
+	if (a == NULL || result == NULL) {
+		return 0;
+	}
+
+	s = (char *) malloc (l * 26);
+	if (s == NULL) {
+		return -1;
+	}
+
+	i = 0;
+	for (i = j = 0; j < l; j++) {
+		n = copy_ulltostr (a[j], s + i);
+		s[i + n] = ',';
+		i += n + 1;
+	}
+	if (i > 0) {
+		s[i - 1] = '\0';
+	}
+	*result = s;
+	return 0;
+}
+
+
 /*
  * Convert a hierarchy list to a string of job IDs separated by commas
  *
