@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2010 Herve Quatremain
+   Copyright (C) 2007-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -43,8 +43,8 @@
 
 #define SQL_HOSTS_LIST "SELECT id,hostname,portnum FROM hosts ORDER BY hostname"
 #define SQL_HOST_DELETE "DELETE FROM hosts WHERE id=%s"
-#define SQL_HOST_DETAIL "SELECT id,hostname,portnum,sslenable,sslcert,description FROM hosts WHERE id=%ld"
 #define SQL_HOST_DETAIL_FROM_NAMES "SELECT id,hostname,portnum,sslenable,sslcert,description FROM hosts WHERE hostname IN (%s) AND portnum=%s"
+#define SQL_HOST_DETAIL_FROM_ID "SELECT id,hostname,portnum,sslenable,sslcert,description FROM hosts WHERE id=%ld"
 #define SQL_HOST_NEW "INSERT INTO hosts (hostname,portnum,sslenable,sslcert,description) VALUES (%s,%s,%d,%s,%s)"
 #define SQL_HOST_UPDATE "UPDATE hosts SET hostname=%s,portnum=%s,sslenable=%d,sslcert=%s,description=%s WHERE id=%s"
 #define SQL_HOST_CERT "SELECT sslenable,sslcert FROM hosts WHERE hostname IN (%s) ORDER BY sslenable DESC"
@@ -154,146 +154,6 @@ sql_host_delete (	const char *host_id,
 }
 
 
-/*
- * Get the host details from the database
- *
- * Return:
- *     0 --> No error
- *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
- *           with user_data_error_func as its first parameter and the error
- *           message as the second parameter)
- *    -2 --> SQL error (if error_func() is not NULL, it is called with
- *           user_data_error_func as its first parameter and the error message
- *           as the second parameter)
- */
-int
-sql_host_get_main (	const char *host_id,
-			void (*set_host_id)(unsigned long long int, void *),
-			void (*set_host_name)(const char *, void *),
-			void (*set_host_port)(const char *, void *),
-			void (*set_host_SSL)(char, void *),
-			void (*set_host_cert)(const char *, void *),
-			void (*set_host_descr)(const char *, void *),
-			void *user_data_set_host,
-			void (*error_func)(void *, const char *, int),
-			void *user_data_error_func)
-{
-	char *err_msg = NULL;
-	int ret;
-	lwc_LL *rows;
-	row_item_t *row;
-
-#if HAVE_ASSERT_H
-	assert (host_id != NULL);
-#endif
-
-	ret = sql_select (	NULL, NULL, &err_msg, NULL, &rows,
-				SQL_HOST_DETAIL, SQL_STRING, host_id, SQL_END);
-
-	if (ret != 0) {
-		if (error_func != NULL) {
-			error_func (user_data_error_func, err_msg, ret);
-		}
-		if (err_msg != NULL) {
-			free (err_msg);
-		}
-		return ret;
-	}
-
-	row = (row_item_t *) lwc_delStartLL (rows);
-	if (row == NULL) {
-		lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
-		if (error_func != NULL) {
-			error_func (	user_data_error_func,
-					_("Unknown host id in the database"),
-					ret);
-		}
-		return -2;
-	}
-	lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
-
-	set_host_id (	(unsigned long long int)sql_row_item2ll (&(row[ID])),
-			user_data_set_host);
-	set_host_name (row[HOSTNAME].value_string, user_data_set_host);
-	set_host_port (row[PORTNUM].value_string, user_data_set_host);
-	set_host_SSL (	(char)sql_row_item2ll (&(row[SSLENABLE])),
-			user_data_set_host);
-	set_host_cert (row[SSLCERT].value_string, user_data_set_host);
-	set_host_descr (row[DESCR].value_string, user_data_set_host);
-
-	sql_free_row (row);
-
-	return 0;
-}
-
-
-/*
- * Get the host details from the database
- *
- * Return:
- *     0 --> No error.  row_out is set and must be freed by the caller by
- *                   sql_free_row (row_out);
- *           row_out is an array of row_item_t objects as follow:
- *                   row_out[0] --> host ID (the same as the host_id parameter)
- *                   row_out[1] --> Host name
- *                   row_out[2] --> TCP port
- *                   row_out[3] --> SSL?
- *                   row_out[4] --> SSL agent certificate
- *                   row_out[5] --> Host description
- *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
- *           with user_data_error_func as its first parameter and the error
- *           message as the second parameter)
- *    -2 --> SQL error (if error_func() is not NULL, it is called with
- *           user_data_error_func as its first parameter and the error message
- *           as the second parameter)
- */
-int
-sql_host_get_main_row (	unsigned long long int host_id,
-			row_item_t **row_out,
-			void (*error_func)(void *, const char *, int),
-			void *user_data_error_func)
-{
-	char *err_msg = NULL;
-	int ret;
-	lwc_LL *rows;
-	row_item_t *row;
-
-#if HAVE_ASSERT_H
-	assert (row_out != NULL);
-#endif
-
-	ret = sql_select (	NULL, NULL, &err_msg, NULL, &rows,
-				SQL_HOST_DETAIL,
-				SQL_INT, (long int)host_id,
-				SQL_END);
-
-	if (ret != 0) {
-		if (error_func != NULL) {
-			error_func (user_data_error_func, err_msg, ret);
-		}
-		if (err_msg != NULL) {
-			free (err_msg);
-		}
-		return ret;
-	}
-
-	row = (row_item_t *) lwc_delStartLL (rows);
-	lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
-	if (row == NULL) {
-		if (error_func != NULL) {
-			error_func (	user_data_error_func,
-					_("Unknown host id in the database"),
-					ret);
-		}
-		return -2;
-	}
-
-	*row_out = row;
-
-	return 0;
-}
-
-
 /*
  * Get the host details from the database.  The provided NULL terminated
  * host_names array contains all the known names of the searched host.
@@ -302,7 +162,7 @@ sql_host_get_main_row (	unsigned long long int host_id,
  *     0 --> No error.  row_out is set and must be freed by the caller by
  *                   sql_free_row (row_out);
  *           row_out is an array of row_item_t objects as follow:
- *                   row_out[0] --> host ID (the same as the host_id parameter)
+ *                   row_out[0] --> host ID
  *                   row_out[1] --> Host name
  *                   row_out[2] --> TCP port
  *                   row_out[3] --> SSL?
@@ -316,7 +176,7 @@ sql_host_get_main_row (	unsigned long long int host_id,
  *           as the second parameter)
  */
 int
-sql_host_get_main_row_names (char **host_names, const char *portnum,
+sql_host_get_by_name (	char **host_names, const char *portnum,
 			row_item_t **row_out,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func)
@@ -422,6 +282,85 @@ sql_host_get_main_row_names (char **host_names, const char *portnum,
 }
 
 
+/*
+ * Get the host details from the database.
+ *
+ * Return:
+ *     0 --> No error.  row_out is set and must be freed by the caller by
+ *                   sql_free_row (row_out);
+ *           row_out is an array of row_item_t objects as follow:
+ *                   row_out[0] --> host ID (the same as the host_id parameter)
+ *                   row_out[1] --> Host name
+ *                   row_out[2] --> TCP port
+ *                   row_out[3] --> SSL?
+ *                   row_out[4] --> SSL agent certificate
+ *                   row_out[5] --> Host description
+ *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
+ *           with user_data_error_func as its first parameter and the error
+ *           message as the second parameter)
+ *    -2 --> SQL error (if error_func() is not NULL, it is called with
+ *           user_data_error_func as its first parameter and the error message
+ *           as the second parameter)
+ */
+int
+sql_host_get_by_id (	unsigned long long int host_id,
+			row_item_t **row_out,
+			void (*error_func)(void *, const char *, int),
+			void *user_data_error_func)
+{
+	char *err_msg = NULL;
+	lwc_LL *rows;
+	row_item_t *row;
+	dbi_conn sql_handler;
+	int ret;
+
+
+#if HAVE_ASSERT_H
+	assert (row_out != NULL);
+#endif
+
+	/* Get the SQL handler */
+	sql_handler = begin_sql (&err_msg);
+	if (sql_handler == NULL) {
+		if (error_func != NULL) {
+			error_func (user_data_error_func, err_msg, 0);
+		}
+		return -2;
+	}
+
+	ret = sql_select (	NULL, NULL, &err_msg, NULL, &rows,
+				SQL_HOST_DETAIL_FROM_ID,
+				SQL_INT, (long int)host_id,
+				SQL_END);
+	end_sql ();
+
+	if (ret != 0) {
+		if (error_func != NULL) {
+			error_func (user_data_error_func, err_msg, ret);
+		}
+		if (err_msg != NULL) {
+			free (err_msg);
+		}
+		return ret;
+	}
+
+	row = (row_item_t *) lwc_delStartLL (rows);
+	lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
+	if (row == NULL) {
+		if (error_func != NULL) {
+			error_func (	user_data_error_func,
+					_("Host not defined in the database"),
+					ret);
+		}
+		return -2;
+	}
+
+	*row_out = row;
+
+	return 0;
+}
+
+
 /*
  * Insert a new host in the database
  *
@@ -621,19 +560,22 @@ sql_host_certificate (	char **names, char *sslenable,
 	lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
 	if (row == NULL) {
 		if (error_func != NULL) {
-            t = (char *)malloc (
-                    schedwi_strlen (_("Host not found in the database: looking for "))
-                    + j + 2);
-            if (t == NULL) {
-			    error_func (	user_data_error_func,
-				    _("Host not found in the database"), 0);
-            }
-            else {
-                strcpy (t, _("Host not found in the database: looking for "));
-                strcat (t, s);
-			    error_func (user_data_error_func, t, 0);
-                free (t);
-            }
+			t = (char *)malloc (
+			schedwi_strlen (
+			_("Host not found in the database: looking for "))
+				+ j + 2);
+			if (t == NULL) {
+				error_func (user_data_error_func,
+					_("Host not found in the database"),
+					0);
+			}
+			else {
+				strcpy (t,
+			_("Host not found in the database: looking for "));
+				strcat (t, s);
+				error_func (user_data_error_func, t, 0);
+				free (t);
+			}
 		}
 		free (s);
 		return -2;
