@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2011 Herve Quatremain
+   Copyright (C) 2007-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -372,6 +372,115 @@ sql_job_get_retries_interval (int workload_date,
 }
 
 
+/*
+ * Retrieve the `manual' flag for the provided job.
+ *
+ * Return:
+ *     0 --> No error.  manual contains the retrieved parameter.
+ *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
+ *           with user_data_error_func as its first parameter and the error
+ *           message as the second parameter)
+ *    -2 --> SQL error (if error_func() is not NULL, it is called with
+ *           user_data_error_func as its first parameter and the error message
+ *           as the second parameter)
+ */
+int
+sql_job_get_manual (int workload_date,
+			lwc_LL *hierarchy_list,
+			char *manual,
+			void (*error_func)(void *, const char *, int),
+			void *user_data_error_func)
+{
+	char *err_msg = NULL;
+	row_item_t value;
+	int ret;
+
+#if HAVE_ASSERT_H
+	assert (hierarchy_list != NULL);
+#endif
+
+	if (manual == NULL) {
+		return 0;
+	}
+	ret = get_job_parameter (	workload_date, hierarchy_list,
+					"job_manual_s",
+					"manual",
+					&value, &err_msg);
+	if (ret != 0) {
+		if (error_func != NULL) {
+			error_func (user_data_error_func, err_msg, ret);
+		}
+		if (err_msg != NULL) {
+			free (err_msg);
+		}
+		return ret;
+	}
+
+	if (value.type == RES_END) {
+		*manual = 0;
+	}
+	else  {
+		*manual = (char)sql_row_item2ll (&value);
+	}
+	return 0;
+}
+
+
+/*
+ * Retrieve the command to alert operator of a waiting manual job.
+ *
+ * Return:
+ *     0 --> No error.  manual_command contains the retrieved parameter and
+ *           must be freed by the caller by free().
+ *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
+ *           with user_data_error_func as its first parameter and the error
+ *           message as the second parameter)
+ *    -2 --> SQL error (if error_func() is not NULL, it is called with
+ *           user_data_error_func as its first parameter and the error message
+ *           as the second parameter)
+ */
+int
+sql_job_get_manual_command (int workload_date,
+			lwc_LL *hierarchy_list,
+			char **manual_command,
+			void (*error_func)(void *, const char *, int),
+			void *user_data_error_func)
+{
+	char *err_msg = NULL;
+	row_item_t value;
+	int ret;
+
+#if HAVE_ASSERT_H
+	assert (hierarchy_list != NULL);
+#endif
+
+	if (manual_command == NULL) {
+		return 0;
+	}
+	ret = get_job_parameter (	workload_date, hierarchy_list,
+					"job_manual_command_s",
+					"manual_command",
+					&value, &err_msg);
+	if (ret != 0) {
+		if (error_func != NULL) {
+			error_func (user_data_error_func, err_msg, ret);
+		}
+		if (err_msg != NULL) {
+			free (err_msg);
+		}
+		return ret;
+	}
+
+	if (value.type == RES_END) {
+		*manual_command = NULL;
+	}
+	else  {
+		*manual_command = value.value_string;
+	}
+	return 0;
+}
+
+
 /*
  * Upate the start_limit parameter of the provided job
  *
