@@ -37,21 +37,27 @@
 #include <assert.h>
 #endif
 
+#include <ping.h>
 #include <lib_functions.h>
+#include <lwc_log.h>
 #include <sql_common.h>
+#include <sql_hierarchy.h>
 #include <sql_status.h>
 
 #define SQLSTATUS_WORKLOAD_LIST "SELECT DISTINCT workload_date FROM job_status ORDER BY workload_date"
-#define SQLSTATUS_GET "SELECT status,start_time,retry_num,wait_reason,error_msg FROM job_status WHERE workload_date=%d AND job_id=%ld"
-#define SQLSTATUS_UPDATE "UPDATE job_status SET status=%d,start_time=%u,retry_num=%d,wait_reason=%d,error_msg=%s WHERE workload_date=%d AND job_id=%s"
-#define SQLSTATUS_SET "INSERT INTO job_status (workload_date,job_id,status,start_time,retry_num,wait_reason,error_msg) VALUES (%d,%s,%d,%u,%d,%d,%s)"
+#define SQLSTATUS_GET "SELECT status,start_time,retry_num,wait_reason,error_msg,duration FROM job_status WHERE workload_date=%d AND job_id=%ld"
+#define SQLSTATUS_UPDATE "UPDATE job_status SET status=%d,start_time=%u,retry_num=%d,wait_reason=%d,error_msg=%s,duration=%d WHERE workload_date=%d AND job_id=%s"
+#define SQLSTATUS_SET "INSERT INTO job_status (workload_date,job_id,status,start_time,retry_num,wait_reason,error_msg,duration) VALUES (%d,%s,%d,%u,%d,%d,%s,%d)"
 #define SQLSTATUS_UPDATE_WAIT_REASON "UPDATE job_status SET wait_reason=%d WHERE workload_date=%d AND job_id=%ld"
 #define SQLSTATUS_UPDATE_START_TIME "UPDATE job_status SET start_time=%u WHERE workload_date=%d AND job_id=%ld"
+#define SQLSTATUS_UPDATE_HOST "UPDATE job_status SET host_id=%ld WHERE workload_date=%d AND job_id=%ld"
 #define SQLSTATUS_DEL "DELETE FROM job_status WHERE workload_date=%d"
 #define SQLSTATUS_DEL_TABLES "DELETE FROM %s_s WHERE workload_date=%d"
 #define SQLSTATUS_CLEAN_TABLES "DELETE FROM %s WHERE workload_date=%d"
 #define SQLSTATUS_COPY "INSERT INTO %s_s SELECT *,%d FROM %s"
 #define SQLSTATUS_GET_OLD "SELECT workload_date FROM %s_s WHERE workload_date<%d"
+#define SQLSTATUS_HOST_COUNT_RUNNING "SELECT host_id,COUNT(*) FROM job_status WHERE status=2 AND host_id IN (%s) GROUP BY host_id ORDER BY COUNT(*)"
+
 
 /*
  * List of tables to copy.  These tables will be copied in tables with the
@@ -79,6 +85,7 @@ static char * status_tables[] = {	"calendars",
 					"job_environment",
 					"host_environment",
 					"job_host",
+					"job_cluster",
 					"constraint_file",
 					"jobset_background",
 					"job_icon_default",
@@ -165,6 +172,7 @@ sql_status_get (int workload_date,
 		int *retry_num,
 		int *wait_reason,
 		char **message,
+		long int *duration,
 		void (*error_func)(void *, const char *, int),
 		void *user_data_error_func)
 {
@@ -174,6 +182,7 @@ sql_status_get (int workload_date,
 	char *s;
 	row_item_t *row;
 
+
 #if HAVE_ASSERT_H
 	assert (status != NULL);
 #endif
@@ -243,6 +252,12 @@ sql_status_get (int workload_date,
 				: (int)sql_row_item2ll (&(row[3]));
 	}
 
+	/* Duration */
+	if (duration != NULL) {
+		*duration = (row == NULL) ? 0
+				: (long int)sql_row_item2ll (&(row[5]));
+	}
+
 	sql_free_row (row);
 	lwc_delLL (rows, (void (*)(const void *))sql_free_row);
 	return 0;
@@ -325,6 +340,7 @@ sql_status_set (int workload_date,
 		int retry_num,
 		int wait_reason,
 		const char *error_message,
+		long int duration,
 		void (*error_func)(void *, const char *, int),
 		void *user_data_error_func)
 {
@@ -344,6 +360,7 @@ sql_status_set (int workload_date,
 				SQL_INT, (long int)wait_reason,
 				SQL_STRING, (error_message != NULL)
 							? error_message: "",
+				SQL_INT, duration,
 				SQL_INT, (long int)workload_date,
 				SQL_STRING, job_id,
 				SQL_END);
@@ -374,6 +391,7 @@ sql_status_set (int workload_date,
 				SQL_INT, (long int)wait_reason,
 				SQL_STRING, (error_message != NULL)
 							? error_message: "",
+				SQL_INT, duration,
 				SQL_END);
 	if (ret != 0) {
 		if (error_func != NULL) {
@@ -679,4 +697,190 @@ sql_status_copy_to_workload (int workload_date,
 	return 0;
 }
 
+
+/*
+ * From the given host ID list, return the host ID on which a few number of
+ * jobs are running.
+ *
+ * Return:
+ *     0 --> No error
+ *    -1 --> Memory allocation error (if err_msg is not NULL, it contains the
+ *           error message which must be freed by the caller.  *err_msg may be
+ *           NULL if there is not enough memory to store the error message)
+ *    -2 --> SQL error (if err_msg is not NULL it contains an error
+ *           message which must be freed by the caller.  *err_msg may be NULL
+ *           if there is not enough memory to store the error message)
+ */
+int
+sql_status_select_host (lwc_LL *host_ids, unsigned long long int *host_id_out,
+			char **err_msg)
+{
+	char *s;
+	lwc_LL *rows;
+	row_item_t *row;
+	int num_ids, num_rows, ret, i, j;
+	unsigned long long int *a, *id;
+	char found;
+
+
+	num_ids = lwc_getNumNode (host_ids);
+
+#if HAVE_ASSERT_H
+	assert (host_ids != NULL && num_ids > 0 && host_id_out != NULL);
+#endif
+
+	if (num_ids == 1) {
+		/* Only one host ID in the list */
+		lwc_rewindLL (host_ids);
+		*host_id_out = *((unsigned long long int *)lwc_nextLL (
+								host_ids));
+		/* We don't try to ping this host, just return its ID */
+		return 0;
+	}
+
+	/* Convert the list in a string suitable for the SQL request */
+	if (hierarchy_list_to_str (host_ids, &s) != 0) {
+		if (err_msg != NULL) {
+			s = _("Memory allocation error");
+			*err_msg = (char *) malloc (schedwi_strlen (s) + 1);
+			if (*err_msg != NULL) {
+				strcpy (*err_msg, s);
+			}
+		}
+		return -1;
+	}
+
+	ret = sql_select (	NULL, NULL, err_msg, NULL, &rows,
+				SQLSTATUS_HOST_COUNT_RUNNING,
+				SQL_STRING_NON_ESCAPE, s,
+				SQL_END);
+	free (s);
+	if (ret != 0) {
+		return ret;
+	}
+
+	/*
+	 * Store all the IDs in an array sorted from the least to the most
+	 * used host (so later on, these hosts will be ping in the order to
+	 * find the least used working host)
+	 */
+	a = (unsigned long long int *) malloc ((num_ids + 1)
+					* sizeof (unsigned long long int));
+	if (a == NULL) {
+		lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
+		if (err_msg != NULL) {
+			s = _("Memory allocation error");
+			*err_msg = (char *) malloc (schedwi_strlen (s) + 1);
+			if (*err_msg != NULL) {
+				strcpy (*err_msg, s);
+			}
+		}
+		return -1;
+	}
+
+	i = 0;
+	/*
+	 * First, store all the IDs not in the returned SQL query (hosts
+	 * that don't have any running jobs)
+	 */
+	num_rows = lwc_getNumNode (rows);
+	if (num_ids > num_rows) {
+		lwc_rewindLL (host_ids);
+		while ((id = (unsigned long long int *)lwc_nextLL (host_ids))
+						!= NULL)
+		{
+			found = 0;
+			lwc_rewindLL (rows);
+			while ((row = (row_item_t *)lwc_nextLL (rows))
+						!= NULL)
+			{
+				if (*id ==
+			(unsigned long long int) sql_row_item2ll (&(row[0])))
+				{
+					found = 1;
+					break;
+				}
+			}
+			if (found == 0) {
+				a[i++] = *id;
+			}
+		}
+	}
+	/* Then store the IDs of hosts with running jobs */
+	while ((row = (row_item_t *) lwc_delStartLL (rows)) != NULL) {
+		a[i++] = (unsigned long long int) sql_row_item2ll (&(row[0]));
+		sql_free_row (row);
+	}
+	lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
+
+	/* Return the ID of the first host in the array that can be pinged */
+	for (j = 0; j < i; j++) {
+		if (ping_by_id (a[j]) == 0) {
+			*host_id_out = a[j];
+			free (a);
+			return 0;
+		}
+	}
+
+	/* All the pings failed. Return the first host anyway */
+	*host_id_out = a[0];
+	free (a);
+	lwc_writeLog (LOG_WARNING, _("None of the hosts replied to ping"));
+	return 0;
+}
+
+
+/*
+ * Change the host ID associated with the given job/jobset.
+ *
+ * @param workload_date:
+ * 			The workload date of the job/jobset.
+ * @param job_id:
+ * 			The database ID of the job or jobset.
+ * @param host_id:
+ * 			The new host ID.
+ * @param error_func:
+ * 			Caller error function which is called when an SQL
+ * 			error occurs.  May be NULL.
+ * @param user_data_error_func:
+ * 			Caller data which is passed to the error_func as the
+ * 			first parameter.
+ * @return:
+ *     0 --> Success
+ *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
+ *           with user_data_error_func as its first parameter and the error
+ *           message as the second parameter)
+ *    -2 --> SQL error (if error_func() is not NULL, it is called with
+ *           user_data_error_func as its first parameter and the error message
+ *           as the second parameter)
+ */
+int
+sql_status_update_host_id (	int workload_date,
+				unsigned long long int job_id,
+				unsigned long long int host_id,
+				void (*error_func)(void *, const char *, int),
+				void *user_data_error_func)
+{
+	char *err_msg = NULL;
+	int ret;
+
+
+	ret = sql_non_select (  NULL, NULL, &err_msg, NULL, NULL, NULL,
+				SQLSTATUS_UPDATE_HOST,
+				SQL_INT, (long int)host_id,
+				SQL_INT, (long int)workload_date,
+				SQL_INT, (long int)job_id,
+				SQL_END);
+	if (ret != 0) {
+		if (error_func != NULL) {
+			error_func (user_data_error_func, err_msg, ret);
+		}
+		if (err_msg != NULL) {
+			free (err_msg);
+		}
+		return ret;
+	}
+	return 0;
+}
+
 /*-----------------============== End Of File ==============-----------------*/
