@@ -48,6 +48,7 @@ extern int sql_status_get OF((int workload_date,
 			int *retry_num,
 			int *wait_reason,
 			char **message,
+			long int *duration,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
 extern int sql_status_update_wait_reason OF((int workload_date,
@@ -62,6 +63,7 @@ extern int sql_status_set OF((int workload_date,
 			int retry_num,
 			int wait_reason,
 			const char *error_message,
+			long int duration,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
 extern int sql_status_adjust_start_time OF((int workload_date,
@@ -80,6 +82,14 @@ extern int sql_status_get_old OF((int workload_date,
 extern int sql_status_copy_to_workload OF((int workload_date,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
+extern int sql_status_select_host OF((lwc_LL *host_ids,
+			unsigned long long int *host_id_out,
+			char **err_msg));
+extern int sql_status_update_host_id OF((int workload_date,
+			unsigned long long int job_id,
+			unsigned long long int host_id,
+			void (*error_func)(void *, const char *, int),
+			void *user_data_error_func));
 
 #ifdef __cplusplus
 }
