@@ -47,6 +47,7 @@ extern int errno;
 #include <utils.h>
 #include <lwc_log.h>
 #include <net_utils.h>
+#include <sql_status.h>
 #include <sql_common.h>
 #include <sql_hierarchy.h>
 #include <sql_hosts.h>
@@ -55,7 +56,7 @@ extern int errno;
 #include <startjob.h>
 
 /*
- * Error callback function for the sql_host_get_main_row() function
+ * Error callback function for the sql_host_get_by_id() function
  */
 static void
 sql_host_get_main_row_error_logger (	void *data, const char *msg,
@@ -71,6 +72,23 @@ sql_host_get_main_row_error_logger (	void *data, const char *msg,
 }
 
 
+/*
+ * Error callback function for the sql_status_update_host_id() function
+ */
+static void
+sql_status_update_host_id_error_logger (void *data, const char *msg,
+					int err_code)
+{
+	if (msg != NULL) {
+		lwc_writeLog (LOG_WARNING, msg);
+	}
+	else {
+		lwc_writeLog (LOG_WARNING,
+		_("Database error while updating the status (host) of a job"));
+	}
+}
+
+
 /*
  * Callback for the SQL function which retrieves the command arguments
  *
@@ -124,7 +142,7 @@ argument_callback (void *obj, row_item_t *row)
  *         no need to wait for a result.  out_message is not changed
  *  -1 --> Error (a message is logged using lwc_writeLog()).  If not NULL,
  *         out_message contains an error message.  It may be NULL if there
- *         is not enought memory to allocate a buffer for this message.
+ *         is not enough memory to allocate a buffer for this message.
  *         out_message must be freed by the caller by free()
  */
 int
@@ -632,7 +650,8 @@ startjob (	int workload_date, unsigned long long int job_id,
 	lwc_delLL (hierarchy_list, (void (*)(const void *))free);
 
 	/* Get the host details */
-	ret= sql_host_get_main_row (host_id, &host_details,
+	ret= sql_host_get_by_id (	host_id,
+					&host_details,
 					sql_host_get_main_row_error_logger,
 					NULL);
 	if (ret != 0) {
@@ -649,6 +668,14 @@ startjob (	int workload_date, unsigned long long int job_id,
 		return -1;
 	}
 
+	/*
+	 * Update the database to specify the host on which the job is
+	 * going to run
+	 */
+	sql_status_update_host_id (	workload_date, job_id, host_id,
+					sql_status_update_host_id_error_logger,
+					NULL);
+
 	/* Establish the connection to the agent */
 	b = net_client (host_details[2].value_string,  /* TCP port */
 			host_details[1].value_string,  /* Agent host name */
