@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2012 Herve Quatremain
+   Copyright (C) 2007-2013 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -55,7 +55,7 @@ extern int errno;
 #include <stopjob.h>
 
 /*
- * Error callback function for the sql_host_get_main_row() function
+ * Error callback function for the sql_host_get_by_id() function
  */
 static void
 sql_host_get_main_row_error_logger (	void *data, const char *msg,
@@ -143,7 +143,7 @@ stopjob (	int workload_date, unsigned long long int job_id,
 	lwc_delLL (hierarchy_list, (void (*)(const void *))free);
 
 	/* Get the host details */
-	ret = sql_host_get_main_row (
+	ret = sql_host_get_by_id (
 			(unsigned long long int) sql_row_item2ll (&host_id),
 			&host_details,
 			sql_host_get_main_row_error_logger,
